

**********************************************************************

* Authors: [Corey Barwick and Vanessa Baird]

* Date Created: [3/19/22]

* Contents: 1. Explain project
*               1.1 	Overview
* 				1.1.a 	Header code 
* 				1.1.b 	Path macros  
* 				1.1.c 	Define data and set log 

*           2. Prepare data for analysis
*               2.1 Clean and check data 
*               2.2 Descriptives: documentation and appendices
*           	2.3 Define variable macros 

*           3. Exploratory analysis 
*               3.1 Exploratory indices, measurement
*               3.2 Exploratory bivariate, trivariate 
*               3.3 Figuring out the basic model 
*               3.4 Complex models (separate models, interactions, etc.)
*				3.5 Documentation of additional indices, measures, and errata (changes after initial posting of clean data)

*           4. Final models in drafts 
*               4.1 Measurement and indices
*               4.2 The basic model 
*               4.3 Complexity: nonlinearity, interactions 
*               4.4 Final coefficient plots, marginsplots, and other visualizations   

**********************************************************************

* 1. Explain project

* The purpose of this project is to understand how our perceptions of ourselves and our lives has an impact on our support for the rule of law, and its concrete applications, such as support for presidents to follow displeasing laws, and support for the ultimate departure for the rule of law: violence for political ends. 

*1.1 Overview

* Original data include the CCES 2016 and 2020. We can also make use of TAPS and the GSS. 

**********************************************************************
* Master Rule of law do files for CCES 2016
**********************************************************************


* 1.1.a Header code 



clear all
macro drop _all

global date: display %td_CCYY_NN_DD date(c(current_date), "DMY")

global date_string = subinstr(trim("$date"), " " , "-", .)

**********************************************************************
* 				1.1.b 	Path macros  
**********************************************************************

* do "${rol_Working}1.1.b.barwick_macro_paths.do"

do "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Rule of law/Working/Clean/1.1.b.baird_macro_paths.do"
**********************************************************************
* 2016 Data 
**********************************************************************

use "${rol_Orig}CCES2016_Orig.dta", replace

* Immediately save it with a new name 
save "${rol_Orig}${date_string}_CCES2016_Clean.dta" , replace 

**********************************************************************
*           2. Prepare data for analysis
*               2.1 Clean and check data
**********************************************************************

* 2.1.a Variable keeps and drops  

do "${rol_Clean}2.1.a.keep2016.do" 			// This keeps original variables to make data more compact

* Immediately save the working file with a new name 
save "${rol_Clean}CCES2016_CleanWorking.dta" , replace

* 1.2.c Var list macros  
	* Demographic and survey vars: demogs
	* Economic vars: econvars (relative deprivation in 2020 only)
	* Political variables: voting, participation, ideology, interest, knowledge, media
	* Dependent vars: Sup. for law, police, courts, violence (violence in 2020 only), concrete rule of law (2016 only)
	* Sense of self and life vars: idvars: grievance, locus of control, sensitivity of social norms, emotions 
	* Superordinate identity 					(2020 only)
	* Subgroup identity: see self and link 		(2020 only)
	* General political values: valvars 
	* Specific political values: policyvars 

do "${rol_Clean}2.1.b.demogs2016.do"		// This file defines survey variables and demographics	
do "${rol_Clean}2.1.c.econvars2016.do"		// This file defines economic perceptions, recent life events, and income 
do "${rol_Clean}2.1.d.polvars2016.do"		// This file defines political variables: ideology, party, pol participation 
do "${rol_Clean}2.1.e.dvs2016.do"			// This file defines rule of law vars, diffuse suppport, and police variables 
do "${rol_Clean}2.1.f.idvars2016.do"		// This file defines identity variables 
do "${rol_Clean}2.1.g.valvars2016.do"		// This file defines general political values - racial resentment, etc. 
do "${rol_Clean}2.1.h.policyvars2016.do"	// This file defines policy attitudes 

* This command, when run, saves a new file in posted - there is no replace because it can't be overwritten once posted 

save "${rol_PostedClean}${date_string}_CCES2016_CleanAllPosted.dta" 

save "${rol_Clean}CCES2016_CleanAll.dta" , replace


* 1.2.c Post cleaning variable checking, keeping, codebooks 
do "${rol_Clean}2.1.i.check_compact2016.do"	// This file runs variable checks, keeps, order, codebook 

save "${rol_PostedClean}${date_string}_CCES2016_CleanCompactPosted.dta" , replace 

save "${rol_Clean}${date_string}CCES2016_CleanCompactWorking.dta" , replace

**********************************************************************
* Law and society submission 3-22-2022
**********************************************************************


*           4. Final models in drafts 

global rol_LawSoc "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Rule of law/Papers/LawSoc/Working/DataTemp"

do "${rol_LawSoc}4.DescStats_Analysis_Plots.do"	// This file runs all the analyses  

