


*********************************************************************************
																				*
* Replication do file for "Social identity and support for the rule of law"							*
																				*  
* Wolak, Jennifer and Vanessa Baird 							*			 *																				 *
*                                                                              	*
* Software used: Stata/SE 17.0                                                  *
*********************************************************************************


**********************************************************************
* Designate your paths  
**********************************************************************


* What you should do here is create the same globals with the same names, but put in your particular path. 


* As an example, consider this command 
* global cces_Clean "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Newest do files/"

* Replace your path that directs it to where you stored CCES. Change this part and leave the rest the same. 

* For a PC user, the path might be something like this:
	* global	"C:\Desktop\Project_A\"

* NOTE: I find it easier to use globals, but Stata programmers will warn you STRONGLY against that. 
* So, make sure to call any global macro something very particular, and not something like "reg" .

/*
global cces_Clean "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Newest do files/"

global cces_Orig "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/Rule of law/Posted/DataOrig/"

global cces_PostedClean "/Users/vanessabaird/Library/CloudStorage/OneDrive-UCB-O365/CU/Research/CCES/Posted/DataClean/"

use "${cces_Orig}CCES2020_Orig.dta"

********************************************************************************
* Macros to assign dates to working clean data *                               
********************************************************************************


global date: display %td_CCYY_NN_DD date(c(current_date), "DMY")

global date_string = subinstr(trim("$date"), " " , "-", .)

save "${cces_Clean}${date_string}_CCES2020_COVID_Serious_Replication.dta" , replace
*/



********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************

**# * Cleaning data

* Creating and recoding new variables, assigning missings and labels, etc.

********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************






*****************************************************************
* Case ID, Survey Weight, and Took Post-Election Survey Variables * 
*****************************************************************



***Case ID, Survey Weight, and Took Post-Election Survey Variables***
//caseid; weight; tookpost; state_fips

**Case ID**
	*varname: caseid*
label var caseid "Case ID"

**Weight**
	*varname: weight*
generate weight = teamweight
order weight, after(caseid)

**Took Post-Election Survey**
	*varname: tookpost*
		// 0 = No; 1 = Yes
order tookpost, after(weight)


**State FIPS Code**
	*varname: state_fips*
		// inputstate is the state R lived in when taking the pre-election
		// questionnaire
clonevar state_fips = inputstate
clonevar zipcode = inputzip
clonevar county_fips = countyfips


label var state_fips "R's state: FIPS code"
order state_fips, after(weight)
order county_fips, after(state_fips)
order zipcode, after(state_fips)


*****************************************************************
* Demographics * 
*****************************************************************

// age01; female; educ01; race_4cat, race_4cat, nonwhite, nonwhite_v2,
// black, black_v2; married; state_fips


* Age * 
	* varname: age01*
generate age=2020-birthyr
label var age "Respondent's age (18-92)"
generate age01=(age-18)/(92-18)
note age01: Respondent's age (0 to 1)
label var age01 "Age"

* Gender * 
	* varname: female*
recode gender (1=0 "0.Male")	(2=1 "1.Female"), generate(female)
note female: Respondent's gender (0=male; 1=female)
label var female "Female"

* Education * 
	* varname: educ01*
recode educ (1=0 	"0.No HS")	(2=1 "1.High School Graduate")  /// 
			(3=2 "2.Some College")	(4=3 "3.2-year")	 /// 
			(5=4 "4.4-year")	(6=5 "5.Post-grad"), generate(educ_6cat)
label var educ_6cat "Respondent's education-level"
generate educ01=educ_6cat/5
note educ01: Respondent's education-level (0 to 1)
label var educ01 "Education"	

* Race * 
	* varname: race_4cat_v2*
recode race (1=0 "0.White")	(2=1 "1.Black")  /// 
			(3=2 "2.Hispanic")	(4/8=3 "3.Other"), generate(race_4cat_v2)
 note race_4cat_v2: Respondent's and ethnicity, simple (0=white; 1=black; 2=hispanic; 3=other)
label var race_4cat_v2 "Race / ethnicity, simple"



	* varname: race_4cat*
generate race_4cat=.
	//generate a new race variable, with all missing values, encoding multiple races

	*white*
replace race_4cat=0 if race==1 & hispanic ~=1 &  /// 
	multrace_2 ~=1 & 	multrace_3 ~=1 & 	multrace_4 ~=1 &  /// 
	multrace_5 ~=1 & 	multrace_8 ~=1 & 	multrace_97 ~=1 &  /// 
	multrace_98 ~=1 

replace race_4cat=0 if race==1 & hispanic==.a &  /// 
	multrace_2 ~=1 & 	multrace_3 ~=1 & 	multrace_4 ~=1 &  /// 
	multrace_5 ~=1 & 	multrace_8 ~=1 & 	multrace_97 ~=1 &  /// 
	multrace_98 ~=1  

replace race_4cat=0 if race==6 & hispanic ~=1 &  /// 
	multrace_1==1 & 	multrace_2 ~=1 & 	multrace_3 ~=1 &  /// 
	multrace_4 ~=1 & 	multrace_5 ~=1 & 	multrace_8 ~=1 &  /// 
	multrace_97 ~=1 & 	multrace_98 ~=1 

replace race_4cat=0 if race==6 & hispanic ~=1 &  /// 
	multrace_1==1 & 	multrace_2 ~=1 & 	multrace_3 ~=1 &  /// 
	multrace_4 ~=1 & 	multrace_5 ~=1 & 	multrace_8 ~=1 &  ///
	multrace_97==.b & 	multrace_98 ~=1 

replace race_4cat=0 if race==7 & hispanic ~=1 &  /// 
	multrace_1==1 & 	multrace_2 ~=1 & 	multrace_3 ~=1 &  ///
	multrace_4 ~=1 & 	multrace_5 ~=1 & 	multrace_8 ~=1 &  ///
	multrace_97 ~=1 & 	multrace_98 ~=1 	

/* Extensive comment about "white"racial category in race_4cat 

i. Respondent coded as "white"if respondent identified as white in the race variable, did not identify as hispanic, and did not identify as any other race, or 

	ii.	skipped hispanic, did not identify as any other race, or 

	iii.	mixed but not hispanic, and only white in multrace vars, or 

	iv.	mixed but not asked multrace_97 

	v. 	other but not hispanic, and only white in multrace vars 
*/

	*black*
replace race_4cat=1 if race ~=1 & hispanic ~=1 &  /// 
	multrace_1 ~=1 & 	multrace_3 ~=1 & 	multrace_3 ~=1 &  /// 
	multrace_4 ~=1 & 	multrace_5 ~=1 & 	multrace_8 ~=1 &  /// 
	multrace_97 ~=1 & 	multrace_98 ~=1 

replace race_4cat=1 if race ~=1 & hispanic==.a &  /// 
	multrace_1 ~=1 & 	multrace_3 ~=1 & 	multrace_3 ~=1 &  /// 
	multrace_4 ~=1 & 	multrace_5 ~=1 & 	multrace_8 ~=1 &  /// 
	multrace_97 ~=1 & 	multrace_98 ~=1 

replace race_4cat=1 if race==6 & hispanic ~=1 &  /// 
	multrace_1 ~=1 & 	multrace_2==1 & 	multrace_3 ~=1 &  /// 
	multrace_4 ~=1 & 	multrace_5 ~=1 & 	multrace_8 ~=1 &  /// 
	multrace_97 ~=1 & 	multrace_98 ~=1 

replace race_4cat=1 if race==6 & hispanic ~=1 &  /// 
	multrace_1 ~=1 & 	multrace_2==1 & 	multrace_3 ~=1 &  /// 
	multrace_4 ~=1 & 	multrace_5 ~=1 & 	multrace_8 ~=1 &  /// 
	multrace_97==.b & 	multrace_98 ~=1 

replace race_4cat=1 if race==7 & hispanic ~=1 &  /// 
	multrace_1 ~=1 & 	multrace_2==1 & 	multrace_3 ~=1 &  /// 
	multrace_4 ~=1 & 	multrace_5 ~=1 & 	multrace_8 ~=1 &  /// 
	multrace_97 ~=1 & 	multrace_98 ~=1 

/* Extensive comment about "black"racial category in race_4cat 

i. Respondent coded as "black"if respondent identified as black in the race variable, did not identify as hispanic, and did not identify as any other race, or 

	ii.	skipped hispanic, did not identify as any other race, or 

	iii.	mixed but not hispanic, and only black in multrace vars, or 

	iv.	mixed but not asked multrace_97, or 

	v. 	other but not hispanic, and only black in multrace vars 
*/

	*hispanic*
replace race_4cat=2 if race==3 & 		multrace_2 ~=1 &  /// 
	multrace_4 ~=1 & 	multrace_5 ~=1 & 	multrace_8 ~=1 &  /// 
	multrace_97 ~=1  

replace race_4cat=2 if race==1 & hispanic==1 & 	multrace_2 ~=1 &  /// 
	multrace_4 ~=1 & 	multrace_5 ~=1 & 	multrace_8 ~=1 &  /// 
	multrace_97 ~=1 & 	multrace_98 ~=1 

replace race_4cat=2 if race==1 & 	multrace_1==1 &  /// 
	multrace_2 ~=1 & 	multrace_3==1 & 	multrace_4 ~=1 &  /// 
	multrace_5 ~=1 & 	multrace_8 ~=1 & 	multrace_97 ~=1 &  /// 
	multrace_98 ~=1 

replace race_4cat=2 if race==1 & 	multrace_1 ~=1 &  /// 
	multrace_2 ~=1 & 	multrace_3==1 & 	multrace_4 ~=1 &  /// 
	multrace_5 ~=1 & 	multrace_8 ~=1 & 	multrace_97 ~=1 &  /// 
	multrace_98 ~=1 

replace race_4cat=2 if race==6 & hispanic==1 &  /// 
	multrace_2 ~=1 & 	multrace_4 ~=1 & 	multrace_5 ~=1 &  /// 
	multrace_8 ~=1 & 	multrace_97 ~=1 & 	multrace_98 ~=1 
	
replace race_4cat=2 if race==6 & hispanic==1 &  /// 
	multrace_2 ~=1 & 	multrace_4 ~=1 & 	multrace_5 ~=1 &  /// 
	multrace_8 ~=1 & 	multrace_97==.b & 	multrace_98 ~=1 

replace race_4cat=2 if race==6 & 	multrace_1 ~=1 &  /// 
	multrace_2 ~=1 & 	multrace_3==1 & 	multrace_4 ~=1 &  /// 
	multrace_5 ~=1 & 	multrace_8 ~=1 & 	multrace_97 ~=1 &  /// 
	multrace_98 ~=1 

replace race_4cat=2 if race==6 & 	multrace_1 ~=1 &  /// 
	multrace_2 ~=1 & 	multrace_3==1 & 	multrace_4 ~=1 &  /// 
	multrace_5 ~=1 & 	multrace_8 ~=1 & 	multrace_97==.b &  /// 
	multrace_98 ~=1 

replace race_4cat=2 if race==6 & 	multrace_1==1 &  /// 
	multrace_2 ~=1 & 	multrace_3==1 & 	multrace_4 ~=1 &  /// 
	multrace_5 ~=1 & 	multrace_8 ~=1 & 	multrace_97 ~=1 &  /// 
	multrace_98 ~=1 

replace race_4cat=2 if race==6 & 	multrace_1==1 &  /// 
	multrace_2 ~=1 & 	multrace_3==1 & 	multrace_4 ~=1 &  /// 
	multrace_5 ~=1 & 	multrace_8 ~=1 & 	multrace_97==.b &  /// 
	multrace_98 ~=1 

replace race_4cat=2 if race==7 & hispanic==1 &  /// 
	multrace_2 ~=1 & 	multrace_4 ~=1 & 	multrace_5 ~=1 &  /// 
	multrace_8 ~=1 & 	multrace_97 ~=1 & 	multrace_98 ~=1 

replace race_4cat=2 if race==7 & 	multrace_1 ~=1 &  /// 
	multrace_2 ~=1 & 	multrace_3==1 & 	multrace_4 ~=1 &  /// 
	multrace_5 ~=1 & 	multrace_8 ~=1 & 	multrace_97 ~=1 &  /// 
	multrace_98 ~=1 

replace race_4cat=2 if race==7 & 	multrace_1==1 &  /// 
	multrace_2 ~=1 & 	multrace_3==1 & 	multrace_4 ~=1 &  /// 
	multrace_5 ~=1 & 	multrace_8 ~=1 & 	multrace_97 ~=1 &  /// 
	multrace_98 ~=1 

/* Extensive comment about "Hispanic"racial category in race_4cat 

i. Respondent coded as "Hispanic"if respondent identified as white in the race variable, Hispanic in the hispanic variable, and did not identify as any other race in the multrace vars, outside of white or hispanic 

	iii.	mixed in race variable but only Hispanic or white in multrace vars, or 

	iv.	mixed but not asked multrace_97, or 

	v. 	hispanic and other race, only white or Hispanic in multrace vars 
*/

	*other*
replace race_4cat=3 if race==4
replace race_4cat=3 if race==5
replace race_4cat=3 if race==8
replace race_4cat=3 if race_4cat==.

/* Extensive comment about "other"racial category in race_4cat 

Respondent coded as "other"if respondent identified as "Asian"or "Native American"or "Middle Eastern"in the race variable, or not identified by previous lines of code 

*/

note race_4cat: Respondent's and ethnicity, multiple races encoded (0=white with no other race or ethnicity; 1=black listed at all unless hispanic; 2=Hispanic (White or black); 3= "Asian"or "Native American"or "Middle Eastern"in the race variable, or not identified)
label var race_4cat "Race / ethnicity"

label define race_4cat 0 "White" 1 "Black" 2 "Latino" 3 "Other"
label values race_4cat race_4cat


	* varname: nonwhite*
	
generate nonwhite=.
replace nonwhite=0 if race_4cat==0
replace nonwhite=1 if race_4cat==1
replace nonwhite=1 if race_4cat==2
replace nonwhite=1 if race_4cat==3
label var nonwhite "Not white"

	* varname: black*
generate black=.
replace black=0 if race_4cat==0
replace black=0 if race_4cat==2
replace black=0 if race_4cat==3
replace black=1 if race_4cat==1
note black: Respondent identifies as black, multiple races encoded
label var black "Black"

* Marital Status * 
	* varname: married*
recode marstat 	(1 6=1 "1.Married or Domestic Partnership")	(2/5=0 "0.Not Married"), generate(married)
label var married "Respondent's marital status (0=not married; 1=married)"






*****************************************************************
* Economic perceptions  
* income, economic circumstances, and events *
*****************************************************************

// income01, inc01, inc01_1; nosayinc; sociopast01; pocketpast01; 
* 2020: 	married1 	lostjob1 	grad1 	retired1 	div1 	child1 /// 
*			newjob1 	victim1 	er1 	
* 			doctor1 	raise1 		paycut1 


// faminc income01 inc01 inc01_1 nosayinc
// CC20_302 sociopast01 
// CC20_303 pocketpast01

* Income * 
	* varname: income01*
recode faminc 	(1=0 "0.Less than $10,000")	(2=1 "1.$10,000-$19,999")  /// 
				(3=2 "2.$20,000-$29,999") 	(4=3 "3.$30,000-$39,999")  /// 
				(5=4 "4.$40,000-$49,999") 	(6=5 "5.$50,000-$59,999")  /// 
				(7=6 "6.$60,000-$69,999") 	(8=7 "7.$70,000-$79,999")  /// 
				(9=8 "8.$80,000-$99,999") 	(10=9 "9.$100,000-$119,999")  /// 
				(11=10 "10. $120,000-$149,999")  /// 
				(12/16 31=11 "11. $150,000 or more")  /// 
				(97=.a "Prefer not to say"), generate(income)

label var income "Respondent's family income"

generate income01=income/11
note income01: Respondent's family income (0 to 1) (11 categories)
label var income01 "Income"

	* varname: inc01 inc01_1 
clonevar inc01=income01
clonevar inc01_1 = inc01
replace inc01_1 = -1 if inc01==.
note inc01_1 : Income, with missing = -1; Must be used in conjunction with nosayinc

label var inc01_1 "inc01 with missing = -1"
	// Must be used in conjunction with 
	* varname: nosayinc
generate nosayinc=0
replace nosayinc=1 if inc01_1==-1
note nosayinc: 0=R reported an income; 1=R did not report an income
label var nosayinc "income missing"

* Perceptions of the economy and personal finances * 

//sociopast01; pocketpast01; 


* PRE Common 






* Perception of the National Economy * 
	* varname: sociopast01*
		// over the past year the nation's economy has...?
recode CC20_302 (1=4 "4.Gotten much better") 	(2=3 "3.Gotten better")  /// 
				(3=2 "2.Stayed about the same")	(4=1 "1.Gotten worse")  /// 
				(5=0 "0.Gotten much worse")	(6=.a "Not sure"),  /// 
generate(sociopast)
label var sociopast "Over the past year the nation's economy has...? (4=Gotten much better)"
generate sociopast01 = sociopast/4
	label var sociopast01 "National economy, past"
note sociopast01: Over the past year, do you think the nation's economy has gotten worse/better (0 to 1)


* Personal Income (Past Four Years) *
	* varname: pocketpast01*
		// over the past four years, has your household's annual income...?
recode CC20_303 	(1=4 "4.Increased a lot")		(2=3 "3.Increased somewhat")	 /// 
					(3 6=2 "2.Same / not sure")	(4=1 "1.Decreased somewhat")	 /// 
					(5=0 "0.Decreased a lot"), generate(pocketpast)
label var pocketpast "Over the past four years, has your household's annual income...? (4=Increased a lot)"
generate pocketpast01=pocketpast/4
note pocketpast01: Over the past four years, has your household's annual income decreased / increased
label var pocketpast01 "Personal financial perceptions, past four years"

	
*****************************************************************
* Life Over the Past year * 
*****************************************************************

// in 2020 but not 2016 
// Visited a doctor for a regular examination _11
// Had a pay cut at work: _13

// Different coding 
// in 2016 Received a raise at work: _11
// in 2020 Received a raise at work: _12

// in 2016 but not 2020
// Been issued a traffic ticket: _8 


// Note in 2016, these are life in the past four years 

* CC20_305_1 CC20_305_2 CC20_305_3 CC20_305_4 CC20_305_5 CC20_305_6 CC20_305_7 CC20_305_9 CC20_305_10 CC20_305_11 CC20_305_12 CC20_305_13

* 2020: 	married1 	lostjob1 	grad1 	retired1 	div1 	child1 /// 
*			newjob1 	victim1 	er1 	
* 			doctor1 	raise1 		paycut1 

* 2016: 	married1 	lostjob1 	grad1 	retired1 	div1 	child1 /// 
*			newjob1 	victim1 	er1 	
*			tick4		  

 //  CC20_305_1 married1
 //  CC20_305_2 lostjob1
 //  CC20_305_3 grad1
 //  CC20_305_4 retired1
 //  CC20_305_5 div1
 //  CC20_305_6 child1
 //  CC20_305_7 newjob1
 //  CC20_305_9 victim1
 //  CC20_305_10 er1
 //  CC20_305_11 doctor1
 //  CC20_305_12 raise1
 //  CC20_305_13 paycut1


** Over the past year, have you...(Check all that apply)


recode CC20_305_1 		(1=1 "1.Yes")	(2=0 "0.No"), generate(married1)
recode CC20_305_2 		(1=1 "1.Yes")	(2=0 "0.No"), generate(lostjob1)
recode CC20_305_3 		(1=1 "1.Yes")	(2=0 "0.No"), generate(grad1)
recode CC20_305_4 		(1=1 "1.Yes")	(2=0 "0.No"), generate(retired1)
recode CC20_305_5 		(1=1 "1.Yes")	(2=0 "0.No"), generate(div1)
recode CC20_305_6 		(1=1 "1.Yes")	(2=0 "0.No"), generate(child1)
recode CC20_305_7 		(1=1 "1.Yes")	(2=0 "0.No"), generate(newjob1)
recode CC20_305_9 		(1=1 "1.Yes")	(2=0 "0.No"), generate(victim1)
recode CC20_305_10 		(1=1 "1.Yes")	(2=0 "0.No"), generate(er1)
recode CC20_305_11 		(1=1 "1.Yes")	(2=0 "0.No"), generate(doctor1)
recode CC20_305_12 		(1=1 "1.Yes")	(2=0 "0.No"), generate(raise1)
recode CC20_305_13 		(1=1 "1.Yes")	(2=0 "0.No"), generate(paycut1)

label var married1 "Married"
label var lostjob1 "Lost job"
label var grad1 "Graduated"
label var retired1 "Retired"
label var div1 "Divorced"
label var child1 "Had child"
label var newjob1 "New job"
label var victim1 "Victim of crime"
label var er1 "ER"
label var raise1 "Raise"
label var doctor1 "Been to doctor"
label var paycut1 "Pay cut"

note married1: "Last year: Married"
note lostjob1: "Last year: Lost a job"
note grad1: "Last year: Finished school"
note retired1: "Last year: Retired"
note div1: "Last year: Divorced"
note child1: "Last year: Had a child"
note newjob1: "Last year: Taken a new job"
note victim1: "Last year: Been a victim of a crime"
note er1: "Last year: Visited an emergency room"
note raise1: "Last year: Received a raise at work"
note doctor1: "Last year: Visited a doctor"
note paycut1: "Last year: Received a pay cut at work"

*****************************************************************
* Ease of handling an emergency $400 expense *
*****************************************************************
	* varnames: ease400_exp; ease400_exp01	
	* CC20_309dx_1 CC20_309dx_2 CC20_309dx_3 CC20_309dx_4 CC20_309dx_5 CC20_309dx_6 CC20_309dx_7 CC20_309dx_8 CC20_309dx_9

* Note that this is a Guttman style coding, where richies are coded first, but if they 
* admit that it is slightly more difficult than they say right away, they are coded
* as having more difficulty 


//// Question wording: 
* Suppose that you have an emergency expense that costs $400. 
* Based on your current financial situation, how would you pay for this expense? 
* If you would use more than one method to cover this expense, please select all that apply.

* CC20_309dx_#
* _1 Put it on my credit card and pay it off in full at the next statement 
* _3 With the money currently in my checking/savings account or with cash 

* _2 Put it on my credit card and pay it off over time 
* _4 Using money from a bank loan or line of credit 
* _5 By borrowing from a friend or family member 

* _6 Using a payday loan, deposit advance, or overdraft 
* _7 By selling something 
* _8 I wouldn't be able to pay for the expense right now 
* _9 Other 





gen ease400_exp = 3 if 			CC20_309dx_3 == 1 |  CC20_309dx_1 == 1
replace ease400_exp = 2 if  	CC20_309dx_2 == 1 |  CC20_309dx_4 == 1 | CC20_309dx_5 == 1
replace ease400_exp = 1 if 	(	CC20_309dx_8 == 1 | CC20_309dx_6 == 1 |  CC20_309dx_7 == 1 | CC20_309dx_9==1 )

label define ease400_exp	 	1 "Cannot pay $400"								///
								2 "Pay off $400 over time or borrow"			/// 
								3 "Has $400" , replace

recode ease400_exp 	(1=0 "Cannot pay $400") /// 
					(2 = .5 ) /// 
					(3=1 "Has $400") , gen (ease400_exp01) 

note ease400_exp: "$400 emergency 1 = easy, .5 = over time; borrow friend/fam 0 = cannot or payday loan"
label var ease400_exp "Ease to pay $400 emergency"
note ease400_exp01: "$400 emergency 1 = easy, .5 = over time; borrow friend/fam 0 = cannot or payday loan"
label var ease400_exp01 "Ease to pay $400 emergency"



*****************************************************************
* COVID work instability *
*****************************************************************

	* varnames: cov_work_instab; cov_work_instab2; cov_work_instab01; cov_work_instab201
// cov_work_instab is coded -1 if they were initially retired or not workign when COVID began 
// it must be used with cov_work_m 									
// cov_work_instab2 is coded 0 if no change regardless of employment status  
								
* This is a Guttman style coding cov_work
* Since "not working when pandemic began" technically is the same, this is coded the same as ///
* "nothing about my work has changed" but we can create a dummy for not working 

* drop cov_work_instab cov_work_instab2
gen cov_work_instab2 = .
* CC20_309c_7 I was not working when the pandemic began							//	194									
* CC20_309c_10 No, nothing about my work has changed							//	467				
replace cov_work_instab2 = 0 if (	CC20_309c_10 	==1 	|					/// no change OR
									CC20_309c_7		==1 		)				/// no change; not working 

replace cov_work_instab2 = 1 if 	CC20_309c_1		==1		| 					/// hours reduced 
									CC20_309c_2 	==1 	| 					/// hours reduced and restored   
									CC20_309c_4		==1 	|					/// laid off, rehired
									CC20_309c_5		==1		|		 			/// employ decreased  
									CC20_309c_8		==1		|					/// hours increased
									CC20_309c_9 	==1 						// 	employ increased


// The logic of this being next is that if COVID had an impact on part of their employment, 
// and it is not restored 
// they are coded higher on the scale. 
// 2 is for when hours are reduced OR lost one of many jobs lost OR 
// lost a job but gained in some hours or took on additional jobs 									
// CC20_309c_1 AND NOT CC20_309c_2
// CC20_309c_1 AND NOT CC20_309c_8 or CC20_309c_9
// CC20_309c_5 AND NOT CC20_309c_8 or CC20_309c_9
// CC20_309c_3 OR CC20_309c_6 AND CC20_309c_8 or CC20_309c_9

replace cov_work_instab2 = 2 if (	CC20_309c_1		==1 	& 					/// hours reduced AND
									CC20_309c_2		==2			) 				/// not restored 
																				///
											|									/// OR
																				///							
								((	CC20_309c_1 	==1 		) 				/// hours reduced  
											&									/// AND
								(	CC20_309c_8		==2 	|					/// hours NOT increased 
									CC20_309c_9		==2			))	 			/// jobs NOT increased  	
																				///
											|									/// OR
																				///							
								((	CC20_309c_5 	==1 		) 				/// lost partial employment    
											&									/// AND
								(	CC20_309c_8		==2 	|					/// hours NOT increased 
									CC20_309c_9		==2			))	 			/// jobs NOT increased  
																				///
											|									/// OR
																				///							
								((	CC20_309c_3		==1 	|					/// temp job loss OR
									CC20_309c_6 	==1			)				/// lost job
											&									/// AND
								(	CC20_309c_8		==1 	|					/// hours increased OR more jobs
									CC20_309c_9		==1			))	
									
// The logic of this being next is that if COVID had an impact on all of their employment, 
// and it is not restored 
// they are coded higher on the scale. 
// 3 is for job is entirely lost and not restored at all, including no additional employment or hours 
// lost a job but gained in some hours or took on additional jobs 									

// CC20_309c_3 OR CC20_309c_6 AND NOT CC20_309c_8 or CC20_309c_9 or CC20_309c_4

replace cov_work_instab2 = 3 if (	CC20_309c_3		==1 	|					/// temp job loss OR
									CC20_309c_6 	==1			)				/// lost job
																				///
											&									/// AND
																				///							
								(	CC20_309c_4		==2	 	|					/// job NOT restored OR
									CC20_309c_8		==2 	|					/// hours or jobs NOT increased 
									CC20_309c_9		==2			)		 			

									

									
* Based on entries to "employ" ; note that it is the "IF" that makes this variable relevant for anyone
* whose work changed at all - in case they decided to retire or go back to school becasue of COVID 

replace cov_work_instab2 = 0 if (cov_work_instab2 ==. & (employ == 1 | employ == 5 | employ == 6)) 

clonevar  cov_work_instab = cov_work_instab2
replace cov_work_instab = -1 if cov_work_instab2 == 0 & (employ>4) 
// note that covid instab must be missing OR they were not coded higher than 0
// so if they retired or something as a result of COVID, they would be coded as that first and THEN coded as not relevant 

* Dummy for not working when COVID began. Notice that if they said retired but also listed anything else 
* work related like changed hours or lost a job, they were coded in the other categories 
gen cov_work_m = 0 
replace cov_work_m = 1 if cov_work_instab == -1


* CC20_309c_#	
	
* CC20_309c_1 My hours have been reduced										// 	177
* CC20_309c_2 My hours were reduced, but they have been restored				// 	62						
* CC20_309c_4 I was temporarily laid off but have now been re-hired				// 	33						
* CC20_309c_5 I had more than one job before the pandemic, and lost one of them //	24									

* CC20_309c_8 My hours have increased											//	49
* CC20_309c_9 I have taken additional jobs since the pandemic					//	26					


* CC20_309c_3 I have been temporarily laid off									//	46	
* CC20_309c_6 I lost my job														//	61
* CC20_309c_7 I was not working when the pandemic began							// 194
													



label define cov_work_instab2 	0 "No change"									/// 
								1 "Fluctuation"									///
								2 "Partial job loss"							/// 
								3 "Lost job" , replace


label define cov_work_instab   -1 "Retired, disabled, home, student"			/// 
								0 "No change"									///  
								1 "Fluctuation"									/// 
								2 "Partial job loss"							/// 
								3 "Lost job" , replace
								
label values cov_work_instab cov_work_instab		
label values cov_work_instab2 cov_work_instab2	

note cov_work_instab: Impact of COVID on employment: -1 = already not working; 	///
0= no change; 1=some fluctuation; 2: partial employment loss; 3 = job loss		///

gen cov_work_instab201 = cov_work_instab2/3
gen cov_work_instab01 = cov_work_instab/3 if cov_work_instab>-1
replace cov_work_instab01 = -1 if cov_work_instab == -1

label define cov_work_instab201		 0 "No change"									/// 
									 1 "Lost job" , replace

label define cov_work_instab01		-1 "Retired, disabled, home, student"			/// 
									 0 "No change"									/// 
									 1 "Lost job" , replace
label var cov_work_instab 		"Impact of COVID on employment"
label var cov_work_instab2 		"Impact of COVID on employment"
label var cov_work_instab201 	"Impact of COVID on employment"
label var cov_work_instab01 	"Impact of COVID on employment"

// tab  cov_work_instab cov_work_instab2, miss

//                       |              cov_work_instab2
//       cov_work_instab | No change  Fluctuati  Partial j   Lost job |     Total
// ----------------------+--------------------------------------------+----------
// Retired, disabled, ho |       376          0          0          0 |       376 
//             No change |       283          0          0          0 |       283 
//           Fluctuation |         0        124          0          0 |       124 
//      Partial job loss |         0          0        117          0 |       117 
//              Lost job |         0          0          0        100 |       100 
// ----------------------+--------------------------------------------+----------
//                 Total |       659        124        117        100 |     1,000 





*alpha = .84, not reduced by excluding any item; lowest item-rest is econ_country

*not necessarily the same concept; rest of items meant to be relative deprivation 


**** Attributes of personal life: Political grievance ****


// CUB3B16 CUB3B17 
* ind_dep, out_power1, out_control1, grieve_harm, grieve_problems, invinc_tough

* super_care, invinc_risk, optgen, econ_country, socsen_stranger, ind_dep_r

	 CUB3B01	I am very frustrated because too many people depend on people like me for their own well-being. 
CUB3B02	Other people's misfortunes disturb me a great deal. 
CUB3B03	I sometimes try to understand people better by imagining how things look from their perspective.
emp_concern1, pers_taking1



recode CUB3B01 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(ind_dep)	
generate ind_dep01=ind_dep/6
note ind_dep: I am very frustrated because too many people depend on people like me for their own well-being.
note ind_dep01: I am very frustrated because too many people depend on people like me for their own well-being.


recode CUB3B02 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(emp_concern1)	
generate emp_concern101=emp_concern1/6
note emp_concern1: Pre-treatment: I believe the problems in my life are completely out of my control.
note emp_concern1: Pre-treatment: I believe the problems in my life are completely out of my control.


recode CUB3B03 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(pers_taking1)	
generate pers_taking101=pers_taking1/6
note pers_taking1: I sometimes try to understand people better by imagining how things look from their perspective.
note pers_taking101: I sometimes try to understand people better by imagining how things look from their perspective.



	 egen out1_01 = rowmean (out_control101 out_power101)
label var out1_01 "Pre-treatment: External locus of control"

recode CUB3B04 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(grieve_harm)	
generate grieve_harm01=grieve_harm/6
note grieve_harm: The American political system tends to harm people like me
note grieve_harm01: The American political system tends to harm people like me



recode CUB3B05 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(grieve_problems)	
generate grieve_problems01=grieve_problems/6
note grieve_problems: I believe that the problems in my life are caused by the problems in our political system.
note grieve_problems01: I believe that the problems in my life are caused by the problems in our political system.

egen grieve01 = rowmean (grieve_harm01 grieve_problems01)

label var grieve01 "Political system blame"

recode CUB3B06 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(invinc_tough)	
generate invinc_tough01=invinc_tough/6
note invinc_tough: I believe I am tougher than most people.
note invinc_tough01: I believe I am tougher than most people.





recode CUB3B07 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(super_care)	
generate super_care01=super_care/6
note super_care: I believe that most Americans care very much about what happens to people like me
note super_care01: I believe that most Americans care very much about what happens to people like me

	
	
	


recode CUB3B08 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(invinc_risk)	
generate invinc_risk01=invinc_risk/6
note invinc_risk: I am the kind of person who takes risks that others wouldn't take
note invinc_risk01: I am the kind of person who takes risks that others wouldn't take



recode CUB3B09 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(optgen)	
generate optgen01=optgen/6
note optgen: Generally, I tend to feel very optimistic about my future
note optgen01: Generally, I tend to feel very optimistic about my future



recode CUB3B10 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(econ_country)	
generate econ_country01=econ_country/6
note econ_country: When I think about my financial situation, I feel that my country has left me behind
note econ_country01: When I think about my financial situation, I feel that my country has left me behind



recode CUB3B11 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(socsen_stranger)	
generate socsen_stranger01=socsen_stranger/6
note socsen_stranger: In general, it makes me very upset when I see someone being unkind to a stranger
note socsen_stranger01: In general, it makes me very upset when I see someone being unkind to a stranger



recode CUB3B12 		(1=0 "0.Agree strongly")	(2=1 "1.Agree")  /// 
				(3=2 "2.Agree somewhat")	(4=3 "3.Neither")	 /// 
				(5=4 "4.Disagree somewhat")	(6=5 "5.Disagree")  /// 
				(7=6 "6.Disagree strongly"), generate(ind_dep_r)	
generate ind_dep_r01=ind_dep_r/6
note ind_dep_r: I often find myself worrying because my well-being depends on people who don't care
note ind_dep_r01: I often find myself worrying because my well-being depends on people who don't care



* See self and sense of linked fate
// CUB3B13 CUB3B14 CUB3B15 CUB3B16 
// seeself_race01


clonevar seeself_race =  CUB3B13
clonevar seeself_pol = CUB3B14 
clonevar seeself_class = CUB3B15 
clonevar seeself_country = CUB3B16 


generate seeself_race01 = (seeself_race-1) /6
generate seeself_pol01 = (seeself_pol-1) /6
generate seeself_class01 = (seeself_class- 1) /6
generate seeself_country01 = (seeself_country-1) /6

label define seeself 0 "0.Not at all important to who I am"  1 "1.Extremely important to who I am"
label values seeself_race01 seeself_pol01 seeself_class01 seeself_country01 seeself

label var seeself_race01 "See self: race/ethnicity"
label var seeself_pol01 "See self: politics"
label var seeself_class01 "See self: class"
label var seeself_country01 "See self: my country"


note seeself_race01: Some social categories may be more important to the way you see yourself than others. On a scale from 1-to-7 with 1 being 'Not at all important to who I am,' and 7 being 'extremely important to who I am,' how important are each of the following to the way you see yourself?
note seeself_pol01: Some social categories may be more important to the way you see yourself than others. On a scale from 1-to-7 with 1 being 'Not at all important to who I am,' and 7 being 'extremely important to who I am,' how important are each of the following to the way you see yourself?
note seeself_class01: Some social categories may be more important to the way you see yourself than others. On a scale from 1-to-7 with 1 being 'Not at all important to who I am,' and 7 being 'extremely important to who I am,' how important are each of the following to the way you see yourself?
note seeself_country01: Some social categories may be more important to the way you see yourself than others. On a scale from 1-to-7 with 1 being 'Not at all important to who I am,' and 7 being 'extremely important to who I am,' how important are each of the following to the way you see yourself?










recode CUB3B16 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(grieve_harm)	
generate grieve_harm01=grieve_harm/6
note grieve_harm: The American political system tends to harm people like me
note grieve_harm01: The American political system tends to harm people like me



recode CUB3B16 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(grieve_harm)	
generate grieve_harm01=grieve_harm/6
note grieve_harm: The American political system tends to harm people like me
note grieve_harm01: The American political system tends to harm people like me



recode CUB3B16 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(grieve_harm)	
generate grieve_harm01=grieve_harm/6
note grieve_harm: The American political system tends to harm people like me
note grieve_harm01: The American political system tends to harm people like me



recode CUB3B16 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(grieve_harm)	
generate grieve_harm01=grieve_harm/6
note grieve_harm: The American political system tends to harm people like me
note grieve_harm01: The American political system tends to harm people like me




CUB3B17=C1, CUB3B17=C2, or CUB3B17=C3 


C1 = external
C2 = internal
C3 = control 


* Yay! most people passed the very difficult manipulation check 

gen treat = .
replace treat = 1 if CUB3B18_rand==1
replace treat = 2 if CUB3B18_rand==2
replace treat = 3 if CUB3B18_rand==3

gen manip_check1 = .a if   treat == 1
replace manip_check1 = 1 if CUB3B18_C1_1==1 & CUB3B31_C1_1==1
replace manip_check1 = 1 if CUB3B18_C1_2==1 & CUB3B31_C1_2==1
replace manip_check1 = 1 if CUB3B18_C1_3==1 & CUB3B31_C1_3==1
replace manip_check1 = 1 if CUB3B18_C1_4==1 & CUB3B31_C1_4==1
replace manip_check1 = 1 if CUB3B18_C1_5==1 & CUB3B31_C1_5==1
replace manip_check1 = 1 if CUB3B18_C1_6==1 & CUB3B31_C1_6==1

gen manip_check2 = .b if   treat == 2
replace manip_check2 = 1 if CUB3B18_C2_1==1 & CUB3B31_C2_1==1
replace manip_check2 = 1 if CUB3B18_C2_2==1 & CUB3B31_C2_2==1
replace manip_check2 = 1 if CUB3B18_C2_3==1 & CUB3B31_C2_3==1
replace manip_check2 = 1 if CUB3B18_C2_4==1 & CUB3B31_C2_4==1
replace manip_check2 = 1 if CUB3B18_C2_5==1 & CUB3B31_C2_5==1
replace manip_check2 = 1 if CUB3B18_C2_6==1 & CUB3B31_C2_6==1



gen manip_check3 = .c if   treat == 3
replace manip_check3 = 1 if ((CUB3B18_C3_1==1) & CUB3B31_C3_1==1 | CUB3B31_C3_2==1 )
replace manip_check3 = 1 if ((CUB3B18_C3_2==1) & CUB3B31_C3_3==1  )
replace manip_check3 = 1 if CUB3B18_C3_3==1 
replace manip_check3 = 1 if CUB3B18_C3_4==1 
replace manip_check3 = 1 if CUB3B31_C3_5==1 & CUB3B31_C3_6==1  
replace manip_check3 = 1 if CUB3B18_C3_6==1 & CUB3B31_C3_5==1




* Well this fucking sucks. C3 manipulation check was not the same 






recode CUB3B19 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(cov_threat)	
generate cov_threat01=cov_threat/6
note cov_threat: I believe that the novel coronavirus (Covid-19) poses a threat to the health and safety of myself and my family
note cov_threat01: I believe that the novel coronavirus (Covid-19) poses a threat to the health and safety of myself and my family

recode CUB3B20 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(cov_action)	
generate cov_action01=cov_action/6
note cov_action: People should take precautions to prevent the spread of Covid-19
note cov_action01: People should take precautions to prevent the spread of Covid-19

recode CUB3B21 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(violpol_dem)	
generate violpol_dem01=violpol_dem/6
note violpol_dem: It is sometimes acceptable for police officers to use physical force to control non-violent demonstrations

note violpol_dem01: It is sometimes acceptable for police officers to use physical force to control non-violent demonstrations


recode CUB3B22 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(violpol_handcuff)	
generate violpol_handcuff01=violpol_handcuff/6
note violpol_handcuff: It is sometimes acceptable for police officers to use physical force against a handcuffed offender

note violpol_handcuff01: It is sometimes acceptable for police officers to use physical force against a handcuffed offender

egen violpol01 = rowmean (violpol_dem01 violpol_handcuff01)

label var violpol01 "Support for police violence"


recode CUB3B23 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(violvig_crim)	
generate violvig_crim01=violvig_crim/6
note violvig_crim: It is all right for members of the public to beat up criminals

note violvig_crim01: It is all right for members of the public to beat up criminals


recode CUB3B24 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(violvig_hands)	
generate violvig_hands01=violvig_hands/6
note violvig_hands: It is sometimes acceptable for people to take the law into their own hands, even if they become violent

note violvig_hands01: It is sometimes acceptable for people to take the law into their own hands, even if they become violent

egen violvig01 = rowmean (violvig_crim01 violvig_hands01)

label var violvig01 "Support for vigilante violence"




absrol_bend, absrol_obey, violprot_unjust, violprot_auth, out_power2, out_control2
Variable Label

Please randomize the order that the row items are asked.  
Any special instructions for programmers

ROWS:
CUB3B25	Sometimes it is necessary to bend the law to deal with social problems.
CUB3B26	It is not necessary to obey a law you consider unjust.
CUB3B27	Sometimes it is understandable that people get violent when they protest against injustice.
CUB3B28	It is sometimes acceptable to encourage violence against authorities who harm innocent people.
CUB3B29	I feel like what happens in my life is mostly determined by people with all the power. 
CUB3B30	I believe the problems in my life are completely out of my control.




recode CUB3B25 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(absrol_bend)	
generate absrol_bend01=absrol_bend/6
note absrol_bend: Sometimes it is necessary to bend the law to deal with social problems

note absrol_bend01: Sometimes it is necessary to bend the law to deal with social problems


recode CUB3B26 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(absrol_obey)	
generate absrol_obey01=absrol_obey/6
note absrol_obey: It is not necessary to obey a law you consider unjust

note absrol_obey01: It is not necessary to obey a law you consider unjust


recode CUB3B27 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(violprot_unjust)	
generate violprot_unjust01=violprot_unjust/6
note violprot_unjust: Sometimes it is understandable that people get violent when they protest against injustice

note violprot_unjust01: Sometimes it is understandable that people get violent when they protest against injustice


recode CUB3B28 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(violprot_auth)	
generate violprot_auth01=violprot_auth/6
note violprot_auth: It is sometimes acceptable to encourage violence against authorities who harm innocent people

note violprot_auth01: It is sometimes acceptable to encourage violence against authorities who harm innocent people

recode CUB3B29 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(out_power2)	
generate out_power201=out_power2/6
note out_power2: Pre-treatment: I feel like what happens in my life is mostly determined by people with all the power.
note out_power201: Pre-treatment: I feel like what happens in my life is mostly determined by people with all the power.



recode CUB3B30 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(out_control2)	
generate out_control201=out_control2/6
note out_control2: Pre-treatment: I believe the problems in my life are completely out of my control.
note out_control201: Pre-treatment: I believe the problems in my life are completely out of my control.

	 egen out2_01 = rowmean (out_control201 out_power201)
label var out2_01 "Post-treatment: External locus of control"

gen more_ext = out2_01-out1_01


* Pearson r = .46




egen fin_cond01 = rowmean (income01 ease400_exp01 )
egen econ_anxiety01 = rowmean ( econ_expect01 econ_friends01 econ_country01 	econ_worry01)
egen econ_rel_dep01 = rowmean ( econ_expect01 econ_friends01  					econ_worry01)

alpha econ_expect01 econ_friends01 econ_country01 econ_worry01, item


*****************************************************************
* Health: general health and COVID related items *
* (not attitudes, but circumstances) *
*****************************************************************


*****************************************************************
* Health: general health *
*****************************************************************
// CC20_309e
	* varnames: genhealth01; genhealth01	

	* Would you say that in general your health is...
recode CC20_309e (1=4 "Excellent") (2=3 "Very good") (3=2 "Good") (4=1 "Fair") (5=0 "Poor"), generate(genhealth)
gen genhealth01 = genhealth/4

label var genhealth01 "Subjective sense of health"


*****************************************************************
* COVID-19 closeness with someone with COVID, died of COVID *
*****************************************************************
		*varnames: covid_close covid_close01 covid_close_sev covid_close_sev01*

	// "Have you or someone you know been diagnosed with the novel coronavirus (COVID-19) during the past year?" closeness to COVID 19

* CC20_309b CC20_309a_1 CC20_309a_2 CC20_309a_3 CC20_309a_4 CC20_309a_5 
		// CUB3S16 has acquaintances with COVID 
		// got COVID or know someone who did
		// family member coded as closer than friend or coworker

* Note that this is a Guttman style coding, where knowing no one is  coded first, but if they 
* admit that they know someone in CUB3S16, they are coded as being higher in familiarity as they know the person better
* with themselves having had it coded the highest  
		// family member coded as closer than friend or coworker


gen covid_close = 0 if  CC20_309a_5 == 1 & CUB3S16 < 2 							// knows no one and answers that way for CUB3S16
replace covid_close = 1 if  (CC20_309a_4 == 1 | CC20_309a_3 == 1 | CUB3S16 > 1)	// knows someone: friends, coworkers, or acquaintances
replace covid_close = 2 if  (CC20_309a_2 == 1 )									// family member got COVID-19
replace covid_close = 3 if  (CC20_309a_1 == 1 )


label define covid_close		0 "Know no one"									///
								1 "Friend/coworker"								/// 
								2 "Family member" 								/// 
								3 "R got COVID", replace
 
gen covid_close01 = covid_close/3
label define covid_close01		0 "Know no one"									///
								1 "R got COVID", replace 
label var  	covid_close 	"Closeness to someone who got COVID" 
label var 	covid_close01  	"Closeness to someone who got COVID" 
label values 	covid_close 	covid_close
label values 	covid_close01 	covid_close01
tab covid_close01

* CC20_309b_#
* Do you anyone who died from the novel coronavirus 
* only asked if they say they knew someone with COVID


*varname: covid_close_sev *
		// died from COVID or know someone who did
		// family member coded as having more impact than friend or family member who died
		// CC20_309b_1 CC20_309b_2 CC20_309b_3 CC20_309b_4 		
gen covid_close_sev = 0
replace covid_close_sev = 1 if covid_close > 0									// anyone got COVID, including self
replace covid_close_sev = 2 if (CC20_309b_2 ==1 | CC20_309b_3 ==1) 				// anyone died from COVID
replace covid_close_sev = 3 if CC20_309b_1 ==1									// family member died 


label define covid_close_sev 	0 "Know no one" 								///
								1 "Knows someone or got COVID" 					/// 
								2 "Knows someone who died" 						/// 
								3 "Family member died" , replace 
	
gen covid_close_sev01 = 	covid_close_sev/3
label define covid_close_sev01 	0 "Know no one" 								///
								1 "Family member died" , replace 

label var covid_close_sev 	"The severity of impact of COVID: closeness with those who had it or died"
label var covid_close_sev01 "The severity of impact of COVID: closeness with those who had it or died"
label values covid_close_sev covid_close_sev
label values covid_close_sev01 covid_close_sev01

tab covid_close_sev covid_close







*****************************************************************
* Party id, ideology *
*****************************************************************

// ideo5; conserv01; CC20_340a conserv_self01; ideolog01; mod01; 
// pid7 rep01; republican_7cat; partisan_4cat; partisan01

* ;   

// Not in 2016: dem_therm CUB3B46 rep_therm CUB3B47


* Political Ideology * 
	* varname: conserv01*
recode ideo5 	(1=0 "0.Very liberal")		(2=1 "1.Liberal")  /// 
				(3=2 "2.Moderate")			(4=3 "3.Conservative")	 /// 
				(5=4 "4.Very conservative")	(6=2 "2.Not sure") , generate(conservative_5cat) 
note conservative_5cat: R's Political ideology: (Not sure=Moderate)
label var conservative_5cat "Cons. ideology"

generate conserv01=conservative_5cat/4
note conserv01: "R's Political ideology: (Not sure=Moderate)
label var conserv01 "Cons. ideology"

*Strength of Ideology*
recode ideo5 	(1 	5 = 2 "Strong ideologue")	(2 4 =1 "1.Not very strong ideologue")	 /// 
				(3 6 4 8=0 "0.Moderate / none")	, generate(ideolog_3cat)
label var ideolog_3cat "Strength of ideology"
generate ideolog01 = ideolog_3cat/2	
note ideolog01: Strength of political ideology (3 categories) (0 to 1)
label var ideolog01 "Strength of ideology"

* Ideology * 
* varname: conserv_self01*
	// ideology - yourself
recode CC20_340a	(1=0 "0.Very Liberal")			(2=1 "1.Liberal")  /// 
					(3=2 "2.Somewhat Liberal")		(4 8=3 "3.Middle/Not sure")  /// 
					(5=4 "4.Somewhat Conservative")	(6=5 "5.Conservative")	 /// 
					(7=6 "6.Very Conservative"), generate(conserv_self)
label var conserv_self "Ideology - self"
generate conserv_self01=conserv_self/6
note conserv_self01: Ideology – self rating 
label var conserv_self01 "Ideology - self"

generate mod01 = 0
replace mod01 = 1 if (conserv_self01 > .32 & conserv_self01 < .67) & (conserv01 > .22 & conserv01 < .78) 
label var mod01 "Moderate"



* Party Identification * 
* varname: rep01*
recode pid7 	(1=0 "0.Strong Democrat")	(2=1 "1.Not very strong Democrat")  /// 
				(3=2 "2.Lean Democrat")		(4=3 "3.Independent")	 /// 
				(5=4 "4.Lean Republican")	(6=5 "5.Not very strong Republican")  /// 
				(7=6 "6.Strong Republican") (8=3 "3.Not sure"), generate(republican_7cat)
note republican_7cat: R's Party identification: (Not sure=Independent)
label var republican_7cat "Party identification: Rep. high (Not sure=Independent)"

generate rep01=republican_7cat/6
note rep01: Party ID (0=Democrat...0.5=Independent...1=Republican)"
label var rep01 "Rep. party ID"

*Strength of Partisanship*
* varname: partisan_4cat01; partisan_3cat01*
recode pid7 	(1 	7=3 "3.Strong D or R")	(2 6=2 "2.Not very strong D or R")	 /// 
				(3 5=1 "1.Lean D or R")		(4 8=0 "0.Independent or Not sure"), generate(partisan_4cat)
note partisan_4cat: Strength of partisanship: 4 categories
label var partisan_4cat "Partisanship"

generate partisan01=partisan_4cat/3
note partisan01: Strength of partisanship: 4 categories
label var partisan01 "Partisanship"

// Thermostat of party 
clonevar dem_therm = CUB3B46 
clonevar rep_therm = CUB3B47 		
	
* dem_therm CUB3B46 
* rep_therm CUB3B47	
	
generate dem_therm01 = 	dem_therm/100
generate rep_therm01 = 	rep_therm/100
gen demlikerep = rep_therm01 if rep01 < .5
gen replikedem = dem_therm01 if rep01 > .5
egen indlikeboth = rowmean (rep_therm01 dem_therm01 ) if rep01 == .5

gen demhate01 = (demlikerep*-1) + 1
gen rephate01 = (replikedem*-1) + 1
gen indhate01  = (indlikeboth*-1) + 1

egen hate_opp_party01  = rowmean (demhate01   rephate01 indhate01) 


* keep	conserv01	conserv_self01	ideolog01	mod01	rep01		partisan01	

* order	conserv01	conserv_self01	ideolog01	mod01	rep01		partisan01, after (raise4)


*****************************************************************
* Political engagement: media, interest, konwledge *
*****************************************************************

// newsint pol_interest01 votereg registered
// CC20_310a knows_control01 CC20_310b knows_control01; media_div01; social_media01
// print_online; locnat; watch_read01; ideo_dk01 ; ideo_know01

// CC20_310a CC20_310b newsint CC20_340a CC20_340a - CC20_340m 
// CC20_300d_1 - CC20_300d_5  CC20_300a CC20_300c
* Political Knowledge * 
recode CC20_310a	(2=1 "1.Knows Democrats control the House")	 /// 
					(2/4=0), generate(knows_house)
label var knows_house "R knows Republicans control House"
recode CC20_310b	(1=1 "1.Knows Republicans control the Senate")  /// 
					(2/4=0), generate(knows_senate)
label var knows_senate "R knows Republicans control Senate"
generate knows_control = knows_house + knows_senate
label var knows_control "R knows party control Congress"
generate knows_control01=knows_control/2
note knows_control01 : R knows Republicans control Congress (0 to 1)
label var knows_control01 "Knowledge: party control of Congress"





* ideological knowledge "don't know"coded in the middle here * 

gen ideo_dk01 = 0
replace ideo_dk01 = 1 if CC20_340a == 8
note ideo_dk01: Don't know one's own ideology 
label variable  ideo_dk01 "Ideological innocence"

* Knowledge of ideology of representatives and candidates 


foreach v of varlist CC20_340a - CC20_340m {
    gen `v'_know = 1 
  } 
  
  
foreach v of varlist CC20_340a - CC20_340m {
    replace `v'_know = 0 if `v' ==8
  } 
  
	// I am creatging a measure of political sophistication out of 
	// don't knows about ideology of actors ,

global ideo_know_vars CC20_340a_know  CC20_340b_know  CC20_340c_know  CC20_340d_know  CC20_340e_know  CC20_340f_know  CC20_340g_know  CC20_340h_know  CC20_340i_know  CC20_340j_know  CC20_340k_know  CC20_340l_know  CC20_340m_know



* Construction of mean index* 
egen ideo_know01 = rowmean ($ideo_know_vars )

macro drop ideo_know_vars
drop CC20_340a_know  CC20_340b_know  CC20_340c_know  CC20_340d_know  CC20_340e_know  CC20_340f_know  CC20_340g_know  CC20_340h_know  CC20_340i_know  CC20_340j_know  CC20_340k_know  CC20_340l_know  CC20_340m_know


label var ideo_know01 "Knowledge: Ideology of representatives and candidates"
note ideo_know01 : Political sophistication: not saying dk on ideology vars cc20_340a-m"



* Political Interest * 
* varname: pol_interest01*
recode newsint 		(1=3 "3.Mostly")	(2=2 "2.Sometime")	(3=1 "1.Only now and then") /// 
					(4 7=0 "0.Hardly at all/Don't know"), generate(pol_interest)
label var pol_interest "How often does R follow politics? (Don't know = Hardly at all)"
generate pol_interest01=pol_interest/3
note pol_interest01: How often does R follow politics? (Don't know = Hardly at all)
label var pol_interest01 "Pol. interest"


* Media and News Questions * 

// in 2016, not in 2020: media_blog

* Media Use * 
recode CC20_300_1 	(1=1 "1.Yes")	(2=0 "0.No"), generate(media_social)
recode CC20_300_2 	(1=1 "1.Yes")	(2=0 "0.No"), generate(media_tv)
recode CC20_300_3 	(1=1 "1.Yes")	(2=0 "0.No"), generate(media_newspaper)
recode CC20_300_4 	(1=1 "1.Yes")	(2=0 "0.No"), generate(media_radio)
recode CC20_300_5 	(1=1 "1.Yes")	(2=0 "0.No"), generate(media_none)


* Construction of mean index* 
egen news_types01 = rowmean ( media_tv media_newspaper media_radio media_social)
replace news_types01 = 0 if  (media_none==1 | news_types01==0) 

label var news_types01 "Count of types of media R uses/consumes"
note news_types01: Types of media: tv, paper, radio, social
label var news_types01 "Num. news media types"


* Social Media Activity * 
recode CC20_300d_1 (1=1 "1.Yes")	(2=0 "0.No"), generate(social_1)
label var social_1 "Posted a story, photo, video or link about politics"
recode CC20_300d_2 (1=1 "1.Yes")	(2=0 "0.No"), generate(social_2)
label var social_2 "Posted a comment about politics"
recode CC20_300d_3 (1=1 "1.Yes")	(2=0 "0.No"), generate(social_3)
label var social_3 "Read a story or watched a video about politics"
recode CC20_300d_4 (1=1 "1.Yes")	(2=0 "0.No"), generate(social_4)
label var social_4 "Followed a political event"
recode CC20_300d_5 (1=1 "1.Yes")	(2=0 "0.No"), generate(social_5)
label var social_5 "Forwarded a story, photo, video or link about politics to friends"


* Construction of mean index* 
egen active_on_social_media = rowtotal (social_1 social_2 social_3 social_4 social_5)
label var active_on_social_media "How active is R on social media?"


* Construction of mean index* 
egen social_media_totals = rowtotal (social_1 social_2 social_3 social_4 social_5)
gen socmed16 = social_media_totals+1
gen socmed06 = socmed16
replace socmed06 = 0 if  CC20_300_1==2 // 0 = no social media; 1 = no reported political activities in CC20_300d_1 - CC20_300d_5
gen social_media01 = socmed06/6

note social_media01: 	Num. social media political activities; ///
						socmed06: 0 = no social media; 1 = no reported political activities in CC20_300d_1 - CC20_300d_5 
label var social_media01 "Politics on social media"


	// There are respondents who answered "No" to all social media questions,
	// but said they did read social media for politics, so they are coded as 1
	// those with a 0 answered no on CC20_300_5 



* News Consumer * 
recode CC20_300a	(1/2=1 "1.Either local or national news")  /// 
					(3=2 "2.Both local and national news")	 /// 
					(.a .b = 0 "Neither"), generate(locnat)
note locnat: Only post: 0=does not watch news; 1=watches either local or national; 2=watches both
label var locnat "Watch nat and local news"

recode CC20_300c	(1/2=1 "1.Either print or online news")  /// 
					(3=2 "2.Both print and online news")	 /// 
					(.a .b = 0 "Neither"), generate(print_online)
note print_online: 0=does not read news; 1=reads either print or online; 2=reads both
label var print_online "Reads print and online news"

egen watch_read=rowtotal (locnat print_online)
note watch_read: Watches local and national; reads print and online 
label var watch_read "News types"
generate watch_read01= watch_read /4
note watch_read01: High = watches local and national; reads print and online
label var watch_read01 "Watch loc and nat; reads print and online"
	**News Consumer: Alternative Coding * 
generate newslocal=0
replace newslocal=1 if CC20_300a==1 | CC20_300a==3
	label var newslocal "R watches local news"
generate newsnat=0
replace newsnat = 1 if CC20_300a==2 | CC20_300a==3
	label var newsnat "R watches national news"
generate newsprint=0
replace newsprint=1 if CC20_300c==1 | CC20_300c==3
	label var newsprint "Reads a print version of a newspaper"
generate newsonline=0
replace newsonline=1 if CC20_300c==2 | CC20_300c==3
label var newsonline "Reads an online version of a newspaper"
 

* Construction of mean index* 
egen  news_var01 = rowmean (newslocal newsnat newsprint newsonline social_media01)
note news_var01: Alternative measure of news diversity: print/online AND local and national tv 
label var news_var01 "News formats: print/online AND local / national tv AND social media"

* order	pol_interest01	registered		knows_control01		news_var01	 /// 
		social_media01 	print_online	locnat				watch_read01	 /// 
		ideo_dk01 		ideo_know01 	news_types01, after (partisan01)
* keep	pol_interest01	registered		knows_control01		news_var01	 /// 
		social_media01 	print_online	locnat				watch_read01	 /// 
		ideo_dk01 		ideo_know01 	news_types01, after (partisan01)

		
		
********************************************************************************
*                                 Network TV news                               
********************************************************************************
//  CC20_300b_1 CC20_300b_2 CC20_300b_3 CC20_300b_4 CC20_300b_5 CC20_300b_6 CC20_300b_7 CC20_300b_8
// media_abc01 media_cbs01 media_cnn01 media_fox01 media_msnbc01 media_nbc01 media_other media_pbs01
// media_network01 media_pbs_msnbc01 media_tv_div01 

***Media TV network diversity ***
//media_network01; media_pbs_msnbc01; media_fox01 media_tv_div01; 
	
	**Which TV news network watched **
		* This is only if CC20_300_2 == 1
			// over the past year the nation's economy has...?

recode CC20_300b_1      (1=1 "Yes") (2=0 "No"), generate(media_abc01) 
recode CC20_300b_2      (1=1 "Yes") (2=0 "No"), generate(media_cbs01) 
recode CC20_300b_3      (1=1 "Yes") (2=0 "No"), generate(media_nbc01) 
recode CC20_300b_4      (1=1 "Yes") (2=0 "No"), generate(media_cnn01) 
recode CC20_300b_5      (1=1 "Yes") (2=0 "No"), generate(media_fox01) 
recode CC20_300b_6      (1=1 "Yes") (2=0 "No"), generate(media_msnbc01) 
recode CC20_300b_7      (1=1 "Yes") (2=0 "No"), generate(media_pbs01) 
recode CC20_300b_8      (1=1 "Yes") (2=0 "No"), generate(media_other) 

replace media_abc01 =0 if CC20_300_2 ==2
replace media_cbs01 =0 if CC20_300_2 ==2
replace media_nbc01 =0 if CC20_300_2 ==2
replace media_cnn01 =0 if CC20_300_2 ==2
replace media_fox01 =0 if CC20_300_2 ==2
replace media_msnbc01 =0 if CC20_300_2 ==2
replace media_pbs01 =0 if CC20_300_2 ==2

egen media_network01 = rowmean (media_abc01 media_cbs01 media_nbc01)
egen media_pbs_msnbc01 = rowmean (media_pbs01 media_msnbc01) 

egen media_tv_div01 = rowmean (media_network01 media_pbs_msnbc01 media_fox01)
replace media_tv_div01 = 0 if CC20_300_2 == 2


*****************************************************************
* Political engagement: participation *
*****************************************************************

// votereg registered CC20_401 presvote16post  presvote16post vote_trump_2016_20 voted_2016_20 CC20_410 vote_trump_20 CC20_410 voted_2020_20 CC20_430a_1 - CC20_430a_6 pol_part01 CC20_430a_1 - CC20_430a_6 pol_part_comp1620_01
//  
// CC20_363 CC20_364a CC20_364b  

* Voter Registration Status * 
* varname: registered*
	// Are you registered to vote?
recode votereg 	(1=1 "1.Yes")	(2 3 = 0 "No/Don't Know"), generate(registered)
note registered: Are you registered to vote? (0 = No; 1 = Yes)"
label var registered "Registered to vote"

*** voting **** 



* Voted in 2016**
	* varname: voted_2016*
recode presvote16post 		(7=0 "0.Did not vote/Not sure")	(1/6=1 "1.Voted in 2016"), generate(voted_2016_20)
label var voted_2016_20 "Did R Vote in 2016? (0=no; 1=yes)"

* Voted in 2020**
	* varname: voted_2020*
recode CC20_401 		(1/4=0 "0.Did not vote")	 /// 
			(5=1 "1.Voted"), generate(voted_2020_20)
label var voted_2020_20 "Did R Vote in 2016? (0=no; 1=yes)"

* Presidential Vote Choice in 2020**
	* varname: vote_trump*
recode CC20_410	(2=1 "1.Trump")	(1=0 "0.Biden")	 /// 
			(3/8=.a "Other"), generate(vote_trump_20)
label var vote_trump_20 "Vote for Trump in 2020"



recode presvote16post (2=1 "1.Trump")	(1=0 "0.Clinton")	 /// 
			(3/8=.a "Other"), generate(vote_trump_2016_20)
label var vote_trump_2016_20 "Vote for Trump in 2016"

gen vote_same = .
replace vote_same = 1 if (vote_trump_2016_20==1 & vote_trump_20==1)
replace vote_same = 1 if (vote_trump_2016_20==0 & vote_trump_20==0)
replace vote_same = 2 if (vote_trump_2016_20==0 & vote_trump_20==1)
replace vote_same = 3 if (vote_trump_2016_20==1 & vote_trump_20==0)
replace vote_same = 4 if ((presvote16post>2 & presvote16post<7) & vote_trump_20==1)
replace vote_same = 5 if ((presvote16post>2 & presvote16post<7) & vote_trump_20==0)
replace vote_same = 6 if presvote16post==7  & vote_trump_20==1
replace vote_same = 7 if presvote16post==7  & vote_trump_20==0
replace vote_same = 8 if vote_trump_2016_20==1 &  CC20_410==4
replace vote_same = 9 if vote_trump_2016_20==0 &  CC20_410==4

label define vote_same 	1 "1.Same vote 2016, 2020" ///
						2 "2.Dem to Rep" ///
						3 "3.Rep to Dem" ///
						4 "4.Other to Rep" ///
						5 "5.Other to Dem" ///
						6 "6.No vote to Rep" ///
						7 "7.No vote to Dem" ///
						8 "8.Rep to no vote" ///
						9 "9.Dem to no vote" 
label values vote_same vote_same 

 tab vote_same

.  tab vote_same

             vote_same |      Freq.     Percent        Cum.
-----------------------+-----------------------------------
1.Same vote 2016, 2020 |        550       75.76       75.76
          2.Dem to Rep |          7        0.96       76.72
          3.Rep to Dem |         13        1.79       78.51
        4.Other to Rep |         18        2.48       80.99
        5.Other to Dem |         29        3.99       84.99
      6.No vote to Rep |         37        5.10       90.08
      7.No vote to Dem |         69        9.50       99.59
      8.Rep to no vote |          2        0.28       99.86
      9.Dem to no vote |          1        0.14      100.00
-----------------------+-----------------------------------
                 Total |        726      100.00


gen more_rep = . 
replace more_rep =  0 if vote_same==3						 
replace more_rep =  1 if vote_same==5 | vote_same==7
replace more_rep =  2 if vote_same==1 | (presvote16post==7 & CC20_410==4)						 
replace more_rep =  3 if vote_same==4 | vote_same==6	
replace more_rep =  4 if vote_same==2						 

label define more_rep 	0 "0.Rep to Dem" ///
						1 "1.Other, no vote to Dem" ///
						2 "2.Same or no vote twice" ///
						3 "3.Other, no vote to Rep" ///
						4 "4.Dem to Rep" 
label values more_rep more_rep 

gen more_dem = . 
replace more_dem =  0 if vote_same==2						 
replace more_dem =  1 if vote_same==4 | vote_same==6
replace more_dem =  2 if vote_same==1 | (presvote16post==7 & CC20_410==4)						 
replace more_dem =  3 if vote_same==5 | vote_same==7
replace more_dem =  4 if vote_same==3						 

label define more_dem 	0 "0.Dem to Rep" ///
						1 "1.Other, no vote to Rep" ///
						2 "2.Same or no vote twice" ///
						3 "3.Other, no vote to Dem" ///
						4 "4.Rep to Dem" 
label values more_dem more_dem 

gen any_change = 1
replace any_change = 0 if vote_same==1 | (presvote16post==7 & CC20_410==4) 

label define any_change 	0 "0.Voted the same or no vote twice" ///
						1 "1.Changed something"

gen more_change = . 
replace more_change =  0 if vote_same==1 | (presvote16post==7 & CC20_410==4) 						 
replace more_change =  1 if vote_same==4 | vote_same==6 | vote_same==5 | vote_same==7
replace more_change =  2 if vote_same==3 | vote_same==2					 

label define more_change 	0 "0.Same or no vote twice" ///
						1 "1.Other, no vote to Rep or Dem" ///
						2 "2.Rep to Dem or Dem to Rep"  
label values more_change more_change 


sum more_dem
gen more_dem01 = ((more_dem- `r(min)') / (`r(max)' - `r(min)')) 

sum more_rep
gen more_rep01 = ((more_rep- `r(min)') / (`r(max)' - `r(min)')) 


sum more_change
gen more_change01 = ((more_change- `r(min)') / (`r(max)' - `r(min)')) 


**** Political participation *****

// ****pol_part01
recode CC20_430a_1 (2=0 "0.No")	(1=1 "1.Yes")  , generate (meet )
recode CC20_430a_2 (2=0 "0.No")	(1=1 "1.Yes")  , generate ( sign )
recode CC20_430a_3 (2=0 "0.No")	(1=1 "1.Yes")  , generate ( work )
recode CC20_430a_6 (2=0 "0.No")	(1=1 "1.Yes")  , generate ( donate)

recode CC20_430a_4 (2=0 "0.No")	(1=1 "1.Yes")  , generate ( protest )
recode CC20_430a_5 (2=0 "0.No")	(1=1 "1.Yes")  , generate ( contact)


// CC20_430a_1  // meet 
// CC20_430a_2  // sign 
// CC20_430a_3  // work  
// CC20_430a_6  // donate  

// CC20_430a_4  // protest  : not in 2016 
// CC20_430a_5  // contact : not in 2016 

* Construction of mean index* 
egen pol_part_comp1620_01 = rowmean (registered voted_2020_20  voted_2016_20 meet sign work donate) 
egen pol_part01 = rowmean (registered voted_2020_20  voted_2016_20 meet sign work donate protest contact ) 
note pol_part_comp1620_01: Political participation, used to compare with 2016: reg, last vote, this vote, meet, sign, work, donate 
note pol_part01: Political participation, with added 2020 items: protest, contact 




*****************************************************************
* Efficacy and government trust *
*****************************************************************





* Pre-election efficacy 
//  CUB3S28 CUB3S29 CUB3S30 CUB3S31 CUB3S32
// effOff 	effSay  	effUnstd_r01 	effUnstd 	effQual		effQual_r01  	effInfmd_r01 effInfmd 
// effPOff effPSay  	effPUnstd_r01	effPUnstd 	effPQual 	effPQual_r01 	effPInfmd_r01 effPInfmd
// exteff exteff01 inteff inteff01 extPeff extPeff01 intPeff inteffP01



clonevar effOff = CUB3S28 
clonevar effSay = CUB3S29 
clonevar effUnstd = CUB3S30 
clonevar effQual = CUB3S31 
clonevar effInfmd = CUB3S32 


label var  effOff  "Public officials don't care much what people like me think"
label var  effSay  "People like me don't have any say about what the government does"
label var  effUnstd  "I feel I understand the most important political issues of this country"
label var  effQual  "I consider myself well-qualified to participate in politics"
label var  effInfmd  "I think that I am better informed about politics and government than most people"


egen exteff  = rowmean (effOff effSay)
gen exteff01 = (exteff - 1)/4

gen effQual_r01 = ((effQual*-1) +5) /4
gen effUnstd_r01 = ((effUnstd*-1) +5) /4
gen effInfmd_r01 = ((effInfmd*-1) +5) /4

egen inteff01  = rowmean ( effQual_r01 effUnstd_r01 effInfmd_r01)
egen inteff  = rowmean ( effQual_r effUnstd_r effInfmd_r)

gen effQual_r = ((effQual*-1) +5) 
gen effUnstd_r = ((effUnstd*-1) +5) 
gen effInfmd_r = ((effInfmd*-1) +5) 

label values effQual_r effUnstd_r effInfmd_r agree5


* Post-election government trust 

// CUB4S07 CUB4S08 CUB4S09 CUB4S10 
// cfFed_r  cfState_r cfLocal_r cfBoard_r trust_gov trust_gov01 

clonevar cfFed = CUB4S07 
clonevar cfState = CUB4S08 
clonevar cfLocal = CUB4S09 
clonevar cfBoard = CUB4S10 

label var  cfFed  "Trust to do what is right: federal government"
label var  cfState  "Trust to do what is right: state government"
label var  cfLocal  "Trust to do what is right: local government"
label var  cfBoard  "Trust to do what is right: local board of elections"

tab cfFed 

recode cfFed ///
	(5=1 "Never") 				(4=2 "Once in a while") ///
	(3=3 "About half the time") (2=4 "Most of the time") /// 
	(1=5 "Always"), generate(cfFed_r)
	tab cfFed_r

 
recode cfState ///
 (5=1 "Never") (4=2 "Once in a while") ///
	(3=3 "About half the time") (2=4 "Most of the time") /// 
	(1=5 "Always"), generate(cfState_r)
	tab cfState_r

 
recode cfLocal ///
 (5=1 "Never") (4=2 "Once in a while") ///
	(3=3 "About half the time") (2=4 "Most of the time") /// 
	(1=5 "Always"), generate(cfLocal_r)
	tab cfLocal_r


recode cfBoard ///
 (5=1 "Never") (4=2 "Once in a while") ///
	(3=3 "About half the time") (2=4 "Most of the time") /// 
	(1=5 "Always"), generate(cfBoard_r)
	tab cfBoard_r

egen trust_gov  = rowmean (cfFed_r  cfState_r cfLocal_r cfBoard_r)
gen trust_gov01 = (trust_gov - 1)/4
tab trust_gov01



*** Efficacy, post-election

clonevar effPOff = CUB4S11 
clonevar effPSay = CUB4S12 
clonevar effPUnstd = CUB4S13 
clonevar effPQual = CUB4S14 
clonevar effPInfmd = CUB4S15 

note  effPOff : Post: Public officials don't care much what people like me think
note  effPSay : Post: People like me don't have any say about what the government does
note   effPUnstd : Post: I feel I understand the most important political issues of this country
note   effPQual : Post: I consider myself well-qualified to participate in politics
note   effPInfmd : Post: I think that I am better informed about politics and government than most people


egen extPeff  = rowmean (effPOff effSay)
gen extPeff01 = (exteff - 1)/4

gen effPQual_r01 = ((effPQual*-1) +5) /4
gen effPUnstd_r01 = ((effPUnstd*-1) +5) /4
gen effPInfmd_r01 = ((effPInfmd*-1) +5) /4

gen effPQual_r = ((effPQual*-1) +5) 
gen effPUnstd_r = ((effPUnstd*-1) +5) 
gen effPInfmd_r = ((effPInfmd*-1) +5) 

egen inteffP01  = rowmean ( effPQual_r01 effPUnstd_r01 effPInfmd_r01)
egen inteffP  = rowmean ( effPQual_r effPUnstd_r effPInfmd_r)





*** Efficacy, indices

label define agree4 4 "Strongly agree" 3 "Agree" 2 "Disagree" 1 "Strongly disagree"
label define agree01 1 "Strongly agree" 0 "Strongly disagree"

label define disagree4 1 "Strongly agree" 2 "Agree" 3 "Disagree" 4 "Strongly disagree"
label define disagree01 0 "Strongly agree" 1 "Strongly disagree"

label define disagree5 1 "Strongly agree" 2 "Agree" 3 "Neutral" 4 "Disagree" 5 "Strongly disagree"
label define agree5 5 "Strongly agree" 4 "Agree" 3 "Neutral" 2 "Disagree" 1 "Strongly disagree"

label define fav_opp4 4  "Strongly favor"  3 "Favor" 2 "Oppose" 1 "Strongly oppose"
label define oppose4 4  "Strongly favor"  3 "Favor" 2 "Oppose" 1 "Strongly oppose"
 

egen exteff_postx  = rowmean (effPOff effPSay)
egen inteff_postx  = rowmean ( effPQual effPInfmd effPUnstd)

gen exteff_post01 = (exteff_postx - 1)/4
gen inteff_post01 = (inteff_postx - 1)/4

corr exteff01 exteff_post01
corr inteff01 inteff_post01

gen ext_change = exteff01 - exteff_post01 





*****************************************************************
* Rule of law variables *
*****************************************************************
  
// CUB3B01 absrol_bend01; CUB3B03 absrol_obey01; CUB3B04 absrol_judge01; abstract_rol06; absrol01
//    
* Dependent Variable: Rule of Law - Abstract Measure * 

* varname: absrol_bend *
	// sometimes it is necessary to bend the law to deal with social problems
recode CUB3B01 	(1=0 "0.Agree strongly")		(2=1 "1.Agree")  /// 
				(3=2 "2.Agree somewhat")		(4=3 "3.Neither")	 /// 
				(5=4 "4.Disagree somewhat")		(6=5 "5.Disagree")  /// 
				(7=6 "6.Disagree strongly"), generate(absrol_bend)
note absrol_bend: Disagree: Sometimes it is necessary to bend the law to deal with social problems
label var absrol_bend "Not bend the law to solve problems"

* varname: absrol_obey *
	// it is not necessary to obey a law you consider unjust
recode CUB3B03 	(1=0 "0.Agree strongly")	(2=1 "1.Agree")  /// 
				(3=2 "2.Agree somewhat")	(4=3 "3.Neither")	 /// 
				(5=4 "4.Disagree somewhat")	(6=5 "5.Disagree")  /// 
				(7=6 "6.Disagree strongly"), generate(absrol_obey)
note absrol_obey: Disagree: It is not necessary to obey a law you consider unjust
label var absrol_obey "Obey unjust law"
* varname: absrol_judge *
	// judges should make decisions based on what they consider right
	// without regard to the law
recode CUB3B04 	(1=0 "0.Agree strongly")	(2=1 "1.Agree")  /// 
				(3=2 "2.Agree somewhat")	(4=3 "3.Neither")	 /// 
				(5=4 "4.Disagree somewhat")	(6=5 "5.Disagree")  /// 
				(7=6 "6.Disagree strongly"), generate(absrol_judge)
note absrol_judge: Judges should make decisions based on what they consider right without regard to the law
label var absrol_judge "Judges should NOT ignore the law"

gen absrol_bend01 = absrol_bend/6
gen absrol_obey01 = absrol_obey/6
gen absrol_judge01 = absrol_judge/6
* Mean Support for Rule of Law in the Abstract * 
	* varname: absrol01*


* Construction of mean index* 
egen abstract_rol06 = rowmean(absrol_bend absrol_obey absrol_judge)
note abstract_rol06: Mean index: support for rule of law in the abstract, 0-6
label var abstract_rol "Support for rule of law in the abstract, 0-6"
generate absrol01=abstract_rol/6
note absrol01: Mean index: support for rule of law in the abstract, 0-1
label var absrol01 "Support for the rule of law"

* keep absrol_bend absrol_obey absabsrol_judges abstract_rol06 absrol01
* order absrol_bend absrol_obey absabsrol_judges abstract_rol06 absrol01, after (ideo_know01)


*****************************************************************
* Rule of Law - Concrete Measures *
*****************************************************************

	// varnames: 
	// Not in 2020: presterr01; presimm01; offrel01; offweed01; rol_rep01; rol_dem01
	// In 2020: black_protest01; guns_protest01

	// CUB3B10 black_protest01 CUB3B15 guns_protest01

recode CUB3B10	(1=0 "Agree strongly") 		(2=1 "Agree")  ///
				(3=2 "Agree somewhat") 		(4=3 "Neither")   /// 
				(5=4 "Disagree somewhat") 	(6=5 "Disagree")  ///
				(7=6 "Disagree strongly"), generate (black_protest)

recode CUB3B15 	(1=0 "Agree strongly") 		(2=1 "Agree") (3=2 "Agree somewhat") (4=3 "Neither")   /// 
				(5=4 "Disagree somewhat") 	(6=5 "Disagree")  ///
				(7=6 "Disagree strongly"), generate (guns_protest)

note black_protest: Since black protestors often get out of hand, it is more important to keep the peace than to allow people to have their voices heard
note guns_protest: Since pro-gun protestors often get out of hand, it is more important to keep the peace than to allow people to have their voices heard

generate black_protest01=black_protest/6
generate guns_protest01=guns_protest/6
note black_protest01: Since black protestors often get out of hand, it is more important to keep the peace than to allow people to have their voices heard
note guns_protest01: Since pro-gun protestors often get out of hand, it is more important to keep the peace than to allow people to have their voices heard

label var black_protest01 "Support for black protestors"
label var guns_protest01 "Support for pro-gun protestors"







*****************************************************************
* Supreme Court variables*
*****************************************************************
  
*sc_too_cons01; sc_dk01; sc_app01; ; ds_ussc01

	// CUB4B01 aware01 CUB4B02 ds_doaway01  CUB4B03 ds_reduce01 CUB4B04 ds_mixed01 CUB4B05 sc_too_cons01 
	// CC20_320c sc_app01 

// in 2016, not in 2020: perception of ideology - but we do have - too lib, too cons; or dk ideo 



recode CUB4B01 	(1=3 "Very aware") 			(2=2 "Somewhat aware") ///	
				(3=1 "Not very aware")  	(4=0 "Never heard of SC") , generate(awareness)	
generate aware01=awareness/3

note aware01:  Would you say that you are very aware, somewhat aware, not very aware, or have you never heard of the United States Supreme Court?
note awareness:  Would you say that you are very aware, somewhat aware, not very aware, or have you never heard of the United States Supreme Court?

recode CUB4B02	(1=0 "Agree strongly") 		(2=1 "Agree")  ///
				(3=2 "Agree somewhat") 		(4=3 "Neither")   /// 
				(5=4 "Disagree somewhat") 	(6=5 "Disagree")  ///
				(7=6 "Disagree strongly"), generate (ds_doaway)

recode CUB4B03	(1=0 "Agree strongly") 		(2=1 "Agree")  ///
				(3=2 "Agree somewhat") 		(4=3 "Neither")   /// 
				(5=4 "Disagree somewhat") 	(6=5 "Disagree")  ///
				(7=6 "Disagree strongly"), generate (ds_reduce)

recode CUB4B04	(1=0 "Agree strongly") 		(2=1 "Agree")  ///
				(3=2 "Agree somewhat") 		(4=3 "Neither")   /// 
				(5=4 "Disagree somewhat") 	(6=5 "Disagree")  ///
				(7=6 "Disagree strongly"), generate (ds_mixed)


generate ds_doaway01= (ds_doaway) /6
generate ds_reduce01= (ds_reduce) /6
generate ds_mixed01= (ds_mixed) /6


note ds_doaway:	If the U.S. Supreme Court started making a lot of decisions that most people disagree with, it might be better to do away with the Supreme Court altogether
note ds_doaway01:	If the U.S. Supreme Court started making a lot of decisions that most people disagree with, it might be better to do away with the Supreme Court altogether


note ds_reduce:	The right of the Supreme Court to decide certain types of controversial issues should be reduced
note ds_reduce01:	The right of the Supreme Court to decide certain types of controversial issues should be reduced


note ds_mixed:	The U.S. Supreme Court gets too mixed up in politics
note ds_mixed01:	The U.S. Supreme Court gets too mixed up in politics



egen ds_ussc01 = rowmean (ds_doaway01 ds_reduce01 ds_mixed01)

label var ds_ussc01 "Diffuse support, US Supreme Court"

recode CUB4B05 	(1=0 "0.Much too liberal")	(2=1 "1.Somewhat too liberal")  /// 
				(3=2 "2.About right")		(4=3 "3.Somewhat too conservative")	 /// 
				(5=4 "4.Much too conservative"), generate(sc_too_cons)

generate sc_too_cons01= (sc_too_cons)/4
note sc_too_cons01: Do you think the Supreme Court is much too liberal, somewhat too liberal, about right, somewhat too conservative, or much too conservative?
note sc_too_cons: Do you think the Supreme Court is much too liberal, somewhat too liberal, about right, somewhat too conservative, or much too conservative?
label var sc_too_cons01 "USSC too conservative"

*alpha ds_doaway01 ds_reduce01 ds_mixed01, item

*Note: Alpha is .72, but it goes up to .73 if ds_mixed is excluded



** Supreme Court approval * 

recode CC20_320c 	(1=4 "4.Strongly approve")	(2=3 "3.Somewhat approve")  /// 
					(5=3 "3.Neither")			(3=1 "1.Somewhat disapprove")	 /// 
					(4=0 "0.Strongly disapprove"), generate(sc_app)
					
					
note sc_app: Approval Supreme Court with don't know in the middle
label variable  sc_app "Supreme Court approval with don't know in the middle"

gen sc_app01 = (sc_app)/4
note sc_app01: Approval Supreme Court with don't know in the middle
label variable  sc_app01  "Supreme Court approval"


** don't know one's own Supreme Court approval * 
gen scapp_dk01 = 0
replace scapp_dk01 = 1 if CC20_320c == 5
label variable  scapp_dk01 "Don't know if approve of Supreme Court"


//   aware01  ds_doaway01   ds_reduce01  ds_mixed01  sc_too_cons01  sc_app01 ds_ussc01
  



*****************************************************************
* Attitudes about policing: support, force, accountability *
***************************************************************** 

	* varnames: CC20_334b pol_camera01 CC20_334h pol_sue01 pol_account01;
	*			polsup_inc01 polsup01; CUB3B05 polsup_rules01; CUB3B06 polsup_morals01
	* 			CUB3B02 polsup_crime01; CC20_307 polsup_safe01; police_more01
	*			polsup_rules; polsup_crime; polsup_safe; 
	
	* varnames: pol_camera01 pol_camera polsup_inc01 polsup_inc  polsup01 polsup polsup_rules01 
	*			polsup_rules polsup_morals01  polsup_morals  polsup_safe01 polsup_safe
	* 			polsup_crime01 polsup_crime; ; police_more01  police_more pol_choke01 
	* 			pol_mil01 pol_not_choke01 pol_not_mil01 pol_force01 pol_not_force01	

	* varnames:  CUB4B02     CUB4B05  CC20_320c  CC20_334b  CC20_334h  CUB3B05 ; CUB3B06 CUB3B02 ; CC20_307

*****************************************************************
* Support for the police *
*****************************************************************
	
	// In 2020, but not in 2016: polsup_morals01 (CUB3B06) 
	// In 2016 but not 2020: polsup_mindo01 polsup_res01
	// In both:  polsup_rules01 polsup_crime01 polsup_safe01

	// In 2016 but not 2020: – not support - polm01

	// polsup: CC20_307 CUB3B02 CUB3B05 CUB3B06	CC20_334c CC20_334d 
	// polsup_rules01 polsup_crime01 polsup_safe01 polsup_morals01 police_more01
	
	// CC20_334e  pol_choke01 pol_not_choke01 CC20_334g pol_mil01  pol_not_mil01 pol_force01 pol_not_force01				
	// CC20_334b pol_camera01 CC20_334h pol_sue01
	
	// In 2016, they ask whether #s of police should be increased by 10% 
	// In 2020, they ask BOTH increase AND decrease - but Rs were confused as they said "both"
	// in 2016, pol_inc01 is part of support, but in 2020, a Guttman scale was created out of decrease v. increase 
	// this is called polsup_more01 but is not exactly comparable to polsup_inc01 
	
	gen polsup_inc01 = CC20_334c 
	
		// CC20_334d  
		
		
// 	pol_camera01 pol_camera polsup_inc01 polsup_inc  polsup01 polsup polsup_rules01 polsup_rules polsup_morals01  polsup_morals  polsup_safe01 polsup_safe
// 	 polsup_crime01 polsup_crime; ; police_more01  police_more pol_choke01 pol_mil01 pol_not_choke01 pol_not_mil01 pol_force01 pol_not_force01	

 // CUB4B02     CUB4B05  CC20_320c  CC20_334b  CC20_334h  CUB3B05 ; CUB3B06 CUB3B02 ; CC20_307


* Police Make Respondent Feel Safe * 
	* varname: polsup_safe01*
recode CC20_307 (1=3 "3.Mostly safe")		(2=2 "2.Somewhat safe")  /// 
				(3=1 "1.Somewhat unsafe")	(4=0 "0.Mostly unsafe"), generate(polsup_safe)
generate polsup_safe01=polsup_safe/3
note polsup_safe01: Police make R feel mostly unsafe to mostly safe  
label var polsup_safe "Support for the police: safe"
label var polsup_safe01 "Support for the police: safe"

	* varname: polsup_crime01*
		// best way to deal with crime is to improve law enforcement
		// with more police
recode CUB3B02 	(1=6 "6.Agree strongly")	(2=5 "5.Agree")  /// 
				(3=4 "4.Agree somewhat")	(4=3 "3.Neither")	 /// 
				(5=2 "2.Disagree somewhat")	(6=1 "1.Disagree")  /// 
				(7=0 "0.Disagree strongly"), generate(polsup_crime)
label var polsup_crime "Best way to deal with crime is to improve law enforcement with more police"
generate polsup_crime01=polsup_crime/6
note polsup_crime01: Best way to deal with crime is to improve law enforcement with more police
label var polsup_crime01 "Support for the police: crime"

	* varname: polsup_rules01*
		// police apply the rules consistently to different kinds of people
recode CUB3B05 	(1=6 "6.Agree strongly")	(2=5 "5.Agree")  /// 
				(3=4 "4.Agree somewhat")	(4=3 "3.Neither")	 /// 
				(5=2 "2.Disagree somewhat")	(6=1 "1.Disagree")  /// 
				(7=0 "0.Disagree strongly"), generate(polsup_rules)
label var polsup_rules "Support for the police: rules"
generate polsup_rules01= polsup_rules /6
note polsup_rules01: Police apply the rules consistently to different kinds of people
label var polsup_rules01 "Support for the police: rules"


	* varname: polsup_morals01*
		// police act in ways that are consistent with my own moral values about how people should be treated
recode CUB3B06 (1=6 "6.Agree strongly")	(2=5 "5.Agree")  /// 
				(3=4 "4.Agree somewhat")	(4=3 "3.Neither")	 /// 
				(5=2 "2.Disagree somewhat")	(6=1 "1.Disagree")  /// 
				(7=0 "0.Disagree strongly"), generate(polsup_morals)
generate polsup_morals01=polsup_morals/6
note  polsup_morals: The police act in ways that are consistent with my own moral values about how people should be treated
label var polsup_morals "Support for the police: morals"
note  polsup_morals01: The police act in ways that are consistent with my own moral values about how people should be treated
label var polsup_morals01 "Support for the police: morals"	


*****************************************************************
* Support for police force and accountability *
*****************************************************************
	// CC20_334e CC20_334g pol_choke01 pol_mil01 pol_not_choke01 pol_not_mil01 pol_force01 pol_not_force01				

**** Support for less force    ****

*varname: pol_not_choke*
		// ban the use of chokeholds
recode CC20_334e (1=1 "1.No choke") (2=0 "0.Choke"), gen (pol_not_choke01)

*varname: pol_not_mil*
		// End the DOD sending surplus military equipment to police departments
recode CC20_334g (1=1 "1.No mil") (2=0 "2.Mil ok"), gen (pol_not_mil01)
corr pol_not_choke pol_not_mil
egen pol_not_force01 = rowmean (pol_not_choke01 pol_not_mil01)





*****************************************************************
* Support for more force: to use as construct validity *
*****************************************************************

*varname: pol_choke*
		// support the use of chokeholds
recode CC20_334e (1=0 "0.No choke") (2=1 "1.Choke"), gen (pol_choke01)
label var pol_choke "Support the use of chokeholds"

*varname: pol_mil*
		// End the DOD sending surplus military equipment to police departments
recode CC20_334g (1=0 "0.No mil") (2=1 "1.Mil ok"), gen (pol_mil01)
label var pol_mil "Support the DOD sending surplus military equipment to police departments"


egen pol_force01 = rowmean (pol_choke01 pol_mil01)




****************************************                    
* Support for more police: complicated *
****************************************
	// CC20_334d CC20_334c 


// tab CC20_334d 
// 
//     Policing |
//  policies -- |
// Decrease the |
//    number of | Policing policies --
//    police on |  Increase the number
//   the street |   of police on the
//        by 10 | street by 10 percent,
//    percent,  |   Support     Oppose |     Total
// -------------+----------------------+----------
//      Support |        48        333 |       381 
//       Oppose |       411        208 |       619 
// -------------+----------------------+----------
//        Total |       459        541 |     1,000 



* This is irritating because 48 people are inconsistent 

* 333 oppose increase and support decrease  : this should be lowest on police_more
* 411  support increase and oppose decrease: this should be highest on police_more
* 208 want things to stay the same: they oppose increase but also oppose decrease  
* 48 support increase and support decrease, so we can put them in the "confused" group , initially


* But just to make sure, we can do a nominal test, using the variable "polsup_crime01"

*Support = 1, Oppose = 2


* start with those who say they want to decrease CC20_334d = 1
* generate  police_more01_test = 1 if (CC20_334d == 1 )

* those who say they want to increase but also want to decrease - the confused group"
* replace police_more01_test = 2 if (CC20_334d == 1 & CC20_334c == 1)

* those who say they do not want to decrease but also want them to increase because they are 0 on "not" increase"
* replace police_more01_test = 3 if (CC20_334d == 2 &  CC20_334c == 2)

* Those who oppose decreasing and support increasing 
* replace police_more01_test = 4 if (CC20_334d == 2 & CC20_334c == 1)

*tab police_more01_test

*police_more |
*    01_test |      Freq.     Percent        Cum.
*------------+-----------------------------------
*          1 |        333       33.30       33.30
*          2 |         48        4.80       38.10
*          3 |        208       20.80       58.90
*          4 |        411       41.10      100.00
*------------+-----------------------------------
*      Total |      1,000      100.00

 
*regr polsup_crime01 i.police_more01_test

* This shows that the confused group (2) is much more supportive of more police compared the "same" group (3) 
* Unsurprisingly, the standard error is higher
* But that advocates for a Guttman style coding where if they say increase, believe them
 
* regr polsup_crime01 i.police_more01_test

*    polsup_crime01 |      Coef.   Std. Err.      t    P>|t|     [95% Conf. Interval]
*-------------------+----------------------------------------------------------------
*                2  |   *** .45 ***   .0381074    11.83   0.000     .3759832    .5255433

*                3  |     .2127825     .021814     9.75   0.000     .1699759    .2555891

*                4  |   *** .48 ***   .0181984    26.48   0.000     .4461242    .5175474

*             _cons |     .2367367    .0135259    17.50   0.000     .2101941    .2632794
*------------------------------------------------------------------------------------

*drop police_more01_test




* Creating a quasi Guttman style coding where if they say increase, believe them and score them a 1, even if they also say decrease


* start with those who say they want to decrease CC20_334d (1=0 "Decrease")" 
generate  police_more01 = 0 if  (CC20_334d == 1 )

* those who say they do not want to decrease but also don't want to increase: stay the same
replace police_more01 = .5 if (CC20_334d == 2 &  CC20_334c == 2)

* those who say they want to increase, includes those who say decrease 
replace police_more01 = 1 if (CC20_334c == 1)

*tab police_more01

*police_more |
*         01 |      Freq.     Percent        Cum.
*------------+-----------------------------------
*          0 |        333       33.30       33.30
*         .5 |        208       20.80       54.10
*          1 |        459       45.90      100.00
*------------+-----------------------------------
*      Total |      1,000      100.00

* Now, the 1 category has the "confused" group 

label var police_more01 "Support increasing police"
note police_more01: Support for increasing police by 10% versus decreasing by 10%


* Support for Police * 
* alpha  polsup_rules01 polsup_crime01  polsup_safe01 polsup_morals01 police_more01, item

* Construction of mean index* 
egen polsup01=rowmean ( polsup_rules01 polsup_crime01  polsup_safe01 police_more01)
note polsup01: Mean index: support for police: they follow rules, reduce crime, make R feel safe, and there should be more
label var polsup01 "Support for the police"

egen polsup01=rowmean ( polsup_rules01 polsup_crime01  polsup_safe01 police_more01)
egen polsup01_comp1620 = rowmean ( polsup_rules01 polsup_crime01  polsup_safe01 )

*** Police policy variables: accountability: cameras and getting rid of qualified immunity    ****


*varname: pol_camera*
		// require body cameras 
		*varname: pol_sue*
		// Allow people to sue police officers 
recode CC20_334b (1=1 "1.Camera") (2=0 "0.No camera"), gen (pol_camera01)

*varname: pol_sue*
		// Allow people to sue police officers 
recode CC20_334h (1=1 "1.Sue") (2=0 "0.Not sue"), gen (pol_sue01)

*tab pol_camera 
*tab  pol_sue

*corr pol_camera pol_sue
* r = .27

* Note: tiny minority reject body cameras; hence no variation 

egen pol_account01 = rowmean (pol_camera01 pol_sue01)

label var pol_account01 "Support for accountability: cameras and torts"


*****************************************************************
* Support for violence: police *
*****************************************************************
// CUB3B13 CUB3B14
//   violpol01 violpol01_2 violpol_dem01 violpol_dem
//   violpol_handcuff01 violpol_handcuff 
//  violvig01

recode CUB3B13 			(1=6 "6.Agree strongly") 	(2=5 "5.Agree") ///
						(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
						(5=2 "2.Disagree somewhat") (6=1 "1.Disagree") ///
						(7=0 "0.Disagree strongly"), generate(violpol_dem)
						
note violpol_dem: It is sometimes acceptable for police officers to use physical force to control non-violent demonstrations
generate violpol_dem01=violpol_dem/6
note violpol_dem01: It is sometimes acceptable for police officers to use physical force to control non-violent demonstrations


recode CUB3B14			(1=6 "6.Agree strongly") 	(2=5 "5.Agree") ///
						(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
						(5=2 "2.Disagree somewhat") (6=1 "1.Disagree") ///
						(7=0 "0.Disagree strongly"), generate(violpol_handcuff)
note violpol_handcuff: It is sometimes acceptable for police officers to use physical force against a handcuffed offender
generate violpol_handcuff01=violpol_handcuff/6
note violpol_handcuff01: It is sometimes acceptable for police officers to use physical force against a handcuffed offender

label var violpol_handcuff01 	"Support for force: handcuffed person"
label var violpol_dem01 		"Support for force: peaceful protestors"

egen violpol01 = rowmean (violpol_dem01 violpol_handcuff01)
label var violpol01 "Support for police violence"

egen violpol01_2 = rowmean (violpol_dem01 violpol_handcuff01 pol_choke01 pol_mil01)
label var violpol01_2 "Support for police violence, with CCES items"


*****************************************************************
*** Support for violence: vigilante ****
*****************************************************************

// CUB3B25 CUB3B26 
// violvig_crim violvig_crim01 violvig_hands violvig_hands01 violvig01


recode CUB3B25		 	(1=6 "6.Agree strongly") 	(2=5 "5.Agree") ///
						(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
						(5=2 "2.Disagree somewhat") (6=1 "1.Disagree") ///
						(7=0 "0.Disagree strongly"), generate(violvig_crim)
note violvig_crim: It is all right for members of the public to beat up criminals
generate violvig_crim01=violvig_crim/6
note violvig_crim01: It is all right for members of the public to beat up criminals
label var violvig_crim01 "Public can beat up criminals"

recode CUB3B26	 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") ///
						(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
						(5=2 "2.Disagree somewhat") (6=1 "1.Disagree") ///
						(7=0 "0.Disagree strongly"), generate(violvig_hands)
note violvig_hands: It is sometimes acceptable for people to take the law into their own hands, even if they become violent
generate violvig_hands01=violvig_hands/6
note violvig_hands01: It is sometimes acceptable for people to take the law into their own hands, even if they become violent
label var violvig_hands01 "People can take law into their own hands"

egen violvig01 = rowmean (violvig_crim01 violvig_hands01)
label var violvig01 "Support for vigilante violence"


* corr violvig_crim01 violvig_hands01  

*corr violvig_crim01 violvig_hands01

*r = .56


*****************************************************************
*** Support for violence: protest ****
*****************************************************************

// CUB3B19  CUB3B20
// violprot_just violprot_just01 violprot_auth violprot_auth01

recode CUB3B19		 	(1=6 "6.Agree strongly") 	(2=5 "5.Agree") ///
						(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
						(5=2 "2.Disagree somewhat") (6=1 "1.Disagree") ///
						(7=0 "0.Disagree strongly"), generate(violprot_just)
note violprot_just: Sometimes it is understandable that people get violent when they protest against injustice
generate violprot_just01=violprot_just/6
note violprot_just01: Sometimes it is understandable that people get violent when they protest against injustice
label var violprot_just01 "Violent protest understandable"

recode CUB3B20 		 	(1=6 "6.Agree strongly") 	(2=5 "5.Agree") ///
						(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
						(5=2 "2.Disagree somewhat") (6=1 "1.Disagree") ///
						(7=0 "0.Disagree strongly"), generate(violprot_auth)
note violprot_auth: It is sometimes acceptable to encourage violence against authorities who harm innocent people
generate violprot_auth01=violprot_auth/6
note violprot_auth01: It is sometimes acceptable to encourage violence against authorities who harm innocent people
label var violprot_auth01 "Acceptable to encourage violence against authorities"


egen violprot01 = rowmean (violprot_just01 violprot_auth01)
label var violprot01 "Support for protest violence"


* corr violprot_just01 violprot_auth01
*r = .53
















*****************************************************************
* Identity variables * 
*****************************************************************

* Locus of control and self-efficacy *

// CUB3B28 CUB3B29 CUB3B27  
// out_power out_power01 out_control out_control01 self_difficult self_difficult01


recode CUB3B28 (1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(out_power)
generate out_power01=out_power/6

recode CUB3B29 (1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(out_control)	
generate out_control01=out_control/6

note out_power01 : I feel like what happens in my life is mostly determined by people with all the power
note out_control01 : I believe the problems in my life are completely out of my control

egen out01 = rowmean (out_power01 out_control01)
label var out01 "External locus of control"




recode CUB3B27 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(self_difficult)	
generate self_difficult01=self_difficult/6
note self_difficult01: When facing difficult tasks, I am certain that I will be able to accomplish them


* Social identity: what people value about their relationship and regard from others 
* Material identity 


// CUB3B30 CUB3B21 CUB3B22 CUB3B23



recode CUB3B30 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(success)	
generate success01=success/6
label var success01 "Importance of success"
note success: It is important to me to be considered successful
note success01: It is important to me to be considered successful

* Importance of social norms  

 


recode CUB3B21 (1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(socsen_stranger)	
generate socsen_stranger01=socsen_stranger/6

note socsen_stranger01: In general, it makes me very upset when I see someone being unkind to a stranger

recode CUB3B22 (1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(socsen_good)	
generate socsen_good01=socsen_good/6

note socsen_good01: It is very important to me to be considered a good person by other people, even if I don't know them well

recode CUB3B23 (1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(socsen_cus)	
generate socsen_cus01=socsen_cus/6

note socsen_cus01: In general, I get angry when customer service people treat me with disrespect




*alpha socsen_cus01 socsen_good01 socsen_stranger01, item 

*Disappointingly, alpha is .47. 
*there is very, very little variation in "good" and "stranger"


*             | socs~s01 socs~d01 socs~r01
*-------------+---------------------------
*socsen_cus01 |   1.0000
*socsen_go~01 |   0.1622   1.0000
*socsen_st~01 |   0.2235   0.2362   1.0000




**** Attributes of personal life: Emotions  ****

// CUB3B07 CUB3B18 CUB3B36
// lonely lonely01 hatred hatred01 anger anger01 sucky_life01 


recode CUB3B07 (1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(lonely)	
generate lonely01=lonely/6

note lonely01: I feel the emotion of loneliness often


recode CUB3B18 (1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(hatred)	
generate hatred01=hatred/6

note hatred01: I feel the emotion of hatred often


recode CUB3B36 (1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(anger)	
generate anger01=anger/6

note anger01: I feel the emotion of anger often

note lonely : I feel the emotion of loneliness often
note hatred : I feel the emotion of hatred often
note anger : I feel the emotion of anger often


*corr anger01 hatred01 lonely01
*             |  anger01 hatred01 lonely01
*-------------+---------------------------
*     anger01 |   1.0000
*    hatred01 |   0.5424   1.0000
*    lonely01 |   0.4079   0.3257   1.0000

egen sucky_life01 = rowmean (  anger01 hatred01 lonely01 )


**** Attributes of personal life: Optimism  ****
// CUB3B24 CUB3B34
// optgen optgen01 optpol optpol01

recode CUB3B24 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(optgen)	
generate optgen01=optgen/6
note optgen01: Generally, I tend to feel very optimistic about my future



recode CUB3B34 (1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(optpol)	
generate optpol01=optpol/6

note optpol01: I believe it is possible to solve the problems in the American political system


*corr optgen optgen01 optpol optpol01

* r = .17


*These are not meant to be the same concept. We use general optimism as a control with optimism about politics.




********************************************************************************
* Risk orientations and other traits *                               
********************************************************************************
// CUB3S19 CUB3S20 CUB3S21 CUB3S22 CUB3S23 CUB4P02 CUB4P03 CUB4P04 CUB4P05x
// rDifferent rAltern rFailure rOpps curious_alts curious01 discount discount01 share share01 risk risk01 


clonevar rBack = CUB3S19 
clonevar rDifferent = CUB3S20 
clonevar rAltern = CUB3S21 
clonevar rFailure = CUB3S22 
clonevar rOpps = CUB3S23 

note rBack : Once I make a decision, I don't look back
note rDifferent:  Whenever I make a choice, I'm curious about what would have happened if I had chosen differently
note rAltern:  Whenever I make a choice, I try to get information about how the other alternatives turned out
note rFailure:  If I make a choice and it turns out well, I still feel like something of a failure if I find out that another choice would have turned out better
note   rOpps:  When I think about how I'm doing in life, I often assess opportunities I have passed up




egen curious_alts = rowmean ( rDifferent rAltern rFailure rOpps )
gen curious01 = (curious_alts -1)/6

note curious01 : Curious about how life would have turned out with different choices, CUB3S20 CUB3S21 CUB3S22 CUB3S23
label var curious01 "Curiosity about past choices"



clonevar risk = CUB4P02 
clonevar discount = CUB4P03 
clonevar share = CUB4P04 
clonevar labrisk  = CUB4P05x 

gen discount01 = (discount )/10
gen risk01 = (risk )/10
gen share01 = (share )/10


note risk01 : Are you a person who is generally willing to take risks, or do you try to avoid taking risks
note  share01 : Are you a person who is willing to share with others without expecting anything in return


label var risk01 "Riskiness"
label var share01 "Willingness to share"

label define risk 0 "0.Completely unwilling to take risks"	1	"1.Very willing to take risks"
label define share 0 "0.Completely unwilling to share"		1	"1.Very willing to share"
label values risk01 risk
label values share01 share 


* alpha  rBack rDifferent rAltern rFailure rOpps, item 
* .68







**** Social and group identity  ****
// CUB3B12 CUB3B42_1 CUB3B43_1 CUB3B44_1 CUB3B45_1  CUB3B38_1 CUB3B39_1 CUB3B40_1 CUB3B41_1 

// super_care super_care01
// seeself_race seeself_race01 seeself_pol seeself_pol01 seeself_class seeself_class01 seeself_country seeself_country01 
// link_race link_race01 link_pol link_pol01 link_class link_class01 link_country link_country01




recode CUB3B12 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(super_care)	
generate super_care01=super_care/6
note super_care: I believe that most Americans care very much about what happens to people like me
note super_care01: I believe that most Americans care very much about what happens to people like me
label var super_care01 "Americans care about me"









clonevar link_race = CUB3B42_1 
clonevar link_pol = CUB3B43_1 
clonevar link_class = CUB3B44_1 
clonevar link_country = CUB3B45_1 	

generate link_race01 = (link_race -1) /6
generate link_pol01 = (link_pol -1) /6
generate link_class01 = (link_class - 1) /6
generate link_country01 = (link_country-1) /6

label var link_race01 "Linked fate: race/ethnicity"
label var link_pol01 "Linked fate: politics"
label var link_class01 "Linked fate: class"
label var link_country01 "Linked fate: Americans"

label define link 0 "0.Not at all likely" 1 "1.Extremely likely"
label values link_race01 link_pol01 link_class01 link_country01 link


note link_race01: Some people feel that what happens to other people who are like them will also have something to do with their own lives. Others feel that what happens to other people who are like them will have nothing to do with their own lives. On a scale from 1-to-7 with 1 being 'not at all likely,' and 7 being 'extremely likely,' how likely is it that your life will be affected by what happens to… 
note link_pol01: Some people feel that what happens to other people who are like them will also have something to do with their own lives. Others feel that what happens to other people who are like them will have nothing to do with their own lives. On a scale from 1-to-7 with 1 being 'not at all likely,' and 7 being 'extremely likely,' how likely is it that your life will be affected by what happens to… 
note link_class01: Some people feel that what happens to other people who are like them will also have something to do with their own lives. Others feel that what happens to other people who are like them will have nothing to do with their own lives. On a scale from 1-to-7 with 1 being 'not at all likely,' and 7 being 'extremely likely,' how likely is it that your life will be affected by what happens to… 
note link_country01: Some people feel that what happens to other people who are like them will also have something to do with their own lives. Others feel that what happens to other people who are like them will have nothing to do with their own lives. On a scale from 1-to-7 with 1 being 'not at all likely,' and 7 being 'extremely likely,' how likely is it that your life will be affected by what happens to… 

* Indexes with just seeself vars 
egen see_class_race01  = rowmean (seeself_race01  seeself_class01)
egen see_class_pol01  = rowmean (seeself_pol01  seeself_class01)
egen seeself01 = rowmean (seeself_race01  seeself_pol01  seeself_class01 )

* Indexes with just link vars 
egen link_class_race01  = rowmean (link_race01  link_class01)
egen link_class_pol01 = rowmean (link_class01 link_pol01 )
egen link01 = rowmean (link_race01 link_class01 link_pol01 )

* Indexes that combine seeself and link  
egen see_link_race01 = rowmean (seeself_race01 link_race01 )
egen see_link_class01 = rowmean (seeself_class01 link_class01 )
egen see_link_pol01 = rowmean (seeself_pol01 link_pol01 )
	
	
********************************************************************************
*                  			*** Social networks ***                               
********************************************************************************
// CUB3A24_split 
// CUB3S01 CUB3S02 CUB3S03 CUB3S04 CUB3S05 CUB3S06 CUB3S07 CUB3S08 CUB3S09 CUB3S10 CUB3S11 CUB3S12 CUB3S13 CUB3S14 CUB3S15 CUB3S16 CUB3S17 
// CUB3S18 
	// 	ac_biden01 ac_black01 ac_covid01 ac_early01 ///
	//	ac_govern01 ac_grad01 ac_gun01 ac_imm01 ac_lgbt01 ///
	//	ac_mil01 ac_muslim01 ac_office01 ac_pol01 ac_run01 ac_trump01 ///
	//	ac_unemp01
	//  Indexes: ac_cons01  ac_disadvant01 ac_gov01

clonevar ac_gun = CUB3S01 
clonevar ac_trump = CUB3S02 
clonevar ac_biden = CUB3S03 
clonevar ac_govern = CUB3S04 
clonevar ac_lgbt = CUB3S05 
clonevar ac_pol = CUB3S06 
clonevar ac_mil = CUB3S07 
clonevar ac_run = CUB3S08 
clonevar ac_black = CUB3S09 
clonevar ac_addict = CUB3S10 
clonevar ac_attend= CUB3S11 
clonevar ac_muslim = CUB3S12 
clonevar ac_imm = CUB3S13 
clonevar ac_unemp = CUB3S14 
clonevar ac_grad = CUB3S15 
clonevar ac_covid = CUB3S16 
clonevar ac_office = CUB3S17 
clonevar ac_early = CUB3S18 



gen  ac_gun01 = 	( ac_gun - 1)/4 
gen  ac_trump01 = 	( ac_trump  - 1)/4 
gen  ac_biden01 = 	( ac_biden  - 1)/4 
gen  ac_govern01 = 	( ac_govern - 1)/4 
gen  ac_lgbt01 = 	( ac_lgbt - 1)/4 
gen  ac_pol01 = 	( ac_pol - 1)/4 
gen  ac_mil01 = 	( ac_mil - 1)/4 
gen  ac_run01 = 	( ac_run   - 1)/4 
gen  ac_black01 = 	( ac_black  - 1)/4 
gen  ac_addict01 = 	( ac_addict   - 1)/4 
gen  ac_attend01 = 	( ac_attend  - 1)/4 
gen  ac_muslim01 = 	( ac_muslim  - 1)/4 
gen  ac_imm01 = 	( ac_imm  - 1)/4 
gen  ac_unemp01 = 	( ac_unemp  - 1)/4 
gen  ac_grad01 = 	( ac_grad  - 1)/4 
gen  ac_covid01 = 	( ac_covid   - 1)/4 
gen  ac_office01 = 	( ac_office - 1)/4 
gen  ac_early01 = 	( ac_early - 1)/4 



label define 	ac_vars 				/// 
				0	"0.0"					/// 			
				1	"1.More than 10"

label values  	ac_biden01 ac_black01 ac_covid01 ac_early01 ///
				ac_govern01 ac_grad01 ac_gun01 ac_imm01 ac_lgbt01 ///
				ac_mil01 ac_muslim01 ac_office01 ac_pol01 ac_run01 ac_trump01 ///
				ac_unemp01 ac_vars
				
 
alpha ac_gun01 ac_trump01 ac_pol01 ac_mil01 , item 
alpha ac_lgbt01  ac_imm01 ac_muslim01 ac_black01, item 




* Religiosity * 

// prayer01 attend01 religimp01 rel01 

recode pew_prayer 	(7/8=0 "0.Never/Don't know")	(6=1 "1.Seldom")	 /// 
					(5=2 "2.A few times a month")	(4=3 "3.Once a week")  /// 
					(3=4 "4.A few times a week")	(2=5 "5.Once a day")  /// 
					(1=6 "6.Several times a day"), generate(prayer)
label var prayer "Prayer"
generate prayer01=prayer/6
label var prayer01 "Prayer"

recode pew_churatd 	(6/7=0 "0.Never/Don't know")	 /// 
					(5=1 "1.Seldom")	(4=2 "2.A few times a year")  /// 
					(3=3 "3.Once or twice a month")	(2=4 "4.Once a week")  /// 
					(1=5 "5.More than once a week"), generate(attend)
label var attend "...how often do you attend religious services?"
generate attend01=attend/5
label var attend01 "...how often do you attend religious services? (0 to 1)"

recode pew_religimp 	(4=0 "0.Not at all important")	 /// 
					(3=1 "1.Not too important")  /// 
					(2=2 "2.Somewhat important")  /// 
					(1=3 "3.Very important"), generate(religimp)
generate religimp01=religimp/3
label var religimp01 "Religion important"

recode pew_bornagain 		(1=1 "1.Yes")	(2=0 "0.No"), generate(bornagain01)
label var bornagain01 "Born again"

* Construction of mean index* 
egen rel01 = rowmean(prayer01 attend01 religimp01 bornagain01)
label var rel01 "Religiosity"
note rel01 : Religiosity: pew_prayer, pew_churatd, pew_religimp pew_bornagain



********************************************************************************
* Denial of racism, people of color racial resentment, resentment of women * 
********************************************************************************


	// in 2020: CC20_440a CC20_440b CC20_441a CC20_441b 
	// only asked of nonwhites (n=213): CC20_441e CC20_441f CC20_441g
	
	// den_advant01 den_rare01 den_favors01 den_dif01 denres01 
	// only asked of nonwhites (n=213): pocres_den01 pocres_getaway01 pocres_und01 pocres01 pocres_m

	// not in 2016:  den_favors01 den_dif01 

	// Not in 2020: den_angry01 
	
	
	// CC20_440c CC20_440d 
	// femres_power01 femres_offend01 femres01

recode CC20_441e	(1=4 "4.Strongly agree")	(2=3 "3.Somewhat agree")  /// 
					(3=2 "2.Neither")			(4=1 "1.Somewhat disagree")	 /// 
					(5=0 "0.Strongly disagree"), generate(pocres_den)

note pocres_den: I resent when Whites deny the existence of racial discrimination
label var pocres_den "People of color racial resentment: Resent whites' denials'"

recode CC20_441f	(1=4 "4.Strongly agree")	(2=3 "3.Somewhat agree")  /// 
					(3=2 "2.Neither")			(4=1 "1.Somewhat disagree")	 /// 
					(5=0 "0.Strongly disagree"), generate(pocres_getaway)

note pocres_getaway: Whites get away with offenses that African Americans would never get away with
label var pocres_getaway "People of color racial resentment: Resent whites' getting away with offenses"

recode CC20_441g	(1=4 "4.Strongly agree")	(2=3 "3.Somewhat agree")  /// 
					(3=2 "2.Neither")			(4=1 "1.Somewhat disagree")	 /// 
					(5=0 "0.Strongly disagree"), generate(pocres_und)

note pocres_und: Whites do not go to great lengths to understand the problems African Americans face
label var pocres_und "People of color racial resentment: Resent whites' lack of understanding'"

gen pocres_den01 = pocres_den /4
gen pocres_getaway01 = pocres_getaway /4
gen pocres_und01 = pocres_und /4

* Construction of mean index* 
egen pocres01 = rowmean (pocres_den01 pocres_getaway01 pocres_und01 )
replace pocres01 = -1 if pocres01==.

gen pocres_m = 0
replace pocres_m = 1 if pocres01 ==1

note pocres_den01: I resent when Whites deny the existence of racial discrimination
label var pocres_den01 "People of color racial resentment: Resent whites' denials"
note pocres_getaway01: Whites get away with offenses that African Americans would never get away with
label var pocres_getaway01 "People of color racial resentment: Resent whites' getting away with offenses"
note pocres_und01: Whites do not go to great lengths to understand the problems African Americans face
label var pocres_und01 "People of color racial resentment: Resent whites' lack of understanding"

note pocres01: People of color racial resentment of whites who deny racism, refuse to try to understand, or get away with offenses 
label var pocres01 "People of color racial resentment"



 

recode CC20_440a	(1=0 "0.Strongly agree")	(2=1 "1.Somewhat agree")  /// 
					(3=2 "2.Neither")			(4=3 "3.Somewhat disagree")	 /// 
					(5=4 "4.Strongly disagree"), generate(den_advant)
					
note den_advant: White people have certain advantages because of the color of their skin
label var den_advant "Denial of racism: White people advantages"

recode CC20_440b	(1=4 "4.Strongly agree")	(2=3 "3.Somewhat agree")  /// 
					(3=2 "2.Neither")			(4=1 "1.Somewhat disagree")	 /// 
					(5=0 "0.Strongly disagree"), generate(den_rare)
					
label var den_rare "Denial of racism: Racial problems rare"
note den_rare: Racial problems in the U.S. are rare, isolated situations

recode CC20_441a	(1=4 "4.Strongly agree")	(2=3 "3.Somewhat agree")  /// 
					(3=2 "2.Neither")			(4=1 "1.Somewhat disagree")	 /// 
					(5=0 "0.Strongly disagree"), generate(den_favors)
					
label var den_favors "Denial of racism: Blacks should work way up"
note den_favors: Irish, Italians, Jewish and many other minorities overcame prejudice and worked their way up. Blacks should do the same without any special favors

recode CC20_441b	(1=0 "0.Strongly agree")	(2=1 "1.Somewhat agree")  /// 
					(3=2 "2.Neither")			(4=3 "3.Somewhat disagree")	 /// 
					(5=4 "4.Strongly disagree"), generate(den_dif)
					
label var den_dif "Denial of racism: Slavery / discrimination made it difficult"
note den_dif: Generations of slavery and discrimination have created conditions that make it difficult for blacks to work their way out of the lower class




gen den_advant01 = den_advant /4
gen den_rare01 = den_rare /4
gen den_favors01 = den_favors /4
gen den_dif01 = den_dif /4

label var den_advant01 "Denial of racism: White people advantages"
note den_advant01: White people have certain advantages because of the color of their skin
label var den_rare01 "Denial of racism: Racial problems rare"
note den_rare01: Racial problems in the U.S. are rare, isolated situations
label var den_favors01 "Denial of racism: Blacks should work way up"
note den_favors01: Irish, Italians, Jewish and many other minorities overcame prejudice and worked their way up. Blacks should do the same without any special favors
label var den_dif01 "Denial of racism: Slavery / discrimination made it difficult"
note den_dif01: Generations of slavery and discrimination have created conditions that make it difficult for blacks to work their way out of the lower class


* Construction of mean index* 
egen denres01 = rowmean ( den_advant01 den_rare01 den_favors01 den_dif01 )
label var denres01 "Index: Denial of racism"




recode CC20_440c	(1=4 "4.Strongly agree")	(2=3 "3.Somewhat agree")  /// 
					(3=2 "2.Neither")			(4=1 "1.Somewhat disagree")	 /// 
					(5=0 "0.Strongly disagree"), generate(femres_power)
					
label var femres_power "Women control men"
note femres_power: Women seek to gain power by getting control over men.

recode CC20_440d	(1=4 "4.Strongly agree")	(2=3 "3.Somewhat agree")  /// 
					(3=2 "2.Neither")			(4=1 "1.Somewhat disagree")	 /// 
					(5=0 "0.Strongly disagree"), generate(femres_offend)

label var femres_offend "Women too offended"
note femres_offend: Women are too easily offended.

gen femres_power01 = femres_power /4
gen femres_offend01 = femres_offend /4

egen femres01 = rowmean (femres_power01 femres_offend01 )
label var femres01 "Resentment of women"



*****************************************************************
* Support for democracy, authoritarianism *
*****************************************************************

// CUB4B11 obey01; 
// CUB3B09 stealth_dem01  stealth_experts01 

// In 2020: stealth_experts01 obey01

	* varname: obey01*
		// In today's world, parents should emphasize obedience more
recode CUB4B11 	(1=6 "6.Agree strongly")	(2=5 "5.Agree")  /// 
				(3=4 "4.Agree somewhat")	(4=3 "3.Neither")	 /// 
				(5=2 "2.Disagree somewhat")	(6=1 "1.Disagree")  /// 
				(7=0 "0.Disagree strongly"), generate(obey)
label var obey "Authoritarianism"
generate obey01=obey/6
note obey01: In today's world, parents should emphasize obedience more
label var obey01 "Authoritarianism"

* Stealth democracy *

* varname: stealth_experts01*
	// government runs better if decisions were left to nonelected, independent
	// experts rather than politicians
recode CUB3B09 	(1=6 "6.Agree strongly")	(2=5 "5.Agree") (3=4 "4.Agree somewhat")   /// 
				(4=3 "3.Neither")			(5=2 "2.Disagree")	(6=1 "1.Disagree somewhat") /// 
				(7=0 "0.Disagree strongly"), generate(stealth_experts)
note: stealth_experts "Government runs better if decisions were left to nonelected, independent experts rather than politicians"
generate stealth_experts01=stealth_experts/6
label var stealth_experts01 "Stealth democracy: nonelected experts"
label var stealth_experts "Stealth democracy: nonelected experts"

* Construction of mean index* 
replace stealth_dem01 = ( stealth_experts01 ) if year == 2020
label var stealth_dem01 "Stealth democracy"

gen dem_culture01 =  (stealth_experts01 *-1)+1
label var dem_culture01 "Democratic culture: experts should not rule"

* NOTE because of a mistake I had to correct it using following code 2020 has 7 values, 2016 has 5  * * Stealth democracy *

* varname: stealth_experts01*
	// government runs better if decisions were left to nonelected, independent
	// experts rather than politicians
* recode CUB3B09 	(1=6 "6.Agree strongly")	(2=5 "5.Agree") (3=4 "4.Agree somewhat")   /// 
				(4=3 "3.Neither")			(5=2 "2.Disagree")	(6=1 "1.Disagree somewhat") /// 
				(7=0 "0.Disagree strongly"), generate(stealth_experts)
* note: stealth_experts "Government runs better if decisions were left to nonelected, independent experts rather than politicians"
* generate stealth_experts01=stealth_experts/6
* label var stealth_experts01 "Stealth democracy: nonelected experts"
* label var stealth_experts "Stealth democracy: nonelected experts"

* Construction of mean index* 
replace stealth_dem01 = ( stealth_experts01 ) 
label var stealth_dem01 "Stealth democracy"

replace  dem_culture01 =  (stealth_experts01 *-1)+1 
label var dem_culture01 "Democratic culture: not stealth democracy"

  
* Dogmatism *

* /!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\

 * Note: this free speech item is not included in dogmatism but comm. to liberty
 
* /!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\/!\

// CUB3B08 liberty01
// CUB3B37 members01 dog01 

recode CUB3B08	 	(1=0 "0.Agree strongly")		(2=1 "1.Agree")  /// 
					(3=2 "2.Agree somewhat")		(4=3 "3.Neither")	 /// 
					(5=4 "4.Disagree somewhat")		(6=5 "5.Disagree")  /// 
					(7=6 "6.Disagree strongly"), generate(liberty)
note liberty: "Free speech is just not worth it if it means that we have to put up with the danger to society of extremist political views"
generate liberty01=liberty/6

note: liberty01: "Free speech is just not worth it if it means that we have to put up with the danger to society of extremist political views"

label var liberty "Support for liberty"
label var liberty01 "Support for liberty"

recode CUB3B37 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") ///
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree") ///
					(7=0 "0.Disagree strongly"), generate(members)
note members: "A group which tolerates too many differences of opinion among its own members cannot exist for long"
generate members01=members/6

egen dog01 = rowmean (members01 )

label var dog01 "Dogmatism"



* Support for compromise 

clonevar compromise = CUB3B48 

label var compromise "It is more important for a politician to compromise to get things done than it is to stand firm on principle"

recode CUB3B48 (1=6 "Agree strongly") (2=5 "Agree") (3=4 "Agree somewhat") (4=3 "Neither agree nor disagree")  /// 
	(5=2 "Disagree somewhat") /// 
	(6=1 "Disagree") (7=0 "Disagree strongly"), generate(compromise_r)

generate compromise01 = compromise_r/6









*****************************************************************
* Policy attitudes *
*****************************************************************



********************************************************************************
* COVID-19 Attitudes *                               
********************************************************************************

// CUB3J01 CUB3J02 CUB3J03 CUB3J04 CUB3J05 CUB3J06 CUB3J07 CUB3J08
// cov_threat cov_threat01 cov_dist cov_dist01 cov_econ cov_econ01 cov_advice cov_advice01 
// cov_mask cov_mask01 cov_part cov_part01 cov_faith cov_faith01 cov_censor cov_censor01 
// cov_serious01 cov_reg01

clonevar cov_threat = CUB3J01 
clonevar cov_dist = CUB3J02 
clonevar cov_econ = CUB3J03 
clonevar cov_advice = CUB3J04 
clonevar cov_mask = CUB3J05 
clonevar cov_part = CUB3J06 
clonevar cov_faith = CUB3J07 
clonevar cov_censor = CUB3J08 




gen cov_advice01 = ((cov_advice*-1)+4)/3
gen cov_dist01 = ((cov_dist*-1)+4)/3
gen cov_threat01 = ((cov_threat*-1)+4)/3

gen cov_mask01 = (cov_mask-1)/3
gen cov_faith01 = (cov_faith-1)/3
gen cov_econ01 = (cov_econ-1)/3

gen cov_part01 = ((cov_part*-1)+4)/3
gen cov_censor01 = (cov_censor-1)/3

label var cov_advice01 "Experts give good advice"
label var cov_threat01 "COVID threat"
label var cov_dist01 "R social distance"

label var cov_mask01 "Masks not threaten freedom"
label var cov_faith01 "Limits not threaten faith"
label var cov_econ01 "Shutdown not threaten economy"

label var cov_part01 "Other party disagree with me"
label var cov_censor01 "Should not censor COVID info"

label define disagree1 1 "1.Disagree strongly" 0 "0.Agree strongly" , replace
label values cov_econ01 cov_dist01 cov_threat01 cov_censor01 disagree1 

label define agree1 0 "0.Disagree strongly" 1 "1.Agree strongly" , replace
label values cov_advice01 cov_dist01 cov_threat01 cov_part01 agree1

note cov_threat:  Agree: I believe that the novel coronavirus (Covid-19) poses a threat to the health and safety of myself and my family
note cov_threat01:  Agree: I believe that the novel coronavirus (Covid-19) poses a threat to the health and safety of myself and my family
note cov_dist: Agree: I have continued to socially distance to prevent the spread of Covid-19, even after my state has lifted stay-at-home orders
note cov_dist01: Agree: I have continued to socially distance to prevent the spread of Covid-19, even after my state has lifted stay-at-home orders
note cov_advice01: Agree: I believe public health experts are giving good advice about Covid-19
note cov_advice: Agree: I believe public health experts are giving good advice about Covid-19
note cov_econ: Disagree: Shutting down the economy is too high of a cost to prevent the spread of Covid-19
note cov_econ01: Disagree: Shutting down the economy is too high of a cost to prevent the spread of Covid-19
note cov_mask: Disagree: Orders requiring me to wear a mask in all public spaces to prevent the spread of Covid-19 threaten my basic freedoms
note cov_mask01: Disagree: Orders requiring me to wear a mask in all public spaces to prevent the spread of Covid-19 threaten my basic freedoms
note cov_faith: Disagree: Orders prohibiting large gatherings to prevent the spread of Covid-19 are a threat to people's ability to practice their faith
note cov_faith01: Disagree: Orders prohibiting large gatherings to prevent the spread of Covid-19 are a threat to people's ability to practice their faith

note cov_part: Agree: People who support a different party than I do probably disagree with me about what we should do about Covid-19
note cov_censor: Disagree: The government should be able to censor what pundits and media personalities can say about Covid-19

note cov_part01: Agree: People who support a different party than I do probably disagree with me about what we should do about Covid-19
note cov_censor01: Disagree: The government should be able to censor what pundits and media personalities can say about Covid-19


* Mean index: Taking COVID seriously 
egen cov_serious01 = rowmean (cov_advice01 cov_dist01 cov_threat01 )
label var cov_serious01 "Takes COVID seriously"
note cov_serious01: "Takes COVID seriously: advice, socially distance, COVID threat to safety

// alpha cov_advice01 cov_dist01 cov_threat01, item 
// alpha = .8


* Mean index: Support for COVID regulations 
egen cov_reg01 = rowmean (cov_econ01 cov_mask01 cov_faith01 )
label var cov_reg01 "Support COVID regulations"
note cov_serious01: Support COVID regulations: not too high price: economic shut down, masks, limit faith gatherings 

// alpha cov_econ01 cov_mask01 cov_faith01, item
// alpha = .76

corr cov_reg01 cov_serious01


corr  CUB3J01 cov_threat cov_threat01
corr  CUB3J02 cov_dist cov_dist01
corr  CUB3J04 cov_advice cov_advice01

corr  CUB3J03 cov_econ cov_econ01
corr  CUB3J05 cov_mask cov_mask01
corr  CUB3J07 cov_faith cov_faith01

corr  CUB3J08 cov_censor cov_censor01 
corr  CUB3J06 cov_part cov_part01

sum  CUB3J01 cov_threat cov_threat01
sum  CUB3J02 cov_dist cov_dist01
sum  CUB3J04 cov_advice cov_advice01

sum  CUB3J03 cov_econ cov_econ01
sum  CUB3J05 cov_mask cov_mask01
sum  CUB3J07 cov_faith cov_faith01

sum  CUB3J08 cov_censor cov_censor01 
sum  CUB3J06 cov_part cov_part01

* alpha = .75 



                    ****************************************                    
					 * Support for universal health care  *
                    ****************************************
// CC20_327a CC20_327b CC20_327c CC20_327d CC20_327e CC20_327f
// healthcare01 health_medall01  health_medage01 health_supaca01 health_mand01

**Support for health care interventions  
	*varname: health_medall01  health_medage01 health_supaca01 health_mand01

* CC20_327a	Expand Medicare to a single comprehensive public health care coverage program that would cover all Americans.
* CC20_327b	Allow the government to negotiate with drug companies to get a lower price on prescription drugs that would apply to both Medicare and private insurance. Maximum negotiated price could not exceed 120% of the average prices in 6 other countries. 
* CC20_327c	Lower the eligibility age for Medicare from 65 to 50.
* CC20_327d	Repeal the entire Affordable Care Act.
* CC20_327e	Restore the Affordable Care Act's mandate that all individuals be required to purchase health insurance.
* CC20_327f	Allow states to import prescription drugs from other countries.  


* This is weird because there are a ton of people who want to appeal the ACA, but also want medicare for all.
* Health Care | Health Care -- Expand
*    -- Repeal | Medicare to a single
*   the entire | comprehensive public
*   Affordable |   health care cove
*    Care Act. |   Support     Oppose |     Total
* -------------+----------------------+----------
*      Support |       151        272 |       423 
*       Oppose |       464        109 |       573 
* -------------+----------------------+----------
*        Total |       615        381 |       996

* b and f do not correlate with the others, and do not correlate with each other.
* b is ridiculous question wording 

* CC20_327c d e and a correlate, with d reversed  

* It seems like a good idea to Guttman scale this one 
* because so many people want Medicare for all, 
* which is the biggest government option, and logically includes the others. 
* Yet many of those who want Medicare for all do not want other government action. 

* 15% of these respondents want the ACA repealed, but also want Medicare for all.
* 27% actually want no ACA and no Medicare for all. 

* corr CC20_327a  CC20_327c CC20_327d CC20_327e 
* (obs=992)
* 
*              | CC2~327a CC2~327c CC2~327d CC2~327e
* -------------+------------------------------------
*    CC20_327a |   1.0000
*    CC20_327c |   0.5502   1.0000
*    CC20_327d |  -0.4628  -0.3476   1.0000
*    CC20_327e |   0.3969   0.2673  -0.3773   1.0000

* Reminder: Support = 1, oppose = 2 

recode CC20_327a 	(1=1 "1.Support Medicare for all" ) ///
					(2=0 "0.Oppose Medicare for all") , generate (health_medall01)
recode CC20_327c 	(1=1 "1.Support lowering age" ) ///
					(2=0 "0.Oppose lowering age") , generate (health_medage01)
recode CC20_327d 	(2=1 "1.Support ACA" ) ///	
					(1=0 "0.Repeal ACA") , generate (health_supaca01)
recode CC20_327e 	(1=1 "1.Support ACA mandate" ) ///
					(2=0 "0.Oppose ACA mandate") , generate (health_mand01)

egen healthcare01 = rowmean(health_medall01  health_medage01 health_supaca01 health_mand01)
label var healthcare01 "Support for universal health care"



corr health_medall01 health_medage01 health_mand01 health_supaca01

* health_m~l01 |   1.0000
* health_m~e01 |   0.5502   1.0000
* health_ma~01 |   0.3969   0.2673   1.0000
* health_su~01 |   0.4628   0.3476   0.3773   1.0000* 



* alpha health_medall01 health_medage01 health_mand01 health_supaca01, item

*                              item-test     item-rest       interitem
* Item         |  Obs  Sign   correlation   correlation     covariance      alpha
* -------------+-----------------------------------------------------------------
* health_m~l01 |  998    +       0.8105        0.6281        .0793503      0.5959
* health_m~e01 |  998    +       0.7262        0.4921        .0990503      0.6772
* health_ma~01 |  996    +       0.6897        0.4365        .1077695      0.7109
* health_su~01 |  998    +       0.7381        0.5062        .0961845      0.6704
* -------------+-----------------------------------------------------------------
* Test scale   |                                             .0955913      0.7263
* -------------------------------------------------------------------------------



egen health_aca01 = rowmean (health_supaca01 health_mand01)
egen health_medicare01 = rowmean (health_medall01 health_medage01)


                    ****************************************                    
					 * Confused about health care policy  *
                    ****************************************

* note that it is easier to be consistent about Medicare, so people who were inconsistent on Medicare were coded as more confused 

* People who are consistent about Medicare but inconsistent about the ACA are more supportive of health care interventions overall 


gen health_confused = 0 if (health_aca == 1 & health_medicare ==1) | ///
(health_aca == 0 & health_medicare ==0)

replace health_confused = 1 if ((health_aca == 1 & health_medicare ==0) | /// consistent about Medicare and ACA not gov intervention 
(health_aca == 0 & health_medicare ==1))

replace health_confused = 2 if (health_aca == .5)  & /// confused about ACA, consistent about Medicare rules
((health_medicare ==1) | ( health_medicare ==0))

replace health_confused = 3 if (health_medicare  == .5)  & /// confused about  Medicare rules , consistent about ACA
((health_aca ==1) | ( health_aca ==0))

replace health_confused = 4 if (health_aca == .5 & health_medicare == .5) 
tab health_confused
tab health_aca health_medicare if health_confused ==.


recode health_confused 	(0=0 "0.Internally consistent about health care" ) /// 
						(1=1 "1.Consist Medicare; Consist ACA, but inconsistent about gov intervention") /// 
						(2=2 "2.Inconsistent about ACA, consistent about Medicare rules" ) /// 
						(3=3 "3.Inconsistent about  Medicare rules , consistent about ACA") /// 
						(4=4 "4.Inconsistent about  both Medicare rules and ACA") , generate (health_confused2)



* With this Guttman scale, I made a choice to rank medicare support as higher support

gen health_guttman = 6 if (health_aca == 1 & health_medicare ==1) 
replace health_guttman = 5 if ( health_aca == .5 & health_medicare ==1 ) 
replace health_guttman = 4 if ( health_aca == 1 & health_medicare ==.5 ) 
replace health_guttman = 3 if ( health_aca == .5 & health_medicare ==.5 )
replace health_guttman = 2 if ( health_aca == 0 & health_medicare ==.5 ) 
replace health_guttman = 1 if ( health_aca == .5 & health_medicare ==0 )
replace health_guttman = 0 if (health_aca == 0 & health_medicare ==0)


* r = .99, so no need for Guttman 


*
* Support for gun control * 
*
// CC20_330b CC20_330c

// in both gun_arban01 gun_conceal01
// in both 2020 and 2016 but not in gun control index gun_pub01
// not in 2020 gun_background
* Reminder: Support = 1, oppose = 2 

	*varname: gun_control01 gun_arban01 gun_conceal01  (gun_pub01 not in index)

* Note: Higher numbers indicate a stronger preference for gun control measures * 


// in both 
//Prohibit state and local governments from publishing the names and addresses of all gun owners
recode CC20_330a	(1=0 "0. Support")	///
					(2=1 "1. Oppose"), generate(gun_pub01)
note gun_pub01: Opposes prohibiting state and local governments from publishing the names and addresses of all gun owners
label var gun_pub01 "Opposes publishing names of gun owners"

// in both and in index 
//Ban assault rifles
recode CC20_330b	(1=1 "1. Support")	///
					(2=0 "0. Oppose"), generate(gun_arban01)
note gun_arban01: Supports ban on assault rifles
label var gun_arban01 "Supports ban on assault rifles"

//Make it easier for people to obtain concealed-carry permit
recode CC20_330c	(1=0 "0. Support")	///
					(2=1 "1. Oppose"), generate(gun_conceal01)
note gun_conceal01: Opposes making it easier for people to obtain concealed-carry permits
label var gun_conceal01 "Opposes concealed-carry"


egen gun_control01 =rowmean( gun_arban01 gun_conceal01)
note gun_control01: Mean support for gun control measures (0 to 1)
label var gun_control01 "Support gun control"






                    ****************************************                    
					 * Support for abortion  *
                    ****************************************
				

tab CC20_332a 
tab CC20_332b 	
tab CC20_332c 	
tab CC20_332d 	
tab CC20_332e 	

corr CC20_332a CC20_332b CC20_332c CC20_332d CC20_332e CC20_332f

* (obs=1,000)
* 
*              | CC2~332a CC2~332b CC2~332c CC2~332d CC2~332e
* -------------+---------------------------------------------
*    CC20_332a |   1.0000
*    CC20_332b |  -0.4570   1.0000
*    CC20_332c |  -0.4629   0.3717   1.0000
*    CC20_332d |  -0.5419   0.3439   0.4966   1.0000
*    CC20_332e |  -0.5399   0.4006   0.5322   0.7046   1.0000  
* 	 CC20_332f |  -0.3046   0088   0.2420   0.3713   0.3282   1.0000


* CC20_332a	Always allow a woman to obtain an abortion as a matter of choice
* CC20_332b	Permit abortion only in case of rape, incest or when the woman's life is in danger
* CC20_332c	Prohibit all abortions after the 20th week of pregnancy
* CC20_332d	Allow employers to decline coverage of abortions in insurance plans
* CC20_332e	Prohibit the expenditure of funds authorized or appropriated by federal law for any abortion.
* CC20_332f	Make abortions illegal in all circumstances

// In 2020 but not 2016
* CC20_332g Prohibit states from requiring that abortions be performed only at hospitals (not clinics).


* CC16_332a Always allow a woman to obtain an abortion as a matter of choice
* CC16_332b Permit abortion only in case of rape, incest or when the woman's life is in danger
* CC16_332c Prohibit all abortions after the 20th week of pregnancy
* CC16_332d Allow employers to decline coverage of abortions in insurance plans
* CC16_332e Prohibit the expenditure of funds authorized or appropriated by federal law for any abortion
* CC16_332f Make abortions illegal in all circumstances



* note CC20_332b is confusing because it says only, so opposed might oppose abortion in this case, but also might oppose because of "only"		


* People misread what was intended by item 2: we want to isolate the 285 respondents who say they oppose the right to choose
* but support in cases of rape and incest 

*Abortion -- |
* Always allow |
*   a woman to |  Abortion -- Permit
*    obtain an | abortion only in case
*  abortion as |  of rape, incest or
*  a matter of | when the woman's lif
*       choice |   Support     Oppose |     Total
* -------------+----------------------+----------
*      Support |       150        450 |       600 
*       Oppose |       285        115 |       400 
* -------------+----------------------+----------
*        Total |       435        565 |     1,000


* Reminder: Support = 1, oppose = 2 

* Code all with support for abortion high except abo_none; otherwise it is confusing. Abo none is when not even rape and incest


	


* Now, make the scale normally such that people who want abortion in all circumstances are moderated by wanting to allow some restrictions
* Then, afterwards, you can Guttman scale it 

	
	// Always allow a woman to obtain an abortion as a matter of choice
recode CC20_332a (1=1 "1.Always allow") (2=0 "0.Not always allow"), generate(abo_always)
label variable abo_always "Allow abortion in all cases"

		// Make abortion illegal in all circumstances
recode CC20_332f (1=0 "0.Always illegal") (2=1 "1.Not always be illegal"), generate(abo_some)
label variable abo_some "Allow in some circumstances"

recode CC20_332b (1=0 "0.Support if rape/incest") (2=1 "1.Oppose if rape/incest"), generate(abo_incest)
label variable 	abo_incest "Flawed CCES incest question"
	
gen abo_incest2 = 0
replace abo_incest2 = 1 if abo_always == 0 & abo_incest == 1
label variable abo_incest2 "Only in cases of incest"
tab abo_incest2

tab abo_incest2 abo_some	

corr abo_incest2 abo_some abo_always
	
	
	* now we have to identify those who say never and also say no to incest 
gen abo_never = 0
replace abo_never = 1 if abo_some == 0 & abo_incest2  == 0
label variable abo_never "Never legal"

recode abo_never (0=1 "1.Not never") (1=0 "0.Never"), gen (abo_not_never)
label variable abo_never "Not never legal"


gen abo_nev_incest_all = 0 if abo_never == 1
replace abo_nev_incest_all = 1 if abo_incest2 == 1



recode CC20_332c (1=0 "0.Oppose after 20 weeks") (2=1 "1.Support after 20 weeks"), generate(abo_20week)
label variable abo_20week "Allow after 20 weeks"

recode CC20_332d (1=0 "0.Restrict allowed") (2=1 "1.Restrict not allowed"), generate(abo_ins)
label variable abo_ins "Forbid insurance to restrict"

recode CC20_332e (1=0 "0.Forbid funding") (2=1 "1.Support funding"), generate(abo_fund)
label variable abo_fund "Allow abortion funding"

corr  abo_not_never abo_some abo_incest2 abo_always abo_20week abo_ins abo_fund
sum   abo_never abo_some abo_incest2 abo_always abo_20week abo_ins abo_fund

corr  abo_not_never abo_some abo_always abo_20week abo_ins abo_fund
sum   abo_never abo_some abo_always abo_20week abo_ins abo_fund



* abo_incest = 1 with 285 in that category 


egen abo_fund_allow02  = rowtotal ( abo_ins abo_fund )
tab abo_fund_allow02

* abo_fund_al |
*      low02 |      Freq.     Percent        Cum.
* ------------+-----------------------------------
*           0 |        367       36.70       36.70
*           1 |        146       14.60       51.30
*           2 |        487       48.70      1000
* ------------+-----------------------------------
*       Total |      1,000      1000


* The lowest support is after 20 weeks 


* Create a measure called "abo_num_fund" because D and E are about funding and I don't want them overtaking two fifths of the measure

	
gen abo06 = abo_nev_incest_all
* 0 absolutely never
* 1 only rape and incest 

replace abo06 = 2 if (abo_some == 1 & abo_fund_allow02 == 0) 

* 2 sometimes allowed, but support for both funding restrictions  

tab abo06

*      abo06 |      Freq.     Percent        Cum.
*------------+-----------------------------------
*          0 |         83       19.58       19.58
*          1 |         97       22.88       42.45
*          2 |        244       57.55      1000
*------------+-----------------------------------
*      Total |        424      1000


replace abo06 = 3 if (abo_some == 1  & abo_fund_allow02 == 1  ) 

tab abo06

replace abo06 = 4 if (abo_some == 1  & abo_fund_allow02 == 2  ) 

tab abo06

replace abo06 = 5 if abo_always == 1 &  abo_20week == 0 & abo_fund_allow02 == 2

tab abo06

replace abo06 = 6 if abo_always == 1  &  abo_20week == 1 & abo_fund_allow02 == 2
 	
	tab abo06
	
*	0 Never allow abortions, even in cases of rape/incest
*	1 Only allow abortions in cases of rape/incest
*	2 Allow some abortions as a matter of choice but also allow both funding restrictions 
*	3 Allow some abortions as a matter of choice but with one funding restriction 
*	4 Allow some abortions as a matter of choice and no funding restrictions 
*	5 Allow abortion as a matter of choice, no funding restrictions, but not after 20 weeks 
*	6 Allow abortions as a matter of choice, no restrictions 
	
	label define cces_abo_scale /// 
	0 "Never" /// 
	1 "Only if rape/incest" /// 
	2 "Allow some abortions, forbid funding" /// 
	3 "Allow some abortions, one funding" /// 
	4 "Allow some abortions and funding" /// 
	5 "Allow abortion, but not after 20 weeks"  /// 
	6 "Allow all abortion and funding" 
	
label values abo06 cces_abo_scale

* Check to make sure 31% say no restrictions

egen abo_check = rowmean (abo_ins abo_fund abo_always abo_20week)				
tab abo_check	

*           0 |        259       25.90       25.90
*         .25 |        139       13.90       39.80
*          .5 |        108       10.80       50.60
*         .75 |        183       18.30       68.90
*           1 |        311       310      1000

*           0 |         44        4.40        4.40
*           1 |         72        7.20       11.60
*           2 |        174       17.40       29.00
*           3 |        130       13.00       42.00
*           4 |        137       13.70       55.70
*           5 |        132       13.20       68.90
*           6 |        311       310      1000
	
gen abo01 = abo06/6
label var abo01  "Support for abortion"
	
	
                    ****************************************                    
					 * Support for environment  *
                    ****************************************
// CC20_333a CC20_333b CC20_333c CC20_333d CC20_355a CC20_355c 
// env_carbon01 env_fuel01 env_ren01 env_clean01 climate01 clean_power01 env01 

* Reminder: Support = 1, oppose = 2 
* CC20_333	Environmental Policies
* 
* CC20_333a	Give the Environmental Protection Agency power to regulate Carbon Dioxide emissions
* 
* CC20_333b	Require that each state use a minimum amount of renewable fuels (wind, solar, and hydroelectric) in the generation of electricity even if electricity prices increase a little
* 
* CC20_333c	Strengthen the Environmental Protection Agency enforcement of the Clean Air Act and Clean Water Act even if it costs U.S. jobs
* 
* CC20_333d	Raise the average fuel efficiency for all cars and trucks in the US from 40 miles per gallon to 54.5 miles per gallon by 2025. 
		// in 2016: from 25mpg to 35 mpg

// CC16_333b is similar but not the same CC20_333d
// 
//	CC16_333a 	CC20_333a 	Give Environmental Protection Agency power to regulate co2 emissions
//	CC16_333b 	CC20_333d	Raise required fuel efficiency for the average automobile 
//	CC16_333c 	CC20_333b	Require a minimum amount of renewable fuels (wind, solar, and hydroelectric) in the generation of electricity even if electricity prices increase somewhat
//	CC16_333d 	CC20_333c	Strengthen enforcement of the Clean Air Act and Clean Water Act even if it costs US jobs


**Environment Policies**
	*Note: Higher numbers indicate stronger support for protecting the environment*
	// Give Environmental Protection Agency power to regulate
		// Carbon Dioxide emissions
recode CC20_333a 	(1=1 "1.Support") ///
					(2=0 "0.Oppose"), generate(env_carbon01)
label var env_carbon01 "Regulate CO2"
	
	// Raise required fuel efficiency for the average automobile
		// from 40 mpg to 54 mpg
recode CC20_333d 	(1=1 "1.Support") ///
					(2=0 "0.Oppose"), generate(env_fuel01)
label var env_fuel01 "Raise fuel efficiency"	
	
	// Require a minimum amount of renewable fuels (wind, solar,
		// hydroelectric) in the generation of electricity even if
		// electricity prices increase somewhat
recode CC20_333b 	(1=1 "1.Support") ///
					(2=0 "0.Oppose"), generate(env_ren01)
label var env_ren01 "Renewable electricity"
	
	// Strengthen enforcement of the Clean Air Act and Clean Water Act
		// even if it costs US jobs
recode CC20_333c 	(1=1 "1.Support") ///
					(2=0 "0.Oppose"), generate(env_clean01)
label var env_clean01 "Clean air and water Acts"




// other - not in 2016 
recode CC20_355a 	(1=0 "0.Support") ///
					(2=1 "1.Oppose") , generate (climate01)
label var climate01 "Not withdraw Paris Climate Agreement" 

recode CC20_355c 	(1=0 "0.1.Support") ///
					(2 = 1 "1.Oppose") , generate (clean_power01)
label var clean_power01 "Not repeal Clean Power Rules" 


sum env_carbon01 env_fuel01 env_ren01 env_clean01 climate01 clean_power01
corr env_carbon01 env_fuel01 env_ren01 env_clean01 climate01 clean_power01
alpha env_carbon01 env_fuel01 env_ren01 env_clean01 climate01 clean_power01, item 




	
egen env01=rowmean(env_carbon01 env_fuel01 env_ren01 env_clean01 climate01 clean_power01)

note env01 : Mean support for pro-environment policies (0 to 1)
label var env01 "Pro-environment"
tab env01 
	
				
                    ****************************************                    
					      * Support for immigration  *
           ****************************************
// CC20_331a CC20_331b CC20_331c CC20_331e CC20_331d CC20_442c CC20_442d CC20_350e
// imm_amnesty01; imm_agents01; imm_dream01 imm_sanctuary01; imm_wall01; imm_legal01; imm_em_wall01; imm_asylum01

// in 2020, not in 2016: imm_sanctuary01; imm_wall01; imm_legal01; imm_em_wall01; imm_asylum01
// In 2016, not in 2020: imm_deport01
// In both: imm_amnesty01; imm_agents01; imm_dream01


// These are in 2020 but not 2016 
recode CC20_331c 	(2=1 "1.Support sanctuary" ) /// 
					(1=0 "0.Oppose sanctuary") , 			generate (imm_sanctuary01)
recode CC20_331e 	(2=1 "1.Oppose border wall" ) /// 
					(1=0 "0.Support border wall") , 		generate (imm_wall01)
recode CC20_331d 	(2=1 "1.Support legal immigration" ) /// 
					(1=0 "0.Reduce legal immigration") , 	generate (imm_legal01)

label var imm_wall01		"Oppose wall"
label var imm_sanctuary01	"Support sanctuaries"
label var imm_legal01		"Support legal immigration"

note  imm_sanctuary01: Withhold federal funds from any local police department that does not report to the federal government anyone they identify as an illegal immigrant
note  imm_legal01:	Reduce <u>legal</u> immigration by eliminating the visa lottery and ending family-based migration.
note  imm_wall01:	Increase spending on border security by $25 billion, including building a wall between the U.S. and Mexico.





* CC20_442c Declare a national emergency to permit construction of border wall with Mexico
* CC20_442d Suspend a program that allows migrants to remain in the US while their asylum cases were being decided.

recode CC20_442c 	(2=1 "1.Oppose emergency wall" ) /// 
					(1=0 "0.Support emergency wall") , generate (imm_em_wall01)
label var imm_em_wall01	"Declare national emergency: wall"
note  imm_em_wall01: 	Declare a national emergency to permit construction of border wall with Mexico

recode CC20_442d 	(2=1 "1.Oppose asylum in U.S" ) /// 
					(1=0  "0.Support asylum in U.S") , generate (imm_asylum01)
label var imm_asylum01	"Suspend asylum in U.S."
note  imm_asylum01: Suspend a program that allows migrants to remain in the US while their asylum cases were being decided




// In both
recode CC20_331a 	(1=1 "1.Support amnesty" ) /// 
					(2=0 "0.Oppose amnesty") , generate (imm_amnesty01)
recode CC20_331b 	(2=1 "1.Oppose increase border agents" ) /// 
					(1=0 "0.Support increase border agents") , generate (imm_agents01)
recode CC20_350e 	(1=1 "1.Support dreamers") /// 
					(2=0 "0.Oppose dreamers") , generate (imm_dream01) 

label var imm_amnesty01 "Amnesty"
note  imm_amnesty01 :	Grant legal status to all illegal immigrants who have held jobs and paid taxes for at least 3 years, and not been convicted of any felony crimes.
label var imm_agents01 " Oppose increase border agents "
note  imm_agents01 :	Increase the number of border patrols on the US-Mexican border.
label var imm_dream01 " Residency to dreamers "
note  imm_dream01 :	Provide permanent resident status to children of immigrants who were brought to the United States by their parents (also known as Dreamers). Provide these immigrants a pathway to citizenship if they meet the citizenship requirements and commit no crimes.

egen imm01 = rowmean(imm_amnesty01 imm_agents01 imm_dream01 imm_sanctuary01 imm_wall01 imm_legal01 imm_em_wall01 imm_asylum01 )
label var imm01 "Support for immigration"

                    ****************************************                    
					 * Support free trade   *
                    ****************************************
// CC20_338a CC20_338b CC20_338c CC20_338d CC20_355b

* Reminder: Support = 1, oppose = 2 


* On the issue of trade, do you support or oppose the following proposed tariffs?


* Tariffs on $200 billion worth of goods imported from China
* 25% tariffs on imported steel and 10% on imported aluminum, EXCEPT from Canada and Mexico.
* 25% tariffs on all imported steel and 10% on imported aluminum, INCLUDING from Canada and Mexico.
* Increase tariffs on European aircraft and agricultural products. 

corr CC20_338a CC20_338b CC20_338c CC20_338d

recode CC20_338a (1=0 "0.Oppose tariff"  ) (2=1 "1.Support tariff") , generate (tar_china01)
label var tar_china "Oppose tariffs on goods from China"

recode CC20_338b (1=0 "0.Oppose tariff"  ) (2=1 "1.Support tariff")  , generate (tar_notam01)
label var tar_notam "Oppose tariffs on steel, alum. except North America"


recode CC20_338c (1=0 "0.Oppose tariff"  ) (2=1 "1.Support tariff")  , generate (tar_am01)
label var tar_am "Oppose tariffs on steel, alum. including North America"


recode CC20_338d (1=0 "0.Oppose tariff"  ) (2=1 "1.Support tariff")  , generate (tar_eu01)
label var tar_eu "Oppose tariffs on EU aircraft and agricultural goods"





recode CC20_355b (1=0 "0.Support") (2 = 1 "1.Oppose") , generate (tpp01)
label var tpp01 "Not withdraw TPP trade" 



 
egen trade01 = rowmean(tar_china01 tar_notam01 tar_am01 tar_eu01 tpp01)
label var trade01 "Support for free trade"






********************************************************************************
********************************************************************************
*               Roll call votes   *                                
******************************************************************************
********************************************************************************
// CC20_350c CC20_350f CC20_350g 
// kav01 trump_abuse01 trump_obs01

* Over the past two years, Congress voted on many issues.  Do you support each of the following proposals?

* Amend federal laws to prohibit discrimination on the basis of gender identity and sexual orientation.
* Raise the minimum wage to $15 an hour.
* Confirm Brett Kavanaugh to become a Justice of the Supreme Court of the United States.
* Require equal pay for women and men who are doing similar jobs and have similar qualifications.
* Provide permanent resident status to children of immigrants who were brought to the United States by their parents (also known as Dreamers). Provide these immigrants a pathway to citizenship if they meet the citizenship requirements and commit no crimes.
* Remove President Trump from office for abuse of power 
* Remove President Trump from office for obstruction of Congress



* liberal view coded high 


 recode CC20_350c (1=0 "0.Support") (2 = 1 "1.Oppose") , generate (kav01)
label var kav01 "Confirm Kavanaugh" 


recode CC20_350f (1=1 "1.Support") (2 = 0 "0.Oppose") , generate (trump_abuse01)
label var trump_abuse01 "Remove Trump for abuse of power "

recode CC20_350g (1=1 "1.Support") (2 = 0 "0.Oppose") , generate (trump_obs01)
label var trump_obs01 "Remove Trump for obstruction"

corr trump_obs01 trump_abuse01
* r = .91 



// CC20_350d CC20_350a CC20_355d 
//gendpay01 gay01 trans01

recode CC20_350d (1=1 "1.Support") (2 = 0 "0.Oppose") , generate (gendpay01) 
label var gendpay01 "Equal pay for women" 
recode CC20_350a (1=1 "1.Support") (2 = 0 "0.Oppose") , generate (gay01)
label var gay01 "Prohibit LGBTQ discrimination" 


recode CC20_355d (1=0 "0.Support") (2 = 1 "1.Oppose") , generate (trans01)
label var trans01 "Not ban trans military" 


corr gendpay01 gay01 trans01


// CC20_351a CC20_351b 
// cares01 heroes01


* CC20_351		Stimulus bills

* In March, the CARES Act proposed to spend $2 trillion in emergency and health care assistance for individuals, families, and businesses, including up to $1,200 per individual and $500 per child.
 
* In May, the HEROES ACT proposed to spend an additional $3 trillion, including $1 trillion for state and local governments and hospitals, spend $200 billion in hazard pay for essential workers, and give households an additional $1,200 to $6,000.

 recode CC20_351a (1=1 "1.Support") (2 = 0 "0.Oppose") , generate (cares01)
label var cares01 "Support CARES Act" 


 recode CC20_351b (1=1 "1.Support") (2 = 0 "0.Oppose") , generate (heroes01)
label var cares01 "Support HEROES Act" 

* wage01 and food_stamps01 are correlated
* cares and heroes is correlated 


// CC20_355e CC20_350b
// wage01 food_stamps01 

recode CC20_355e (1=0 "0.Support") (2 = 1 "1.Oppose") , generate (food_stamps01)
label var food_stamps01 "Not require job for food stamps" 


recode CC20_350b (1=1 "1.Support") (2 = 0 "0.Oppose") , generate (wage01)
label var wage01 "Minimum wage at $15" 








**********************************************************************************************************
* Additional indexes   *                           
**********************************************************************************************************
// trust_eff01 care_think01 empathy01 super01 pol_under_educ01


egen trust_eff01 = rowmean ( exteff01 trust_gov01 )
egen care_think01 = rowmean (success01 socsen_good01)
egen empathy01 = rowmean (share01 socsen_stranger01)
egen super01 = rowmean ( seeself_country01 super_care01)
egen pol_under_educ01 = rowmean (pol_interest01 inteff01 knows_control01 aware01 educ01  )
 egen pol_understand01 = rowmean (pol_interest01 inteff01 knows_control01 aware01 )
egen att_ac_attend01 = rowmean (ac_attend01 attend01 )
egen ac_cons01 = rowmean (  ac_gun01 ac_trump01 ac_pol01 ac_mil01 )
egen   ac_disadvant01 = rowmean (ac_lgbt01  ac_imm01 ac_muslim01 ac_black01 )
egen ac_gov01 = rowmean (	  ac_govern01 ac_office01 ac_early01  ac_run01 )




		 






* Addenda and new indices 






gen out5 = 1 if (out01 >= 0 & out01 <.2)
replace out5 = 2 if (out01  > .2 & out01 <.25 )

replace out5 = 3 if (out01  > .3 & out01 <.45 )
replace out5 = 4 if (out01 >= .5 & out01 <.6)
replace out5 = 5 if (out01 >= .6 )

label var out5 "Locus of control"
label define out5 1 "High internal" 2 "Somewhat internal" 3 "A little of both"  4 "Somewhat external" 5 "High external", replace
label values out5 out5
       

recode	cov_threat01															///
					(0 / .3 = 1 "Not at all supportive")											///
					(.3001 / .5 = 2 "Not very supportive")								///
					(.6001 / .8 = 4 "Somewhat supportive")								///
					(.8001 / 1 = 5 "Very supportive") , generate ( cov_threat_4cat)
					
					
recode	cov_dist01															///
					(0 / .3 = 1 "Not at all supportive")											///
					(.3001 / .5 = 2 "Not very supportive")								///
					(.6001 / .8 = 4 "Somewhat supportive")								///
					(.8001 / 1 = 5 "Very supportive") , generate ( cov_dist_4cat)					
					
recode	cov_advice01															///
					(0 / .3 = 1 "Not at all supportive")											///
					(.3001 / .5 = 2 "Not very supportive")								///
					(.6001 / .8 = 4 "Somewhat supportive")								///
					(.8001 / 1 = 5 "Very supportive") , generate ( cov_advice_4cat)					
					
recode	cov_econ01															///
					(0 / .3 = 1 "Not at all supportive")											///
					(.3001 / .5 = 2 "Not very supportive")								///
					(.6001 / .8 = 4 "Somewhat supportive")								///
					(.8001 / 1 = 5 "Very supportive") , generate ( cov_econ_4cat)					
					
recode	cov_mask01															///
					(0 / .3 = 1 "Not at all supportive")											///
					(.3001 / .5 = 2 "Not very supportive")								///
					(.6001 / .8 = 4 "Somewhat supportive")								///
					(.8001 / 1 = 5 "Very supportive") , generate ( cov_mask_4cat)					
					
recode	cov_faith01															///
					(0 / .3 = 1 "Not at all supportive")											///
					(.3001 / .5 = 2 "Not very supportive")								///
					(.6001 / .8 = 4 "Somewhat supportive")								///
					(.8001 / 1 = 5 "Very supportive") , generate ( cov_faith_4cat)
					
					
					
					
	recode	cov_threat01															///
					(0 / .3 = 1 "Not at all supportive")											///
					(.3001 / .5 = 2 "Not very supportive")								///
					(.6001 / .8 = 4 "Somewhat supportive")								///
					(.8001 / 1 = 5 "Very supportive") , generate ( cov_threat_4uncat)
					
					
recode	cov_dist01															///
					(0 / .3 = 1 "Not at all supportive")											///
					(.3001 / .5 = 2 "Not very supportive")								///
					(.6001 / .8 = 4 "Somewhat supportive")								///
					(.8001 / 1 = 5 "Very supportive") , generate ( cov_dist_4uncat)					
					
recode	cov_advice01															///
					(0 / .3 = 1 "Not at all supportive")											///
					(.3001 / .5 = 2 "Not very supportive")								///
					(.6001 / .8 = 4 "Somewhat supportive")								///
					(.8001 / 1 = 5 "Very supportive") , generate ( cov_advice_4uncat)					
					
recode	cov_econ01															///
					(0 / .3 = 1 "Not at all supportive")											///
					(.3001 / .5 = 2 "Not very supportive")								///
					(.6001 / .8 = 4 "Somewhat supportive")								///
					(.8001 / 1 = 5 "Very supportive") , generate ( cov_econ_4uncat)					
					
recode	cov_mask01															///
					(0 / .3 = 1 "Not at all supportive")											///
					(.3001 / .5 = 2 "Not very supportive")								///
					(.6001 / .8 = 4 "Somewhat supportive")								///
					(.8001 / 1 = 5 "Very supportive") , generate ( cov_mask_4uncat)					
					
recode	cov_faith01															///
					(0 / .3 = 1 "Not at all supportive")											///
					(.3001 / .5 = 2 "Not very supportive")								///
					(.6001 / .8 = 4 "Somewhat supportive")								///
					(.8001 / 1 = 5 "Very supportive") , generate ( cov_faith_4uncat)				
					
					

label var cov_advice_4uncat "Experts give good advice"
label var cov_dist_4uncat "R social distance"
label var cov_econ_4uncat "Shutdown not threaten economy"
label var cov_faith_4uncat "Limits not threaten faith"
label var cov_mask_4uncat "Masks not threaten freedom"
label var cov_threat_4uncat "COVID threat"
					
label var cov_advice_4cat "Experts give good advice"
label var cov_dist_4cat "R social distance"
label var cov_econ_4cat "Shutdown not threaten economy"
label var cov_faith_4cat "Limits not threaten faith"
label var cov_mask_4cat "Masks not threaten freedom"
label var cov_threat_4cat "COVID threat"
					
					
recode	cfFed																	///
					(0 / .4 = 1 "High trust")									///
					(.4001 / .6 = 2 "Medium") 									///
					(.6001 / 1 = 3 "Low trust") , generate ( cfFed_3uncat)

recode	cfState																	///
					(0 / .4 = 1 "High trust")									///
					(.4001 / .6 = 2 "Medium") 									///
					(.6001 / 1 = 3 "Low trust") , generate ( cfState_3uncat)
					
recode	cfLocal																	///
					(0 / .4 = 1 "High trust")									///
					(.4001 / .6 = 2 "Medium") 									///
					(.6001 / 1 = 3 "Low trust") , generate ( cfLocal_3uncat)					

recode	cfBoard																	///
					(0 / .4 = 1 "High trust")									///
					(.4001 / .6 = 2 "Medium") 									///
					(.6001 / 1 = 3 "Low trust") , generate ( cfBoard_3uncat)					
   					
gen 	cfFed01 = (cfFed-1)	/4
gen 	cfState01 = (cfState-1)	/4
gen 	cfLocal01 = (cfLocal-1)	/4
gen 	cfBoard01 = (cfBoard-1)	/4

label var cfFed_3uncat "Distrust in the federal government"
label var cfState_3uncat "Distrust in the state government"			
label var cfLocal_3uncat "Distrust in the local government"
label var cfBoard_3uncat "Distrust in the local board of elections"


label var cfFed01 "Distrust in the federal government"
label var cfState01 "Distrust in the state government"			
label var cfLocal01 "Distrust in the local government"
label var cfBoard01 "Distrust in the local board of elections"



					
label define	econ_pers_fin_3cat					///
1 "Low"												///
2 "Medium"											///
3 "High", replace 

clonevar age_4cat = age_5cat
label define	age_4cat							///
1 "18-33"											///
2 "34-48"											///
3 "49-64"											///
4 "Above 65", replace 

recode age_4cat (5=4)
label values age_4cat age_4cat

label define educ_3cat 1 "Highschool or less" 2 "Some college" 3 "College degree or more", replace
label values educ_3cat educ_3cat 

 clonevar ac_covid_4cat = ac_covid_5cat
recode ac_covid_4cat (5=4)
 
 
label define	ac_covid_4cat					///
1 "0"	2 "1"										///
3 "2-5"											///
4 "6 or more", replace

label values ac_covid_4cat ac_covid_4cat

corr denres01 femres01 

egen social_dom01 = rowmean (denres01 femres01  )

label var social_dom01 "Social dominance orientation"

egen pident01 = rowmean (seeself_pol01 link_pol01 partisan01 ideolog01 ) 
egen seelink_country01 = rowmean (seeself_country01 link_country01)

egen parties_therm01 = rowmean (dem_therm01 rep_therm01)
gen parties_hate01 =  (parties_therm01*-1)+1

label var fin_cond01 "Financial ease"

clonevar rep_fewind01 = rep01
replace rep_fewind01 = .6 if (rep01 == .5 & cons_atts01 > .6)
replace rep_fewind01 = .4 if (rep01 == .5 & cons_atts01 < .4)

egen 

*The purpose of this is to identify the closet partisans 
egen cons_atts01 = rowmean (femres01 denres01 healthcare01 abo01 env_carbon01 env01 imm01 trump_abuse01 trump_obs01 gendpay01 gay01 trans01 cares01 heroes01 wage01)

egen link_class_pol01 = rowmean (link_class01 link_pol01 )
egen att_ac_attend01 = rowmean (ac_attendance01 attend01 )
egen seelink_race01 = rowmean (link_race01     seeself_race01 )
egen fin_cond01 = rowmean (income01 ease400_exp01 )
egen pol_understand01 = rowmean (pol_interest01 inteff01 knows_control01 aware01 )
egen perc_econ01 = rowmean (econ_expect01 econ_friends01)
egen econ_grieve01 = rowmean ( econ_country01 grieve01 )
egen trust_eff01 = rowmean ( exteff01 trust_gov01 )
egen care_think01 = rowmean (success01 socsen_good01)

clonevar  risk01_1 = risk01 

replace risk01_1 = -1 if tookpost2020 ==0 

clonevar  trust_gov01_1 = trust_gov01 

replace trust_gov01_1 = -1 if tookpost2020 ==0 

gen distrust01 = (trust_gov01*-1)+1
clonevar  distrust01_1 = distrust01 

replace distrust01_1 = -1 if tookpost2020 ==0 

label var distrust01 "Distrust in government"
label var distrust01_1 "Distrust in government"

label var care_think01 "Values societal validation"
label var super_care01 "Perception that Americans care about 'people like me'"

label var ac_covid01 "Number in social network who had COVID"


label var rep01 "Republican party identification"
egen empathy01 = rowmean (altruism_01 socsen_stranger01)

egen super01 = rowmean ( seeself_country01 super_care01)

egen pol_under_educ01 = rowmean (pol_interest01 inteff01 knows_control01 aware01 educ01  )
gen dem_culture01 =  (stealth_experts01 *-1)+1				 
  label define icovid_instab4 
  
egen cov_maskfaith01 = rowmean (cov_faith01 cov_mask01 )
label var cov_maskfaith01 "Support masks and distancing"


label var covid_close_sev01 "Effect of COVID on life"


label define covid_close 

clonevar prox_cov_5cat = covid_close_sev
 replace prox_cov_5cat = covid_close_sev+1 if covid_close_sev > 1
 replace prox_cov_5cat = 2 if (covid_close01 ==1 & covid_close_sev < 2)
label define prox_cov_5cat 0 "0.Know no one" 1 "1.Knows someone who got COVID" 2 "2.R got it, know no one who died" 3 "3.Knows someone who died" 4 "4.Family member died" , replace
label values prox_cov_5cat prox_cov_5cat

label define prox_cov3 0 "0.Knows no one" 1 "1.Friend or coworker got COVID" 2 "2.R or family member got COVID" 3 "3.Knows someone who died", replace

recode   covid_close (0=0) (1=1) (2/3 = 2), gen (prox_cov3)
replace prox_cov3 = 3 if prox_cov_5cat>2
replace prox_cov3 = . if year == 2016

label var prox_cov3 "Proximity to the danger of COVID"
label values prox_cov3 prox_cov3


recode prox_cov3 (0=0) (1=1) (2 = 2) (3=4), gen (prox_cov4)
replace prox_cov4 = 3 if (prox_cov3 < 3 & prox_cov_5cat==2)
label define prox_cov4 0 "0.Knows no one" 1 "1.Friend or coworker got COVID" 2 "2.Family member got COVID" 3 "3.R got COVID" 4 "4.Knows someone who died", replace
label values prox_cov4 prox_cov4
label var prox_cov4 "Proximity to the danger of COVID"

gen died_cov = 0 if year ==2020
replace died_cov = 1 if  ((year ==2020) & (CC20_309b_1 == 1 |  CC20_309b_2 ==1 | CC20_309b_3 ==1))

 recode prox_cov4 (0=0) (1/2=1)  (3=2) (4=3) , gen (covid_impact3) 
 label define covid_impact3 0 "0.Knows no one" 1 "1.Knows someone who got" 2 "2.R got COVID" 3 "3.Knows someone who died", replace
label values covid_impact3 covid_impact3
label var covid_impact3 "COVID impact on personal life"
 
 
 
  recode covid_impact3 (0=0) (1=1)  (2/3=2)  , gen (covid_impact2) 
 label define covid_impact2 0 "0.Knows no one" 1 "1.Knows someone who got COVID" 2 "2.R got COVID or knows someone who died", replace
label values covid_impact2 covid_impact2
label var covid_impact2 "COVID impact on personal life"
 
  tabulate covid_impact3, generate(covid_impact_cat)

label var covid_impact_cat1 "Knows no one with COVID"
label var  covid_impact_cat2 "Knows someone who got COVID"
label var  covid_impact_cat3 "R got COVID"
label var  covid_impact_cat4 "Knows someone who died"



label define icovid_instab4 0 "0.No change in last year" 1 "1.Generally not working" 2 "2.Fluctuation in hours" 3 "3.Partial job loss" 4 "4.Unemployed" , replace
label values icovid_instab4 icovid_instab4 

clonevar  = icovid_instab4

recode icovid_instab4 (0=0 "0.Employed") (1=1 "1.Generally not working") (2/3 =2 "2.Job instability") (4 = 3 "3.Lost job") ,  gen (icov_work3)

recode icovid_instab4 (0=0 "0.Employed") (1/3 =2 "2.Other") (4 = 1 "1.Lost job") ,  gen (icov_work2)

label define icovid_instab4 0 "0.No change in last year" 1 "1.Generally not working" 2 "2.Fluctuation in hours" 3 "3.Partial job loss" 4 "4.Unemployed" , replace
label values icovid_instab4 icovid_instab4 

recode genhealth (0/1 = 0) (2/3=1) (4=2), gen (genhealth2)
label define genhealth2 0  "0.Poor or fair" 1 "1.Good or very good" 2 "2.Excellent"
label values genhealth2 genhealth2
label var genhealth2 "General health"

gen internals01 = (out01*-1)+1

label var internals01 "Sense of internal control"

* gen_not_work work_not_change hours part_loss job_loss 

gen gen_not_work = 0
replace gen_not_work = 1 if icovid_instab4 == 1

gen work_not_change = 0
replace work_not_change = 1 if icovid_instab4 == 0

gen hours = 0
replace hours = 1 if icovid_instab4 == 2

gen part_loss = 0
replace part_loss = 1 if icovid_instab4 == 3

gen job_loss = 0
replace job_loss = 1 if icovid_instab4 == 4
	  

label var gen_not_work "Generally not working"
label var work_not_change "No change in last year"
label var hours "Fluctuation in hours (restored)"
label var part_loss "Partial job loss"
label var job_loss "Lost job"

label define job_loss 0 "0.Did not lose job" 1 "1.Lost job in last year"
label values job_loss job_loss 




gen employ2 = 0 if  icovid_instab4 == 0 | icovid_instab4 == 2 | icovid_instab4 == 3
replace employ2 = 1 if icovid_instab4 == 1
replace employ2 = 2 if icovid_instab4 == 4 

label define employ2 0 "0.Did not lose job" 1 "1.Generally not working" 2 "2.Lost job in last year"
label values employ2 employ2 



  tabulate employ2, generate(employ_cat)

label var employ_cat1 "Did not lose job"
label var  employ_cat2 "Generally not working"
label var  employ_cat3 "Lost job in last year"






*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

* Figure X.

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************


*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

* Figure X.

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

* Figure X.

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************


*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

* Figure X.

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************


*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

* Figure X.

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************



*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

* Figure X.

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************


*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

* Figure X.

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************



*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

* Figure X.

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************


*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

* Figure X.

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************


*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

* Figure X.

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************



*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

* Figure X.

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************


*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

* Figure X.

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************


*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************

* Figure X.

*********************************************************************************
*********************************************************************************
*********************************************************************************
*********************************************************************************






********************************************************************************
**# Descriptive statistic tables for Appendix *
********************************************************************************
grstyle clear
  set scheme s2color	// This is Stata's default scheme
grstyle init		
grstyle plotregion dimgray	
grstyle set imesh, horizontal   minor 
grstyle color ci_arealine c2_arealine gs16%0
grstyle gsize axis_title_gap medium
grstyle yesno draw_major_hgrid yes
grstyle yesno grid_draw_min yes
grstyle yesno grid_draw_max yes
grstyle color background white		
grstyle set imesh, horizontal compact minor
grstyle set horizontal     							// set tick labels horizontal  
grstyle set compact     							// overall design compact 
grstyle set noextend 
grstyle set size small: subheading axis_title 		// subtitle and axis title set to small 
grstyle set size vsmall: small_body   				// margin around notes 
grstyle set legend 6, nobox   						//legend position on 6 o'clock, removes box  
grstyle set linewidth medthick: major_grid   			// set grid line thickness to thin 
grstyle set linewidth medium: tick          			// set tick thickness to thin 
grstyle set linewidth thin: axisline         		// set axislines thickness to thin 
grstyle set linewidth vthin: xyline    				// reference line at 0 
graph set window fontface       "Calibri"
grstyle color background white 
grstyle color plotregion gs14 
grstyle linewidth plotregion medium
grstyle color plotregion_line black
grstyle gsize axis_title_gap small											
grstyle symbol p diamond
grstyle symbol p1 square
grstyle symbol p2 diamond
grstyle symbol p3 triangle 
grstyle symbol p4 circle
grstyle symbol p5 triangle
grstyle anglestyle p5symbol 180
grstyle clockdir legend_position     6
grstyle linewidth p   medthick

 grstyle color p "164 118 120 %80" 		// coral 
 
 grstyle color p1 "164 118 120 %80" 	// coral  first 
 grstyle color p2 "132 132 98 %80" 		// gold
 grstyle color p3   "0 46 104 %80" 		// dark blue 
 grstyle color p4 "123 128 161 %80" 	// lavender
 grstyle color p5 "94 156 185 %80" 		// aqua 
 grstyle color p6 "103 103 103 %80" 	// gray
 
 
 grstyle color pmarkfill "164 118 120 %80"		// coral 
 
 grstyle color p1markfill "164 118 120 %80"		// coral 
 grstyle color p2markfill "132 132 98 %80" 		// gold	  
 grstyle color p3markfill   "0 46 104 %80" 		// dark blue 
 grstyle color p4markfill "123 128 161 %80" 	// lavender
 grstyle color p5markfill "94 156 185 %80"		// aqua
 grstyle color p6markfill "103 103 103 %80" 	// gray
 
 grstyle color pline "164 118 120"		// coral 
 
 grstyle color p1line "164 118 120"		// coral 
 grstyle color p2line "132 132 98" 		// gold
 grstyle color p3line   "0 46 104" 		// dark blue 
 grstyle color p4line "123 128 161" 	// lavender
 grstyle color p5line "94 156 185"		// aqua
 grstyle color p6line "103 103 103" 	// gray

 grstyle color pbar "164 118 120 %80"	// coral 
 
 grstyle color p1bar "164 118 120 %80"	// coral 
 grstyle color p2bar "132 132 98 %80" 	// gold
 grstyle color p3bar   "0 46 104 %80" 	// dark blue 
 grstyle color p4bar "123 128 161 %80" 	// lavender
 grstyle color p5bar "94 156 185 %80"	// aqua
 grstyle color p6bar "103 103 103 %80"  // gray
 
 grstyle color pmarkline "164 118 120"		// coral 
 
 grstyle color p1markline "164 118 120"		// coral 
 grstyle color p2markline "132 132 98" 		// gold
 grstyle color p3markline   "0 46 104" 		// dark blue 
 grstyle color p4markline "123 128 161" 	// lavender
 grstyle color p5markline "94 156 185"		// aqua
 grstyle color p6markline "103 103 103" 	// gray


					
********************************************************************************
* Table A1. Values societal validation *
********************************************************************************





pwcorr socsen_good01 success01  	 
local r : display %4.2f `r(rho)'
putdocx table TableA1 = (5,8), border(all, nil) layout(autofitcontents)   		///
	note ("Pearson r = `r'. The valuing of societal validation is indicated by:")	///
	note ("${success01_note1}")			///									
	note ("${socsen_good01_note1}")											
putdocx table TableA1(1,.), border (bottom, double)  height(48pt  , atleast ) 
putdocx table TableA1(1,1) = ("Table A4. Valuing societal validation"), colspan(7) halign(left) 

putdocx table TableA1(2,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA1(3,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA1(4,.),   height(24pt  , atleast ) valign (center)
 
putdocx table TableA1(5,.),   height(5pt  , atleast ) valign (center) border (bottom, single) 


putdocx table TableA1(2,2/4), border (bottom, single) 
putdocx table TableA1(2,6/8), border (bottom, single) 

putdocx table TableA1(2,2) = ("Does not value %"), halign (center) 
putdocx table TableA1(2,3) = ("Values somewhat %"), halign (center)
putdocx table TableA1(2,4) = ("Values a great deal %"), halign (center)
putdocx table TableA1(2,6) = ("Mean"), halign (center)
putdocx table TableA1(2,7) = ("St. dev."), halign (center)
putdocx table TableA1(2,8) = ("N"), halign (center)

svy: tabulate success_3uncat if year ==2020 

putdocx table TableA1(3,1) = (e(rowvlab))

putdocx table TableA1(3,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA1(3,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA1(3,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)


svy: mean success01  if year ==2020 
	estat sd 

putdocx table TableA1(3,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA1(3,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA1(3,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)



svy: tabulate socsen_good_3uncat 

putdocx table TableA1(4,1) = (e(rowvlab))

putdocx table TableA1(4,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA1(4,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA1(4,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)

svy: mean socsen_good01 
	estat sd 

putdocx table TableA1(4,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA1(4,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA1(4,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)



 
 










  
********************************************************************************
* Table A2. Belief that Americans care about people like me  *
********************************************************************************




putdocx sectionbreak 


putdocx table TableA2 = (4,8), border(all, nil) layout(autofitcontents)   		///
	note ("Perception that Americans care about 'people like me' is indicated by:")	///
	note ("${super_care01_note1}")												
putdocx table TableA2(1,.), border (bottom, double)  height(48pt  , atleast ) 
putdocx table TableA2(1,1) = ("Table A5. Perception that Americans care about 'people like me"), colspan(7) halign(left) 

putdocx table TableA2(2,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA2(3,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA2(4,.),   height(24pt  , atleast ) valign (center)
 
putdocx table TableA2(5,.),   height(5pt  , atleast ) valign (center) border (bottom, single) 


putdocx table TableA2(2,2/4), border (bottom, single) 
putdocx table TableA2(2,6/8), border (bottom, single) 

putdocx table TableA2(2,2) = ("Do not care %"), halign (center) 
putdocx table TableA2(2,3) = ("Somewhat care %"), halign (center)
putdocx table TableA2(2,4) = ("Care very much %"), halign (center)
putdocx table TableA2(2,6) = ("Mean"), halign (center)
putdocx table TableA2(2,7) = ("St. dev."), halign (center)
putdocx table TableA2(2,8) = ("N"), halign (center)

svy: tabulate super_care_3uncat 

putdocx table TableA2(3,1) = (e(rowvlab))

putdocx table TableA2(3,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA2(3,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA2(3,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)


svy: mean super_care01  
	estat sd 

putdocx table TableA2(3,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA2(3,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA2(3,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)




  
  
  
  
  
********************************************************************************
* Table A3. Distrust in government  *
********************************************************************************





	
alpha cfFed cfState cfLocal cfBoard, item 	 
local alpha : display %4.2f `r(alpha)'
putdocx table TableA3 = (7,8), border(all, nil) layout(autofitcontents)   		///
note ("Alpha = `alpha'. Distrust in government is an index of distrust in federal, state, and local governments, and the local board of elections")	
putdocx table TableA3(1,.), border (bottom, double)  height(48pt  , atleast ) 
putdocx table TableA3(1,1) = ("Table A6. Distrust in government"), colspan(7) halign(left) 

putdocx table TableA3(2,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA3(3,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA3(4,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA3(5,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA3(6,.),   height(24pt  , atleast ) valign (center)
 
putdocx table TableA3(7,.),   height(5pt  , atleast ) valign (center) border (bottom, single) 


putdocx table TableA3(2,2/4), border (bottom, single) 
putdocx table TableA3(2,6/8), border (bottom, single) 

putdocx table TableA3(2,2) = ("High trust %"), halign (center) 
putdocx table TableA3(2,3) = ("Medium %"), halign (center)
putdocx table TableA3(2,4) = ("Low trust %"), halign (center)
putdocx table TableA3(2,6) = ("Mean"), halign (center)
putdocx table TableA3(2,7) = ("St. dev."), halign (center)
putdocx table TableA3(2,8) = ("N"), halign (center)

svy: tabulate cfFed_3uncat 

putdocx table TableA3(3,1) = (e(rowvlab))

putdocx table TableA3(3,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA3(3,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA3(3,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)


svy: mean cfFed01  
	estat sd 

putdocx table TableA3(3,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA3(3,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA3(3,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)



svy: tabulate cfState_3uncat 

putdocx table TableA3(4,1) = (e(rowvlab))

putdocx table TableA3(4,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA3(4,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA3(4,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)

svy: mean cfState01 
	estat sd 

putdocx table TableA3(4,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA3(4,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA3(4,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)


svy: tabulate cfLocal_3uncat 

putdocx table TableA3(5,1) = (e(rowvlab))

putdocx table TableA3(5,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA3(5,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA3(5,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)

svy: mean cfLocal01 
	estat sd 

putdocx table TableA3(5,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA3(5,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA3(5,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)


  
  
  
  svy: tabulate cfBoard_3uncat 

putdocx table TableA3(6,1) = (e(rowvlab))

putdocx table TableA3(6,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA3(6,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA3(6,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)

svy: mean cfBoard01 
	estat sd 

putdocx table TableA3(6,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA3(6,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA3(6,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)

 
 
 
********************************************************************************
* Table A4. Authoritarianism  *
********************************************************************************





	
putdocx table TableA4 = (4,8), border(all, nil) layout(autofitcontents)   		///
	note ("Authoritarianism is indicated by:")	///
	note ("${obey01_note1}")												
putdocx table TableA4(1,.), border (bottom, double)  height(48pt  , atleast ) 
putdocx table TableA4(1,1) = ("Table A7. Authoritarianism"), colspan(7) halign(left) 

putdocx table TableA4(2,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA4(3,.),   height(24pt  , atleast ) valign (center)

putdocx table TableA4(4,.),   height(5pt  , atleast ) valign (center) border (bottom, single) 


putdocx table TableA4(2,2/4), border (bottom, single) 
putdocx table TableA4(2,6/8), border (bottom, single) 

putdocx table TableA4(2,2) = ("Low %"), halign (center) 
putdocx table TableA4(2,3) = ("Medium %"), halign (center)
putdocx table TableA4(2,4) = ("High %"), halign (center)
putdocx table TableA4(2,6) = ("Mean"), halign (center)
putdocx table TableA4(2,7) = ("St. dev."), halign (center)
putdocx table TableA4(2,8) = ("N"), halign (center)

svy: tabulate obey_3uncat if year ==2020 

putdocx table TableA4(3,1) = (e(rowvlab))

putdocx table TableA4(3,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA4(3,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA4(3,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)


svy: mean obey01  if year ==2020 
	estat sd 

putdocx table TableA4(3,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA4(3,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA4(3,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)




  

********************************************************************************
* Table A5. Tendency to take risks  *
********************************************************************************




putdocx sectionbreak 
	
putdocx table TableA5 = (4,8), border(all, nil) layout(autofitcontents)   		///
	note ("Tendency to take risks is indicated by:")	///
	note ("${risk01_note1}")												
putdocx table TableA5(1,.), border (bottom, double)  height(48pt  , atleast ) 
putdocx table TableA5(1,1) = ("Table A8. Tendency to take risks"), colspan(7) halign(left) 

putdocx table TableA5(2,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA5(3,.),   height(24pt  , atleast ) valign (center)
 
putdocx table TableA5(4,.),   height(5pt  , atleast ) valign (center) border (bottom, single) 


putdocx table TableA5(2,2/4), border (bottom, single) 
putdocx table TableA5(2,6/8), border (bottom, single) 

putdocx table TableA5(2,2) = ("Low %"), halign (center) 
putdocx table TableA5(2,3) = ("Medium %"), halign (center)
putdocx table TableA5(2,4) = ("High %"), halign (center)
putdocx table TableA5(2,6) = ("Mean"), halign (center)
putdocx table TableA5(2,7) = ("St. dev."), halign (center)
putdocx table TableA5(2,8) = ("N"), halign (center)

svy: tabulate risk_3uncat 

putdocx table TableA5(3,1) = (e(rowvlab))

putdocx table TableA5(3,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA5(3,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA5(3,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)


svy: mean risk01  
	estat sd 

putdocx table TableA5(3,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA5(3,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA5(3,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)




  

********************************************************************************
* Table A6. Subjective sense of health  *
********************************************************************************




	
putdocx table TableA6 = (4,8), border(all, nil) layout(autofitcontents)   		///
	note ("Subjective sense of health is indicated by:")	///
	note ("${genhealth01_note1}")												
putdocx table TableA6(1,.), border (bottom, double)  height(48pt  , atleast ) 
putdocx table TableA6(1,1) = ("Table A9. Subjective sense of health"), colspan(7) halign(left) 

putdocx table TableA6(2,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA6(3,.),   height(24pt  , atleast ) valign (center)
 
putdocx table TableA6(4,.),   height(5pt  , atleast ) valign (center) border (bottom, single) 


putdocx table TableA6(2,2/4), border (bottom, single) 
putdocx table TableA6(2,6/8), border (bottom, single) 

putdocx table TableA6(2,2) = ("Poor-Fair %"), halign (center) 
putdocx table TableA6(2,3) = ("Good %"), halign (center)
putdocx table TableA6(2,4) = ("Very good - Excellent %"), halign (center)
putdocx table TableA6(2,6) = ("Mean"), halign (center)
putdocx table TableA6(2,7) = ("St. dev."), halign (center)
putdocx table TableA6(2,8) = ("N"), halign (center)

svy: tabulate genhealth_3uncat 

putdocx table TableA6(3,1) = (e(rowvlab))

putdocx table TableA6(3,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA6(3,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA6(3,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)


svy: mean genhealth01  
	estat sd 

putdocx table TableA6(3,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA6(3,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA6(3,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)





 
********************************************************************************
* Table A10 Number in social network who had COVID *
********************************************************************************





	
putdocx table TableA10 = (4,9), border(all, nil) layout(autofitcontents)   		///
	note ("Number in social network who had COVID is indicated by:")	///
	note ("${ac_covid01_note1}")												
putdocx table TableA10(1,.), border (bottom, double)  height(48pt  , atleast ) 
putdocx table TableA10(1,1) = ("Table A10. Number in social network who had COVID"), colspan(7) halign(left) 

putdocx table TableA10(2,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA10(3,.),   height(24pt  , atleast ) valign (center)
 
putdocx table TableA10(4,.),   height(5pt  , atleast ) valign (center) border (bottom, single) 


putdocx table TableA10(2,2/5), border (bottom, single) 
putdocx table TableA10(2,7/9), border (bottom, single) 

putdocx table TableA10(2,2) = ("0 %"), halign (center) 
putdocx table TableA10(2,3) = ("1 %"), halign (center)
putdocx table TableA10(2,4) = ("2-5 %"), halign (center)
putdocx table TableA10(2,5) = ("6 or more %"), halign (center)

putdocx table TableA10(2,7) = ("Mean"), halign (center)
putdocx table TableA10(2,8) = ("St. dev."), halign (center)
putdocx table TableA10(2,9) = ("N"), halign (center)

svy: tabulate  ac_covid_4cat 
 

putdocx table TableA10(3,1) = (e(rowvlab))

putdocx table TableA10(3,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA10(3,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA10(3,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)
putdocx table TableA10(3,5) = ((e(b)[1,4])*100) , nformat("%5.0f") halign(center)


svy: mean ac_covid01  
	estat sd 

putdocx table TableA10(3,7) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA10(3,8) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA10(3,9) = ((e(df_r))+1), nformat("%5.0f") halign(center)



  
********************************************************************************
* Table A11 Education  *
********************************************************************************





	
putdocx table TableA11 = (4,8), border(all, nil) layout(autofitcontents)   		///

putdocx table TableA11(1,.), border (bottom, double)  height(48pt  , atleast ) 
putdocx table TableA11(1,1) = ("Table A11. Education"), colspan(7) halign(left) 

putdocx table TableA11(2,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA11(3,.),   height(24pt  , atleast ) valign (center)
 
putdocx table TableA11(4,.),   height(5pt  , atleast ) valign (center) border (bottom, single) 


putdocx table TableA11(2,2/4), border (bottom, single) 
putdocx table TableA11(2,6/8), border (bottom, single) 

putdocx table TableA11(2,2) = ("Highschool %"), halign (center) 
putdocx table TableA11(2,3) = ("Some college %"), halign (center)
putdocx table TableA11(2,4) = ("College degree %"), halign (center)

putdocx table TableA11(2,6) = ("Mean"), halign (center)
putdocx table TableA11(2,7) = ("St. dev."), halign (center)
putdocx table TableA11(2,8) = ("N"), halign (center)

svy: tabulate educ_3cat if year ==2020 

putdocx table TableA11(3,1) = (e(rowvlab))

putdocx table TableA11(3,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA11(3,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA11(3,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)


svy: mean educ01  if year ==2020 
	estat sd 

putdocx table TableA11(3,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA11(3,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA11(3,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)



********************************************************************************
* Table A12. Age *
********************************************************************************




 
	
putdocx table TableA12 = (4,9), border(all, nil) layout(autofitcontents)   		///

putdocx table TableA12(1,.), border (bottom, double)  height(48pt  , atleast ) 
putdocx table TableA12(1,1) = ("Table A12. Age"), colspan(7) halign(left) 

putdocx table TableA12(2,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA12(3,.),   height(24pt  , atleast ) valign (center)
 
putdocx table TableA12(4,.),   height(5pt  , atleast ) valign (center) border (bottom, single) 


putdocx table TableA12(2,2/5), border (bottom, single) 
putdocx table TableA12(2,7/9), border (bottom, single) 

putdocx table TableA12(2,2) = ("18-33 %"), halign (center) 
putdocx table TableA12(2,3) = ("34-48 %"), halign (center)
putdocx table TableA12(2,4) = ("49-64 %"), halign (center)
putdocx table TableA12(2,5) = ("Above 64 %"), halign (center)

putdocx table TableA12(2,7) = ("Mean"), halign (center)
putdocx table TableA12(2,8) = ("St. dev."), halign (center)
putdocx table TableA12(2,9) = ("N"), halign (center)

svy: tabulate  age_4cat if year == 2020
 

putdocx table TableA12(3,1) = (e(rowvlab))

putdocx table TableA12(3,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA12(3,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA12(3,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)
putdocx table TableA12(3,5) = ((e(b)[1,4])*100) , nformat("%5.0f") halign(center)


svy: mean age01  if year == 2020
	estat sd 

putdocx table TableA12(3,7) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA12(3,8) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA12(3,9) = ((e(df_r))+1), nformat("%5.0f") halign(center)




putdocx save "DescStatTables_COVID_paper_Appendix.docx", replace



********************************************************************************
* Table A14. Racial resentment descriptive statistics
********************************************************************************



putdocx clear 
					
putdocx begin, pagesize(letter) font("Times New Roman" ,10,black) 				///
	margin(left,0.5) margin(right,0.5)
putdocx paragraph 
alpha den_favors01  den_dif01 den_advant01 den_rare01 if year ==2020, item  	 
local alpha : display %4.2f `r(alpha)'
putdocx table TableA14 = (7,8), border(all, nil) layout(autofitcontents)   		///
	note ("Alpha = `alpha'. Racial resentment indicated by:")			///
	note ("${den_advant01_note1}")												///									
	note ("${den_rare01_note1}")												///
	note ("${den_favors01_note1}")												///
	note ("${den_dif01_note1}")	
putdocx table TableA14(1,.), border (bottom, double)  height(48pt  , atleast ) 
putdocx table TableA14(1,1) = ("Table A2. Racial resentment"), colspan(7) halign(left) 

putdocx table TableA14(2,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA14(3,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA14(4,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA14(5,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA14(6,.),   height(24pt  , atleast ) valign (center)

putdocx table TableA14(7,.),   height(5pt  , atleast ) valign (center) border (bottom, single) 


putdocx table TableA14(2,2/4), border (bottom, single) 
putdocx table TableA14(2,6/8), border (bottom, single) 

putdocx table TableA14(2,2) = ("Low %"), halign (center) 
putdocx table TableA14(2,3) = ("Medium %"), halign (center)
putdocx table TableA14(2,4) = ("High %"), halign (center)
putdocx table TableA14(2,6) = ("Mean"), halign (center)
putdocx table TableA14(2,7) = ("St. dev."), halign (center)
putdocx table TableA14(2,8) = ("N"), halign (center)

svy: tabulate den_advant_3uncat if year == 2020

putdocx table TableA14(3,1) = (e(rowvlab))

putdocx table TableA14(3,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA14(3,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA14(3,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)


svy: mean den_advant01  if year == 2020
	estat sd 

putdocx table TableA14(3,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA14(3,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA14(3,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)



svy: tabulate den_rare_3uncat if year ==2020 

putdocx table TableA14(4,1) = (e(rowvlab))

putdocx table TableA14(4,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA14(4,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA14(4,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)

svy: mean den_rare01 if year ==2020 
	estat sd 

putdocx table TableA14(4,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA14(4,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA14(4,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)





svy: tabulate den_favors_3uncat 

putdocx table TableA14(5,1) = (e(rowvlab))


putdocx table TableA14(5,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA14(5,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA14(5,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)




svy: mean den_favors01  
	estat sd 

putdocx table TableA14(5,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA14(5,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA14(5,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)




svy: tabulate den_dif_3uncat 

putdocx table TableA14(6,1) = (e(rowvlab))


putdocx table TableA14(6,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA14(6,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA14(6,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)


svy: mean den_dif01  
	estat sd 

putdocx table TableA14(6,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA14(6,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA14(6,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)



********************************************************************************
* Table A15. Resentment toward women *
********************************************************************************




putdocx paragraph 

corr femres_power01 femres_offend01  	 
local r : display %4.2f `r(rho)'
putdocx table TableA14 = (6,8), border(all, nil) layout(autofitcontents)   		///
	note ("Pearson r = `r'. High resentment of women indicated by:")	///
	note ("${femres_power_note1}")	///											
	note ("${femres_offend_note1}")											
putdocx table TableA14(1,.), border (bottom, double)  height(48pt  , atleast ) 
putdocx table TableA14(1,1) = ("Table A3. Resentment of women"), colspan(7) halign(left) 

putdocx table TableA14(2,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA14(3,.),   height(24pt  , atleast ) valign (center)
putdocx table TableA14(4,.),   height(24pt  , atleast ) valign (center)
 
putdocx table TableA14(5,.),   height(5pt  , atleast ) valign (center) border (bottom, single) 


putdocx table TableA14(2,2/5), border (bottom, single) 
putdocx table TableA14(2,6/8), border (bottom, single) 

putdocx table TableA14(2,2) = ("Low %"), halign (center) 
putdocx table TableA14(2,3) = ("Medium %"), halign (center)
putdocx table TableA14(2,4) = ("High %"), halign (center)

putdocx table TableA14(2,6) = ("Mean"), halign (center)
putdocx table TableA14(2,7) = ("St. dev."), halign (center)
putdocx table TableA14(2,8) = ("N"), halign (center)

svy: tabulate femres_power_3uncat 

putdocx table TableA14(3,1) = (e(rowvlab))

putdocx table TableA14(3,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA14(3,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA14(3,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)


svy: mean femres_power01  
	estat sd 

putdocx table TableA14(3,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA14(3,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA14(3,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)



svy: tabulate femres_offend_3uncat 

putdocx table TableA14(4,1) = (e(rowvlab))

putdocx table TableA14(4,2) = ((e(b)[1,1])*100) , nformat("%5.0f") halign(center)
putdocx table TableA14(4,3) = ((e(b)[1,2])*100) , nformat("%5.0f") halign(center)
putdocx table TableA14(4,4) = ((e(b)[1,3])*100) , nformat("%5.0f") halign(center)

svy: mean femres_offend01 
	estat sd 

putdocx table TableA14(4,6) = (e(b)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA14(4,7) = (r(sd)[1,1]) , nformat("%5.2f") halign(center)
putdocx table TableA14(4,8) = ((e(df_r))+1), nformat("%5.0f") halign(center)



putdocx save "DescStatTables_COVID_paper_Appendix_Social_Dominance.docx", replace







* Post 


*****************************************************************
* Perceptions of economics: absolute and relative deprivation  * 
*****************************************************************

// CUB3B31 CUB3B32 CUB3B33 CUB3B35 
// econ_expect econ_expect01 econ_friends econ_friends01 econ_country econ_country01 econ_worry econ_worry01
// econ_anxiety01 econ_rel_dep01 




recode CUB3B31 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(econ_expect)	
generate econ_expect01=econ_expect/6

note econ_expect01: I believe that I am not as financially successful as I thought I would be
label var econ_expect01 "Less success: I thought I would be"

recode CUB3B32 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(econ_friends)	
generate econ_friends01=econ_friends/6

note econ_friends01: I feel that I am less financially successful than my friends and family
label var econ_friends01 "Less success: than friends/family"


recode CUB3B33 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(econ_country)	
generate econ_country01=econ_country/6

note econ_country01: When I think about my financial situation, I feel that my country has left me behind
label var econ_country01 "Less success: than my country"


recode CUB3B35 		(1=6 "6.Agree strongly") 	(2=5 "5.Agree") /// 
					(3=4 "4.Agree somewhat") 	(4=3 "3.Neither agree nor disagree")  /// 
					(5=2 "2.Disagree somewhat") (6=1 "1.Disagree")  /// 
					(7=0 "0.Disagree strongly"), generate(econ_worry)	
generate econ_worry01=econ_worry/6

note econ_worry01: I feel very worried about my financial future
label var econ_worry01 "Economic worry" 



note econ_expect : I believe that I am not as financially successful as I thought I would be
note econ_friends: I feel that I am less financially successful than my friends and family
note econ_country: When I think about my financial situation, I feel that my country has left me behind
note econ_worry: I feel very worried about my financial future


obey, dog, econ_expect, econ_friends, liberty, absrol_judges
Variable Label

Please randomize the order that the row items are asked.  
Any special instructions for programmers

ROWS:
CUB4B01	In today's world, parents should emphasize obedience more.
CUB4B02	A group which tolerates too many differences of opinion among its own members cannot exist for long 
CUB4B03	I believe that I am not as financially successful as I thought I would be.
CUB4B04	I feel that I am less financially successful than my friends and family.
CUB4B05	Free speech is just not worth it if it means that we have to put up with the danger to society of extremist political views.
CUB4B06	Judges should make decisions based on what they consider right, without regard to the law.


CUB4B07	When I make decisions, I trust myself more than anyone else.
CUB4B08	People are just too quick to judge others for mistakes that are not their fault.
CUB4B09	I often make choices I don't like to avoid upsetting people in my life. 
CUB4B10	I would like it if we as a society created rules that punish people for immoral behavior.
CUB4B11	I have to admit it is fun to watch bad people get what they deserve. 
CUB4B12	Too many people accept the opinions of experts without thinking for themselves. 



ind_rules, hatred, lonely, self_difficult, invinc_handle_r, coll_share
Variable Label

Please randomize the order that the row items are asked.  
Any special instructions for programmers

ROWS:
CUB4B13	I often find myself looking for ways to get around the rules.
CUB4B14	I feel the emotion of hatred often
CUB4B15	I feel the emotion of loneliness often.
CUB4B16	When facing difficult tasks, I am certain that I will be able to accomplish them.
CUB4B17	It seems like other people can handle things that are harder for me.
CUB4B18	I am a person who is willing to share with others without expecting anything in return.


Some people feel that what happens to other people who are like them will also have something to do with their own lives. Others feel that what happens to other people who are like them will have nothing to do with their own lives. On a scale from 1-to-7 with 1 being "not at all likely," and 7 being "extremely likely," how likely is it that your life will be affected by what happens to… 

Question Text

ROWS:
CUB4B19	Those who share your race or ethnicity
CUB4B20	Those who share your political beliefs
CUB4B21	Those who share your socio-economic class
CUB4B22	Americans as a whole


I have continued to take the following precautions to prevent the spread of Covid-19. (select all that apply)   
Question Text


ROWS: 
CUB4B23	I postponed travel to avoid catching COVID
CUB4B24	I wear a mask in crowded indoor areas 
CUB4B25	I read news related to COVID
CUB4B26	Stayed home when I was sick 
CUB4B27	Talk to my friends about being COVID safe 



If respondent selects any of items CUB4B23, CUB4B24, CUB4B25, CUB4B26, CUB4B27 then present items CUB4B29, CUB4B30, CUB4B31, CUB4B32, CUB4B33, CUB4B34
Any special instructions for programmers

Why did you take these precautions (select all that apply)
Question Text


CUB4B29	I spend time around people who could become very ill with COVID
CUB4B30	I am afraid of getting sick from COVID
CUB4B31	I am afraid I could infect a family member 
CUB4B32	I am afraid I could infect a friend or colleague 
CUB4B33	A stranger might catch COVID from me

CUB4B34	None of these
Outcome 	Outcome Label and instructions in { }



CUB4B35, CUB4B36, CUB4B37, CUB4B38, CUB4B39, CUB4B40 
(22 points *1/2 respondents)

Variable Name

DYNAMIC GRID
Variable Type 
If respondent selects CUB4B34, then present items CUB4B35, CUB4B36, CUB4B37, CUB4B38, CUB4B39, CUB4B40
Any special instructions for programmers


Why did you not take these precautions (select all that apply)
Question Text

CUB4B35	I am rarely around people who could give me COVID
CUB4B36	I am rarely around people who might catch COVID from me
CUB4B37	COVID is not a threat to me
CUB4B38	I have no friends or family who are afraid they might get COVID
CUB4B39	I do not trust medical experts who say that COVID is a threat

CUB4B40	None of these








